Class: Aws::Lambda::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Lambda::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-lambda/client.rb
Overview
An API client for Lambda. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::Lambda::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_layer_version_permission(params = {}) ⇒ Types::AddLayerVersionPermissionResponse
Adds permissions to the resource-based policy of a version of an [Lambda layer].
-
#add_permission(params = {}) ⇒ Types::AddPermissionResponse
Grants an Amazon Web Service, Amazon Web Services account, or Amazon Web Services organization permission to use a function.
-
#create_alias(params = {}) ⇒ Types::AliasConfiguration
Creates an [alias] for a Lambda function version.
-
#create_code_signing_config(params = {}) ⇒ Types::CreateCodeSigningConfigResponse
Creates a code signing configuration.
-
#create_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Creates a mapping between an event source and an Lambda function.
-
#create_function(params = {}) ⇒ Types::FunctionConfiguration
Creates a Lambda function.
-
#create_function_url_config(params = {}) ⇒ Types::CreateFunctionUrlConfigResponse
Creates a Lambda function URL with the specified configuration parameters.
-
#delete_alias(params = {}) ⇒ Struct
Deletes a Lambda function [alias].
-
#delete_code_signing_config(params = {}) ⇒ Struct
Deletes the code signing configuration.
-
#delete_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Deletes an [event source mapping].
-
#delete_function(params = {}) ⇒ Struct
Deletes a Lambda function.
-
#delete_function_code_signing_config(params = {}) ⇒ Struct
Removes the code signing configuration from the function.
-
#delete_function_concurrency(params = {}) ⇒ Struct
Removes a concurrent execution limit from a function.
-
#delete_function_event_invoke_config(params = {}) ⇒ Struct
Deletes the configuration for asynchronous invocation for a function, version, or alias.
-
#delete_function_url_config(params = {}) ⇒ Struct
Deletes a Lambda function URL.
-
#delete_layer_version(params = {}) ⇒ Struct
Deletes a version of an [Lambda layer].
-
#delete_provisioned_concurrency_config(params = {}) ⇒ Struct
Deletes the provisioned concurrency configuration for a function.
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Retrieves details about your account's [limits] and usage in an Amazon Web Services Region.
-
#get_alias(params = {}) ⇒ Types::AliasConfiguration
Returns details about a Lambda function [alias].
-
#get_code_signing_config(params = {}) ⇒ Types::GetCodeSigningConfigResponse
Returns information about the specified code signing configuration.
-
#get_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Returns details about an event source mapping.
-
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Returns information about the function or function version, with a link to download the deployment package that's valid for 10 minutes.
-
#get_function_code_signing_config(params = {}) ⇒ Types::GetFunctionCodeSigningConfigResponse
Returns the code signing configuration for the specified function.
-
#get_function_concurrency(params = {}) ⇒ Types::GetFunctionConcurrencyResponse
Returns details about the reserved concurrency configuration for a function.
-
#get_function_configuration(params = {}) ⇒ Types::FunctionConfiguration
Returns the version-specific settings of a Lambda function or version.
-
#get_function_event_invoke_config(params = {}) ⇒ Types::FunctionEventInvokeConfig
Retrieves the configuration for asynchronous invocation for a function, version, or alias.
-
#get_function_url_config(params = {}) ⇒ Types::GetFunctionUrlConfigResponse
Returns details about a Lambda function URL.
-
#get_layer_version(params = {}) ⇒ Types::GetLayerVersionResponse
Returns information about a version of an [Lambda layer], with a link to download the layer archive that's valid for 10 minutes.
-
#get_layer_version_by_arn(params = {}) ⇒ Types::GetLayerVersionResponse
Returns information about a version of an [Lambda layer], with a link to download the layer archive that's valid for 10 minutes.
-
#get_layer_version_policy(params = {}) ⇒ Types::GetLayerVersionPolicyResponse
Returns the permission policy for a version of an [Lambda layer].
-
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Returns the [resource-based IAM policy] for a function, version, or alias.
-
#get_provisioned_concurrency_config(params = {}) ⇒ Types::GetProvisionedConcurrencyConfigResponse
Retrieves the provisioned concurrency configuration for a function's alias or version.
-
#invoke(params = {}) ⇒ Types::InvocationResponse
Invokes a Lambda function.
-
#invoke_async(params = {}) ⇒ Types::InvokeAsyncResponse
For asynchronous function invocation, use Invoke.
-
#list_aliases(params = {}) ⇒ Types::ListAliasesResponse
Returns a list of [aliases] for a Lambda function.
-
#list_code_signing_configs(params = {}) ⇒ Types::ListCodeSigningConfigsResponse
Returns a list of [code signing configurations].
-
#list_event_source_mappings(params = {}) ⇒ Types::ListEventSourceMappingsResponse
Lists event source mappings.
-
#list_function_event_invoke_configs(params = {}) ⇒ Types::ListFunctionEventInvokeConfigsResponse
Retrieves a list of configurations for asynchronous invocation for a function.
-
#list_function_url_configs(params = {}) ⇒ Types::ListFunctionUrlConfigsResponse
Returns a list of Lambda function URLs for the specified function.
-
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
Returns a list of Lambda functions, with the version-specific configuration of each.
-
#list_functions_by_code_signing_config(params = {}) ⇒ Types::ListFunctionsByCodeSigningConfigResponse
List the functions that use the specified code signing configuration.
-
#list_layer_versions(params = {}) ⇒ Types::ListLayerVersionsResponse
Lists the versions of an [Lambda layer].
-
#list_layers(params = {}) ⇒ Types::ListLayersResponse
Lists [Lambda layers] and shows information about the latest version of each.
-
#list_provisioned_concurrency_configs(params = {}) ⇒ Types::ListProvisionedConcurrencyConfigsResponse
Retrieves a list of provisioned concurrency configurations for a function.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns a function's [tags].
-
#list_versions_by_function(params = {}) ⇒ Types::ListVersionsByFunctionResponse
Returns a list of [versions], with the version-specific configuration of each.
-
#publish_layer_version(params = {}) ⇒ Types::PublishLayerVersionResponse
Creates an [Lambda layer] from a ZIP archive.
-
#publish_version(params = {}) ⇒ Types::FunctionConfiguration
Creates a [version] from the current code and configuration of a function.
-
#put_function_code_signing_config(params = {}) ⇒ Types::PutFunctionCodeSigningConfigResponse
Update the code signing configuration for the function.
-
#put_function_concurrency(params = {}) ⇒ Types::Concurrency
Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level.
-
#put_function_event_invoke_config(params = {}) ⇒ Types::FunctionEventInvokeConfig
Configures options for [asynchronous invocation] on a function, version, or alias.
-
#put_provisioned_concurrency_config(params = {}) ⇒ Types::PutProvisionedConcurrencyConfigResponse
Adds a provisioned concurrency configuration to a function's alias or version.
-
#remove_layer_version_permission(params = {}) ⇒ Struct
Removes a statement from the permissions policy for a version of an [Lambda layer].
-
#remove_permission(params = {}) ⇒ Struct
Revokes function-use permission from an Amazon Web Service or another Amazon Web Services account.
-
#tag_resource(params = {}) ⇒ Struct
Adds [tags] to a function.
-
#untag_resource(params = {}) ⇒ Struct
Removes [tags] from a function.
-
#update_alias(params = {}) ⇒ Types::AliasConfiguration
Updates the configuration of a Lambda function [alias].
-
#update_code_signing_config(params = {}) ⇒ Types::UpdateCodeSigningConfigResponse
Update the code signing configuration.
-
#update_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Updates an event source mapping.
-
#update_function_code(params = {}) ⇒ Types::FunctionConfiguration
Updates a Lambda function's code.
-
#update_function_configuration(params = {}) ⇒ Types::FunctionConfiguration
Modify the version-specific settings of a Lambda function.
-
#update_function_event_invoke_config(params = {}) ⇒ Types::FunctionEventInvokeConfig
Updates the configuration for asynchronous invocation for a function, version, or alias.
-
#update_function_url_config(params = {}) ⇒ Types::UpdateFunctionUrlConfigResponse
Updates the configuration for a Lambda function URL.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-lambda/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5968 5969 5970 |
# File 'lib/aws-sdk-lambda/client.rb', line 5968 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5971 5972 5973 |
# File 'lib/aws-sdk-lambda/client.rb', line 5971 def errors_module Errors end |
Instance Method Details
#add_layer_version_permission(params = {}) ⇒ Types::AddLayerVersionPermissionResponse
Adds permissions to the resource-based policy of a version of an [Lambda layer]. Use this action to grant layer usage permission to other accounts. You can grant permission to a single account, all accounts in an organization, or all Amazon Web Services accounts.
To revoke permission, call RemoveLayerVersionPermission with the statement ID that you specified when you added it.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
439 440 441 442 |
# File 'lib/aws-sdk-lambda/client.rb', line 439 def (params = {}, = {}) req = build_request(:add_layer_version_permission, params) req.send_request() end |
#add_permission(params = {}) ⇒ Types::AddPermissionResponse
Grants an Amazon Web Service, Amazon Web Services account, or Amazon Web Services organization permission to use a function. You can apply the policy at the function level, or specify a qualifier to restrict access to a single version or alias. If you use a qualifier, the invoker must use the full Amazon Resource Name (ARN) of that version or alias to invoke the function. Note: Lambda does not support adding policies to version $LATEST.
To grant permission to another account, specify the account ID as the `Principal`. To grant permission to an organization defined in Organizations, specify the organization ID as the `PrincipalOrgID`. For Amazon Web Services, the principal is a domain-style identifier that the service defines, such as `s3.amazonaws.com` or `sns.amazonaws.com`. For Amazon Web Services, you can also specify the ARN of the associated resource as the `SourceArn`. If you grant permission to a service principal without specifying the source, other accounts could potentially configure resources in their account to invoke your Lambda function.
This operation adds a statement to a resource-based permissions policy for the function. For more information about function policies, see [Using resource-based policies for Lambda].
[1]: docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html
571 572 573 574 |
# File 'lib/aws-sdk-lambda/client.rb', line 571 def (params = {}, = {}) req = build_request(:add_permission, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 |
# File 'lib/aws-sdk-lambda/client.rb', line 5823 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-lambda' context[:gem_version] = '1.90.0' Seahorse::Client::Request.new(handlers, context) end |
#create_alias(params = {}) ⇒ Types::AliasConfiguration
Creates an [alias] for a Lambda function version. Use aliases to provide clients with a function identifier that you can update to invoke a different version.
You can also map an alias to split invocation requests between two versions. Use the `RoutingConfig` parameter to specify a second version and the percentage of invocation requests that it receives.
[1]: docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html
656 657 658 659 |
# File 'lib/aws-sdk-lambda/client.rb', line 656 def create_alias(params = {}, = {}) req = build_request(:create_alias, params) req.send_request() end |
#create_code_signing_config(params = {}) ⇒ Types::CreateCodeSigningConfigResponse
Creates a code signing configuration. A [code signing configuration] defines a list of allowed signing profiles and defines the code-signing validation policy (action to be taken if deployment validation checks fail).
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-codesigning.html
710 711 712 713 |
# File 'lib/aws-sdk-lambda/client.rb', line 710 def create_code_signing_config(params = {}, = {}) req = build_request(:create_code_signing_config, params) req.send_request() end |
#create_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Creates a mapping between an event source and an Lambda function. Lambda reads items from the event source and invokes the function.
For details about how to configure different event sources, see the following topics.
- Amazon DynamoDB Streams][1
- Amazon Kinesis][2
- Amazon SQS][3
- Amazon MQ and RabbitMQ][4
- Amazon MSK][5
- Apache Kafka][6
The following error handling options are available only for stream sources (DynamoDB and Kinesis):
-
`BisectBatchOnFunctionError` – If the function returns an error, split the batch in two and retry.
-
`DestinationConfig` – Send discarded records to an Amazon SQS queue or Amazon SNS topic.
-
`MaximumRecordAgeInSeconds` – Discard records older than the specified age. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires
-
`MaximumRetryAttempts` – Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.
-
`ParallelizationFactor` – Process multiple batches from each shard concurrently.
For information about which configuration parameters apply to each event source, see the following topics.
- Amazon DynamoDB Streams][7
- Amazon Kinesis][8
- Amazon SQS][9
- Amazon MQ and RabbitMQ][10
- Amazon MSK][11
- Apache Kafka][12
[1]: docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-dynamodb-eventsourcemapping [2]: docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-eventsourcemapping [3]: docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#events-sqs-eventsource [4]: docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-eventsourcemapping [5]: docs.aws.amazon.com/lambda/latest/dg/with-msk.html [6]: docs.aws.amazon.com/lambda/latest/dg/kafka-smaa.html [7]: docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-ddb-params [8]: docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-params [9]: docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#services-sqs-params [10]: docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-params [11]: docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-parms [12]: docs.aws.amazon.com/lambda/latest/dg/with-kafka.html#services-kafka-parms
1063 1064 1065 1066 |
# File 'lib/aws-sdk-lambda/client.rb', line 1063 def create_event_source_mapping(params = {}, = {}) req = build_request(:create_event_source_mapping, params) req.send_request() end |
#create_function(params = {}) ⇒ Types::FunctionConfiguration
Creates a Lambda function. To create a function, you need a
- deployment package][1
-
and an [execution role]. The deployment
package is a .zip file archive or container image that contains your function code. The execution role grants the function permission to use Amazon Web Services, such as Amazon CloudWatch Logs for log streaming and X-Ray for request tracing.
If the deployment package is a [container image], then you set the package type to `Image`. For a container image, the code property must include the URI of a container image in the Amazon ECR registry. You do not need to specify the handler and runtime properties.
If the deployment package is a [.zip file archive], then you set the package type to `Zip`. For a .zip file archive, the code property specifies the location of the .zip file. You must also specify the handler and runtime properties. The code in the deployment package must be compatible with the target instruction set architecture of the function (`x86-64` or `arm64`). If you do not specify the architecture, then the default value is `x86-64`.
When you create a function, Lambda provisions an instance of the function and its supporting resources. If your function connects to a VPC, this process can take a minute or so. During this time, you can't invoke or modify the function. The `State`, `StateReason`, and `StateReasonCode` fields in the response from GetFunctionConfiguration indicate when the function is ready to invoke. For more information, see [Lambda function states].
A function has an unpublished version, and can have published versions and aliases. The unpublished version changes when you update your function's code and configuration. A published version is a snapshot of your function code and configuration that can't be changed. An alias is a named resource that maps to a version, and can be changed to map to a different version. Use the `Publish` parameter to create version `1` of your function from its initial configuration.
The other parameters let you configure version-specific and function-level settings. You can modify version-specific settings later with UpdateFunctionConfiguration. Function-level settings apply to both the unpublished and published versions of the function, and include tags (TagResource) and per-function concurrency limits (PutFunctionConcurrency).
You can use code signing if your deployment package is a .zip file archive. To enable code signing for this function, specify the ARN of a code-signing configuration. When a user attempts to deploy a code package with UpdateFunctionCode, Lambda checks that the code package has a valid signature from a trusted publisher. The code-signing configuration includes set of signing profiles, which define the trusted publishers for this function.
If another Amazon Web Services account or an Amazon Web Service invokes your function, use AddPermission to grant permission by creating a resource-based Identity and Access Management (IAM) policy. You can grant permissions at the function level, on a version, or on an alias.
To invoke your function directly, use Invoke. To invoke your function in response to events in other Amazon Web Services, create an event source mapping (CreateEventSourceMapping), or configure a function trigger in the other service. For more information, see [Invoking Lambda functions].
[1]: docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html [2]: docs.aws.amazon.com/lambda/latest/dg/intro-permission-model.html#lambda-intro-execution-role [3]: docs.aws.amazon.com/lambda/latest/dg/lambda-images.html [4]: docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html#gettingstarted-package-zip [5]: docs.aws.amazon.com/lambda/latest/dg/functions-states.html [6]: docs.aws.amazon.com/lambda/latest/dg/lambda-invocation.html
1454 1455 1456 1457 |
# File 'lib/aws-sdk-lambda/client.rb', line 1454 def create_function(params = {}, = {}) req = build_request(:create_function, params) req.send_request() end |
#create_function_url_config(params = {}) ⇒ Types::CreateFunctionUrlConfigResponse
Creates a Lambda function URL with the specified configuration parameters. A function URL is a dedicated HTTP(S) endpoint that you can use to invoke your function.
1545 1546 1547 1548 |
# File 'lib/aws-sdk-lambda/client.rb', line 1545 def create_function_url_config(params = {}, = {}) req = build_request(:create_function_url_config, params) req.send_request() end |
#delete_alias(params = {}) ⇒ Struct
Deletes a Lambda function [alias].
[1]: docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html
1587 1588 1589 1590 |
# File 'lib/aws-sdk-lambda/client.rb', line 1587 def delete_alias(params = {}, = {}) req = build_request(:delete_alias, params) req.send_request() end |
#delete_code_signing_config(params = {}) ⇒ Struct
Deletes the code signing configuration. You can delete the code signing configuration only if no function is using it.
1610 1611 1612 1613 |
# File 'lib/aws-sdk-lambda/client.rb', line 1610 def delete_code_signing_config(params = {}, = {}) req = build_request(:delete_code_signing_config, params) req.send_request() end |
#delete_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Deletes an [event source mapping]. You can get the identifier of a mapping from the output of ListEventSourceMappings.
When you delete an event source mapping, it enters a `Deleting` state and might not be completely deleted for several seconds.
[1]: docs.aws.amazon.com/lambda/latest/dg/intro-invocation-modes.html
1705 1706 1707 1708 |
# File 'lib/aws-sdk-lambda/client.rb', line 1705 def delete_event_source_mapping(params = {}, = {}) req = build_request(:delete_event_source_mapping, params) req.send_request() end |
#delete_function(params = {}) ⇒ Struct
Deletes a Lambda function. To delete a specific function version, use the `Qualifier` parameter. Otherwise, all versions and aliases are deleted.
To delete Lambda event source mappings that invoke a function, use DeleteEventSourceMapping. For Amazon Web Services and resources that invoke your function directly, delete the trigger in the service where you originally configured it.
1753 1754 1755 1756 |
# File 'lib/aws-sdk-lambda/client.rb', line 1753 def delete_function(params = {}, = {}) req = build_request(:delete_function, params) req.send_request() end |
#delete_function_code_signing_config(params = {}) ⇒ Struct
Removes the code signing configuration from the function.
1787 1788 1789 1790 |
# File 'lib/aws-sdk-lambda/client.rb', line 1787 def delete_function_code_signing_config(params = {}, = {}) req = build_request(:delete_function_code_signing_config, params) req.send_request() end |
#delete_function_concurrency(params = {}) ⇒ Struct
Removes a concurrent execution limit from a function.
1821 1822 1823 1824 |
# File 'lib/aws-sdk-lambda/client.rb', line 1821 def delete_function_concurrency(params = {}, = {}) req = build_request(:delete_function_concurrency, params) req.send_request() end |
#delete_function_event_invoke_config(params = {}) ⇒ Struct
Deletes the configuration for asynchronous invocation for a function, version, or alias.
To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.
1865 1866 1867 1868 |
# File 'lib/aws-sdk-lambda/client.rb', line 1865 def delete_function_event_invoke_config(params = {}, = {}) req = build_request(:delete_function_event_invoke_config, params) req.send_request() end |
#delete_function_url_config(params = {}) ⇒ Struct
Deletes a Lambda function URL. When you delete a function URL, you can't recover it. Creating a new function URL results in a different URL address.
1905 1906 1907 1908 |
# File 'lib/aws-sdk-lambda/client.rb', line 1905 def delete_function_url_config(params = {}, = {}) req = build_request(:delete_function_url_config, params) req.send_request() end |
#delete_layer_version(params = {}) ⇒ Struct
Deletes a version of an [Lambda layer]. Deleted versions can no longer be viewed or added to functions. To avoid breaking functions, a copy of the version remains in Lambda until no functions refer to it.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
1937 1938 1939 1940 |
# File 'lib/aws-sdk-lambda/client.rb', line 1937 def delete_layer_version(params = {}, = {}) req = build_request(:delete_layer_version, params) req.send_request() end |
#delete_provisioned_concurrency_config(params = {}) ⇒ Struct
Deletes the provisioned concurrency configuration for a function.
1975 1976 1977 1978 |
# File 'lib/aws-sdk-lambda/client.rb', line 1975 def delete_provisioned_concurrency_config(params = {}, = {}) req = build_request(:delete_provisioned_concurrency_config, params) req.send_request() end |
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Retrieves details about your account's [limits] and usage in an Amazon Web Services Region.
2006 2007 2008 2009 |
# File 'lib/aws-sdk-lambda/client.rb', line 2006 def get_account_settings(params = {}, = {}) req = build_request(:get_account_settings, params) req.send_request() end |
#get_alias(params = {}) ⇒ Types::AliasConfiguration
Returns details about a Lambda function [alias].
[1]: docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html
2065 2066 2067 2068 |
# File 'lib/aws-sdk-lambda/client.rb', line 2065 def get_alias(params = {}, = {}) req = build_request(:get_alias, params) req.send_request() end |
#get_code_signing_config(params = {}) ⇒ Types::GetCodeSigningConfigResponse
Returns information about the specified code signing configuration.
2099 2100 2101 2102 |
# File 'lib/aws-sdk-lambda/client.rb', line 2099 def get_code_signing_config(params = {}, = {}) req = build_request(:get_code_signing_config, params) req.send_request() end |
#get_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Returns details about an event source mapping. You can get the identifier of a mapping from the output of ListEventSourceMappings.
2187 2188 2189 2190 |
# File 'lib/aws-sdk-lambda/client.rb', line 2187 def get_event_source_mapping(params = {}, = {}) req = build_request(:get_event_source_mapping, params) req.send_request() end |
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Returns information about the function or function version, with a link to download the deployment package that's valid for 10 minutes. If you specify a function version, only details that are specific to that version are returned.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* function_active_v2
* function_exists
* function_updated_v2
2308 2309 2310 2311 |
# File 'lib/aws-sdk-lambda/client.rb', line 2308 def get_function(params = {}, = {}) req = build_request(:get_function, params) req.send_request() end |
#get_function_code_signing_config(params = {}) ⇒ Types::GetFunctionCodeSigningConfigResponse
Returns the code signing configuration for the specified function.
2350 2351 2352 2353 |
# File 'lib/aws-sdk-lambda/client.rb', line 2350 def get_function_code_signing_config(params = {}, = {}) req = build_request(:get_function_code_signing_config, params) req.send_request() end |
#get_function_concurrency(params = {}) ⇒ Types::GetFunctionConcurrencyResponse
Returns details about the reserved concurrency configuration for a function. To set a concurrency limit for a function, use PutFunctionConcurrency.
2392 2393 2394 2395 |
# File 'lib/aws-sdk-lambda/client.rb', line 2392 def get_function_concurrency(params = {}, = {}) req = build_request(:get_function_concurrency, params) req.send_request() end |
#get_function_configuration(params = {}) ⇒ Types::FunctionConfiguration
Returns the version-specific settings of a Lambda function or version. The output includes only options that can vary between versions of a function. To modify these settings, use UpdateFunctionConfiguration.
To get all of a function's details, including function-level settings, use GetFunction.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* function_active
* function_updated
* published_version_active
2538 2539 2540 2541 |
# File 'lib/aws-sdk-lambda/client.rb', line 2538 def get_function_configuration(params = {}, = {}) req = build_request(:get_function_configuration, params) req.send_request() end |
#get_function_event_invoke_config(params = {}) ⇒ Types::FunctionEventInvokeConfig
Retrieves the configuration for asynchronous invocation for a function, version, or alias.
To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.
2597 2598 2599 2600 |
# File 'lib/aws-sdk-lambda/client.rb', line 2597 def get_function_event_invoke_config(params = {}, = {}) req = build_request(:get_function_event_invoke_config, params) req.send_request() end |
#get_function_url_config(params = {}) ⇒ Types::GetFunctionUrlConfigResponse
Returns details about a Lambda function URL.
2660 2661 2662 2663 |
# File 'lib/aws-sdk-lambda/client.rb', line 2660 def get_function_url_config(params = {}, = {}) req = build_request(:get_function_url_config, params) req.send_request() end |
#get_layer_version(params = {}) ⇒ Types::GetLayerVersionResponse
Returns information about a version of an [Lambda layer], with a link to download the layer archive that's valid for 10 minutes.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
2719 2720 2721 2722 |
# File 'lib/aws-sdk-lambda/client.rb', line 2719 def get_layer_version(params = {}, = {}) req = build_request(:get_layer_version, params) req.send_request() end |
#get_layer_version_by_arn(params = {}) ⇒ Types::GetLayerVersionResponse
Returns information about a version of an [Lambda layer], with a link to download the layer archive that's valid for 10 minutes.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
2774 2775 2776 2777 |
# File 'lib/aws-sdk-lambda/client.rb', line 2774 def get_layer_version_by_arn(params = {}, = {}) req = build_request(:get_layer_version_by_arn, params) req.send_request() end |
#get_layer_version_policy(params = {}) ⇒ Types::GetLayerVersionPolicyResponse
Returns the permission policy for a version of an [Lambda layer]. For more information, see AddLayerVersionPermission.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
2813 2814 2815 2816 |
# File 'lib/aws-sdk-lambda/client.rb', line 2813 def get_layer_version_policy(params = {}, = {}) req = build_request(:get_layer_version_policy, params) req.send_request() end |
#get_policy(params = {}) ⇒ Types::GetPolicyResponse
Returns the [resource-based IAM policy] for a function, version, or alias.
[1]: docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html
2866 2867 2868 2869 |
# File 'lib/aws-sdk-lambda/client.rb', line 2866 def get_policy(params = {}, = {}) req = build_request(:get_policy, params) req.send_request() end |
#get_provisioned_concurrency_config(params = {}) ⇒ Types::GetProvisionedConcurrencyConfigResponse
Retrieves the provisioned concurrency configuration for a function's alias or version.
2921 2922 2923 2924 |
# File 'lib/aws-sdk-lambda/client.rb', line 2921 def get_provisioned_concurrency_config(params = {}, = {}) req = build_request(:get_provisioned_concurrency_config, params) req.send_request() end |
#invoke(params = {}) ⇒ Types::InvocationResponse
Invokes a Lambda function. You can invoke a function synchronously (and wait for the response), or asynchronously. To invoke a function asynchronously, set `InvocationType` to `Event`.
For [synchronous invocation], details about the function response, including errors, are included in the response body and headers. For either invocation type, you can find more information in the
- execution log][2
-
and [trace].
When an error occurs, your function may be invoked multiple times. Retry behavior varies by error type, client, event source, and invocation type. For example, if you invoke a function asynchronously and it returns an error, Lambda executes the function up to two more times. For more information, see [Error handling and automatic retries in Lambda].
For [asynchronous invocation], Lambda adds events to a queue before sending them to your function. If your function does not have enough capacity to keep up with the queue, events may be lost. Occasionally, your function may receive the same event multiple times, even if no error occurs. To retain events that were not processed, configure your function with a [dead-letter queue].
The status code in the API response doesn't reflect function errors. Error codes are reserved for errors that prevent your function from executing, such as permissions errors, [quota] errors, or issues with your function's code and configuration. For example, Lambda returns `TooManyRequestsException` if running the function would cause you to exceed a concurrency limit at either the account level (`ConcurrentInvocationLimitExceeded`) or function level (`ReservedFunctionConcurrentInvocationLimitExceeded`).
For functions with a long timeout, your client might disconnect during synchronous invocation while it waits for a response. Configure your HTTP client, SDK, firewall, proxy, or operating system to allow for long connections with timeout or keep-alive settings.
This operation requires permission for the [lambda:InvokeFunction] action. For details on how to set up permissions for cross-account invocations, see [Granting function access to other accounts].
[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-sync.html [2]: docs.aws.amazon.com/lambda/latest/dg/monitoring-functions.html [3]: docs.aws.amazon.com/lambda/latest/dg/lambda-x-ray.html [4]: docs.aws.amazon.com/lambda/latest/dg/invocation-retries.html [5]: docs.aws.amazon.com/lambda/latest/dg/invocation-async.html [6]: docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-dlq [7]: docs.aws.amazon.com/lambda/latest/dg/gettingstarted-limits.html [8]: docs.aws.amazon.com/IAM/latest/UserGuide/list_awslambda.html [9]: docs.aws.amazon.com/lambda/latest/dg/access-control-resource-based.html#permissions-resource-xaccountinvoke
3061 3062 3063 3064 |
# File 'lib/aws-sdk-lambda/client.rb', line 3061 def invoke(params = {}, = {}) req = build_request(:invoke, params) req.send_request() end |
#invoke_async(params = {}) ⇒ Types::InvokeAsyncResponse
For asynchronous function invocation, use Invoke.
Invokes a function asynchronously.
3107 3108 3109 3110 |
# File 'lib/aws-sdk-lambda/client.rb', line 3107 def invoke_async(params = {}, = {}) req = build_request(:invoke_async, params) req.send_request() end |
#list_aliases(params = {}) ⇒ Types::ListAliasesResponse
Returns a list of [aliases] for a Lambda function.
[1]: docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3176 3177 3178 3179 |
# File 'lib/aws-sdk-lambda/client.rb', line 3176 def list_aliases(params = {}, = {}) req = build_request(:list_aliases, params) req.send_request() end |
#list_code_signing_configs(params = {}) ⇒ Types::ListCodeSigningConfigsResponse
Returns a list of [code signing configurations]. A request returns up to 10,000 configurations per call. You can use the `MaxItems` parameter to return fewer configurations per call.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuring-codesigning.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3226 3227 3228 3229 |
# File 'lib/aws-sdk-lambda/client.rb', line 3226 def list_code_signing_configs(params = {}, = {}) req = build_request(:list_code_signing_configs, params) req.send_request() end |
#list_event_source_mappings(params = {}) ⇒ Types::ListEventSourceMappingsResponse
Lists event source mappings. Specify an `EventSourceArn` to show only event source mappings for a single event source.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3335 3336 3337 3338 |
# File 'lib/aws-sdk-lambda/client.rb', line 3335 def list_event_source_mappings(params = {}, = {}) req = build_request(:list_event_source_mappings, params) req.send_request() end |
#list_function_event_invoke_configs(params = {}) ⇒ Types::ListFunctionEventInvokeConfigsResponse
Retrieves a list of configurations for asynchronous invocation for a function.
To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3398 3399 3400 3401 |
# File 'lib/aws-sdk-lambda/client.rb', line 3398 def list_function_event_invoke_configs(params = {}, = {}) req = build_request(:list_function_event_invoke_configs, params) req.send_request() end |
#list_function_url_configs(params = {}) ⇒ Types::ListFunctionUrlConfigsResponse
Returns a list of Lambda function URLs for the specified function.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3468 3469 3470 3471 |
# File 'lib/aws-sdk-lambda/client.rb', line 3468 def list_function_url_configs(params = {}, = {}) req = build_request(:list_function_url_configs, params) req.send_request() end |
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
Returns a list of Lambda functions, with the version-specific configuration of each. Lambda returns up to 50 functions per call.
Set `FunctionVersion` to `ALL` to include all published versions of each function in addition to the unpublished version.
<note markdown=“1”> The `ListFunctions` operation returns a subset of the FunctionConfiguration fields. To get the additional fields (State, StateReasonCode, StateReason, LastUpdateStatus, LastUpdateStatusReason, LastUpdateStatusReasonCode) for a function or version, use GetFunction.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3587 3588 3589 3590 |
# File 'lib/aws-sdk-lambda/client.rb', line 3587 def list_functions(params = {}, = {}) req = build_request(:list_functions, params) req.send_request() end |
#list_functions_by_code_signing_config(params = {}) ⇒ Types::ListFunctionsByCodeSigningConfigResponse
List the functions that use the specified code signing configuration. You can use this method prior to deleting a code signing configuration, to verify that no functions are using it.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3631 3632 3633 3634 |
# File 'lib/aws-sdk-lambda/client.rb', line 3631 def list_functions_by_code_signing_config(params = {}, = {}) req = build_request(:list_functions_by_code_signing_config, params) req.send_request() end |
#list_layer_versions(params = {}) ⇒ Types::ListLayerVersionsResponse
Lists the versions of an [Lambda layer]. Versions that have been deleted aren't listed. Specify a [runtime identifier] to list only versions that indicate that they're compatible with that runtime. Specify a compatible architecture to include only layer versions that are compatible with that architecture.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html [2]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3701 3702 3703 3704 |
# File 'lib/aws-sdk-lambda/client.rb', line 3701 def list_layer_versions(params = {}, = {}) req = build_request(:list_layer_versions, params) req.send_request() end |
#list_layers(params = {}) ⇒ Types::ListLayersResponse
Lists [Lambda layers] and shows information about the latest version of each. Specify a [runtime identifier] to list only layers that indicate that they're compatible with that runtime. Specify a compatible architecture to include only layers that are compatible with that [instruction set architecture].
[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-layers.html [2]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html [3]: docs.aws.amazon.com/lambda/latest/dg/foundation-arch.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3770 3771 3772 3773 |
# File 'lib/aws-sdk-lambda/client.rb', line 3770 def list_layers(params = {}, = {}) req = build_request(:list_layers, params) req.send_request() end |
#list_provisioned_concurrency_configs(params = {}) ⇒ Types::ListProvisionedConcurrencyConfigsResponse
Retrieves a list of provisioned concurrency configurations for a function.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3831 3832 3833 3834 |
# File 'lib/aws-sdk-lambda/client.rb', line 3831 def list_provisioned_concurrency_configs(params = {}, = {}) req = build_request(:list_provisioned_concurrency_configs, params) req.send_request() end |
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Returns a function's [tags]. You can also view tags with GetFunction.
3866 3867 3868 3869 |
# File 'lib/aws-sdk-lambda/client.rb', line 3866 def (params = {}, = {}) req = build_request(:list_tags, params) req.send_request() end |
#list_versions_by_function(params = {}) ⇒ Types::ListVersionsByFunctionResponse
Returns a list of [versions], with the version-specific configuration of each. Lambda returns up to 50 versions per call.
[1]: docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3981 3982 3983 3984 |
# File 'lib/aws-sdk-lambda/client.rb', line 3981 def list_versions_by_function(params = {}, = {}) req = build_request(:list_versions_by_function, params) req.send_request() end |
#publish_layer_version(params = {}) ⇒ Types::PublishLayerVersionResponse
Creates an [Lambda layer] from a ZIP archive. Each time you call `PublishLayerVersion` with the same layer name, a new version is created.
Add layers to your function with CreateFunction or UpdateFunctionConfiguration.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
4085 4086 4087 4088 |
# File 'lib/aws-sdk-lambda/client.rb', line 4085 def publish_layer_version(params = {}, = {}) req = build_request(:publish_layer_version, params) req.send_request() end |
#publish_version(params = {}) ⇒ Types::FunctionConfiguration
Creates a [version] from the current code and configuration of a function. Use versions to create a snapshot of your function code and configuration that doesn't change.
Lambda doesn't publish a version if the function's configuration and code haven't changed since the last version. Use UpdateFunctionCode or UpdateFunctionConfiguration to update the function before publishing a version.
Clients can invoke versions directly or with an alias. To create an alias, use CreateAlias.
[1]: docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html
4245 4246 4247 4248 |
# File 'lib/aws-sdk-lambda/client.rb', line 4245 def publish_version(params = {}, = {}) req = build_request(:publish_version, params) req.send_request() end |
#put_function_code_signing_config(params = {}) ⇒ Types::PutFunctionCodeSigningConfigResponse
Update the code signing configuration for the function. Changes to the code signing configuration take effect the next time a user tries to deploy a code package to the function.
4293 4294 4295 4296 |
# File 'lib/aws-sdk-lambda/client.rb', line 4293 def put_function_code_signing_config(params = {}, = {}) req = build_request(:put_function_code_signing_config, params) req.send_request() end |
#put_function_concurrency(params = {}) ⇒ Types::Concurrency
Sets the maximum number of simultaneous executions for a function, and reserves capacity for that concurrency level.
Concurrency settings apply to the function as a whole, including all published versions and the unpublished version. Reserving concurrency both ensures that your function has capacity to process the specified number of events simultaneously, and prevents it from scaling beyond that level. Use GetFunction to see the current setting for a function.
Use GetAccountSettings to see your Regional concurrency limit. You can reserve concurrency for as many functions as you like, as long as you leave at least 100 simultaneous executions unreserved for functions that aren't configured with a per-function limit. For more information, see [Lambda function scaling].
[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-scaling.html
4354 4355 4356 4357 |
# File 'lib/aws-sdk-lambda/client.rb', line 4354 def put_function_concurrency(params = {}, = {}) req = build_request(:put_function_concurrency, params) req.send_request() end |
#put_function_event_invoke_config(params = {}) ⇒ Types::FunctionEventInvokeConfig
Configures options for [asynchronous invocation] on a function, version, or alias. If a configuration already exists for a function, version, or alias, this operation overwrites it. If you exclude any settings, they are removed. To set one option without affecting existing settings for other options, use UpdateFunctionEventInvokeConfig.
By default, Lambda retries an asynchronous invocation twice if the function returns an error. It retains events in a queue for up to six hours. When an event fails all processing attempts or stays in the asynchronous invocation queue for too long, Lambda discards it. To retain discarded events, configure a dead-letter queue with UpdateFunctionConfiguration.
To send an invocation record to a queue, topic, function, or event bus, specify a [destination]. You can configure separate destinations for successful invocations (on-success) and events that fail all processing attempts (on-failure). You can configure destinations in addition to or instead of a dead-letter queue.
[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-async.html [2]: docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations
4464 4465 4466 4467 |
# File 'lib/aws-sdk-lambda/client.rb', line 4464 def put_function_event_invoke_config(params = {}, = {}) req = build_request(:put_function_event_invoke_config, params) req.send_request() end |
#put_provisioned_concurrency_config(params = {}) ⇒ Types::PutProvisionedConcurrencyConfigResponse
Adds a provisioned concurrency configuration to a function's alias or version.
4524 4525 4526 4527 |
# File 'lib/aws-sdk-lambda/client.rb', line 4524 def put_provisioned_concurrency_config(params = {}, = {}) req = build_request(:put_provisioned_concurrency_config, params) req.send_request() end |
#remove_layer_version_permission(params = {}) ⇒ Struct
Removes a statement from the permissions policy for a version of an [Lambda layer]. For more information, see AddLayerVersionPermission.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
4566 4567 4568 4569 |
# File 'lib/aws-sdk-lambda/client.rb', line 4566 def (params = {}, = {}) req = build_request(:remove_layer_version_permission, params) req.send_request() end |
#remove_permission(params = {}) ⇒ Struct
Revokes function-use permission from an Amazon Web Service or another Amazon Web Services account. You can get the ID of the statement from the output of GetPolicy.
4619 4620 4621 4622 |
# File 'lib/aws-sdk-lambda/client.rb', line 4619 def (params = {}, = {}) req = build_request(:remove_permission, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds [tags] to a function.
4651 4652 4653 4654 |
# File 'lib/aws-sdk-lambda/client.rb', line 4651 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes [tags] from a function.
4681 4682 4683 4684 |
# File 'lib/aws-sdk-lambda/client.rb', line 4681 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_alias(params = {}) ⇒ Types::AliasConfiguration
Updates the configuration of a Lambda function [alias].
[1]: docs.aws.amazon.com/lambda/latest/dg/versioning-aliases.html
4766 4767 4768 4769 |
# File 'lib/aws-sdk-lambda/client.rb', line 4766 def update_alias(params = {}, = {}) req = build_request(:update_alias, params) req.send_request() end |
#update_code_signing_config(params = {}) ⇒ Types::UpdateCodeSigningConfigResponse
Update the code signing configuration. Changes to the code signing configuration take effect the next time a user tries to deploy a code package to the function.
4818 4819 4820 4821 |
# File 'lib/aws-sdk-lambda/client.rb', line 4818 def update_code_signing_config(params = {}, = {}) req = build_request(:update_code_signing_config, params) req.send_request() end |
#update_event_source_mapping(params = {}) ⇒ Types::EventSourceMappingConfiguration
Updates an event source mapping. You can change the function that Lambda invokes, or pause invocation and resume later from the same location.
For details about how to configure different event sources, see the following topics.
- Amazon DynamoDB Streams][1
- Amazon Kinesis][2
- Amazon SQS][3
- Amazon MQ and RabbitMQ][4
- Amazon MSK][5
- Apache Kafka][6
The following error handling options are available only for stream sources (DynamoDB and Kinesis):
-
`BisectBatchOnFunctionError` – If the function returns an error, split the batch in two and retry.
-
`DestinationConfig` – Send discarded records to an Amazon SQS queue or Amazon SNS topic.
-
`MaximumRecordAgeInSeconds` – Discard records older than the specified age. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires
-
`MaximumRetryAttempts` – Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.
-
`ParallelizationFactor` – Process multiple batches from each shard concurrently.
For information about which configuration parameters apply to each event source, see the following topics.
- Amazon DynamoDB Streams][7
- Amazon Kinesis][8
- Amazon SQS][9
- Amazon MQ and RabbitMQ][10
- Amazon MSK][11
- Apache Kafka][12
[1]: docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-dynamodb-eventsourcemapping [2]: docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-eventsourcemapping [3]: docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#events-sqs-eventsource [4]: docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-eventsourcemapping [5]: docs.aws.amazon.com/lambda/latest/dg/with-msk.html [6]: docs.aws.amazon.com/lambda/latest/dg/kafka-smaa.html [7]: docs.aws.amazon.com/lambda/latest/dg/with-ddb.html#services-ddb-params [8]: docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html#services-kinesis-params [9]: docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#services-sqs-params [10]: docs.aws.amazon.com/lambda/latest/dg/with-mq.html#services-mq-params [11]: docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-parms [12]: docs.aws.amazon.com/lambda/latest/dg/with-kafka.html#services-kafka-parms
5119 5120 5121 5122 |
# File 'lib/aws-sdk-lambda/client.rb', line 5119 def update_event_source_mapping(params = {}, = {}) req = build_request(:update_event_source_mapping, params) req.send_request() end |
#update_function_code(params = {}) ⇒ Types::FunctionConfiguration
Updates a Lambda function's code. If code signing is enabled for the function, the code package must be signed by a trusted publisher. For more information, see [Configuring code signing for Lambda].
If the function's package type is `Image`, then you must specify the code package in `ImageUri` as the URI of a [container image] in the Amazon ECR registry.
If the function's package type is `Zip`, then you must specify the deployment package as a [.zip file archive]. Enter the Amazon S3 bucket and key of the code .zip file location. You can also provide the function code inline using the `ZipFile` field.
The code in the deployment package must be compatible with the target instruction set architecture of the function (`x86-64` or `arm64`).
The function's code is locked when you publish a version. You can't modify the code of a published version, only the unpublished version.
<note markdown=“1”> For a function defined as a container image, Lambda resolves the image tag to an image digest. In Amazon ECR, if you update the image tag to a new image, Lambda does not automatically update the function.
</note>
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-codesigning.html [2]: docs.aws.amazon.com/lambda/latest/dg/lambda-images.html [3]: docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html#gettingstarted-package-zip
5326 5327 5328 5329 |
# File 'lib/aws-sdk-lambda/client.rb', line 5326 def update_function_code(params = {}, = {}) req = build_request(:update_function_code, params) req.send_request() end |
#update_function_configuration(params = {}) ⇒ Types::FunctionConfiguration
Modify the version-specific settings of a Lambda function.
When you update a function, Lambda provisions an instance of the function and its supporting resources. If your function connects to a VPC, this process can take a minute. During this time, you can't modify the function, but you can still invoke it. The `LastUpdateStatus`, `LastUpdateStatusReason`, and `LastUpdateStatusReasonCode` fields in the response from GetFunctionConfiguration indicate when the update is complete and the function is processing events with the new configuration. For more information, see [Lambda function states].
These settings can vary between versions of a function and are locked when you publish a version. You can't modify the configuration of a published version, only the unpublished version.
To configure function concurrency, use PutFunctionConcurrency. To grant invoke permissions to an Amazon Web Services account or Amazon Web Service, use AddPermission.
[1]: docs.aws.amazon.com/lambda/latest/dg/functions-states.html
5632 5633 5634 5635 |
# File 'lib/aws-sdk-lambda/client.rb', line 5632 def update_function_configuration(params = {}, = {}) req = build_request(:update_function_configuration, params) req.send_request() end |
#update_function_event_invoke_config(params = {}) ⇒ Types::FunctionEventInvokeConfig
Updates the configuration for asynchronous invocation for a function, version, or alias.
To configure options for asynchronous invocation, use PutFunctionEventInvokeConfig.
5723 5724 5725 5726 |
# File 'lib/aws-sdk-lambda/client.rb', line 5723 def update_function_event_invoke_config(params = {}, = {}) req = build_request(:update_function_event_invoke_config, params) req.send_request() end |
#update_function_url_config(params = {}) ⇒ Types::UpdateFunctionUrlConfigResponse
Updates the configuration for a Lambda function URL.
5814 5815 5816 5817 |
# File 'lib/aws-sdk-lambda/client.rb', line 5814 def update_function_url_config(params = {}, = {}) req = build_request(:update_function_url_config, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw `:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default `:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ———————— | ———————————– | ——– | ————- | | function_active | #get_function_configuration | 5 | 60 | | function_active_v2 | #get_function | 1 | 300 | | function_exists | #get_function | 1 | 20 | | function_updated | #get_function_configuration | 5 | 60 | | function_updated_v2 | #get_function | 1 | 300 | | published_version_active | #get_function_configuration | 5 | 312 |
5929 5930 5931 5932 5933 |
# File 'lib/aws-sdk-lambda/client.rb', line 5929 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5937 5938 5939 |
# File 'lib/aws-sdk-lambda/client.rb', line 5937 def waiter_names waiters.keys end |