Module: Aws::Lambda::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-lambda/errors.rb,
sig/errors.rbs
Overview
When Lambda returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::Lambda::Errors::ServiceError < Errors::ServiceError
You can rescue all Lambda errors using ServiceError:
begin
# do stuff
rescue Aws::Lambda::Errors::ServiceError
# rescues all Lambda API errors
end
Request Context
ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
Error Classes
- AliasLimitExceededException
- CallbackTimeoutException
- CapacityProviderLimitExceededException
- CodeArtifactUserDeletedException
- CodeArtifactUserFailedException
- CodeArtifactUserPendingException
- CodeSigningConfigNotFoundException
- CodeStorageExceededException
- CodeVerificationFailedException
- DurableExecutionAlreadyStartedException
- EC2AccessDeniedException
- EC2ThrottledException
- EC2UnexpectedException
- EFSIOException
- EFSMountConnectivityException
- EFSMountFailureException
- EFSMountTimeoutException
- ENILimitReachedException
- ENINotReadyException
- FunctionVersionsPerCapacityProviderLimitExceededException
- InvalidCodeSignatureException
- InvalidParameterValueException
- InvalidRequestContentException
- InvalidRuntimeException
- InvalidSecurityGroupIDException
- InvalidSubnetIDException
- InvalidZipFileException
- KMSAccessDeniedException
- KMSDisabledException
- KMSInvalidStateException
- KMSNotFoundException
- ModeNotSupportedException
- NoPublishedVersionException
- PolicyLengthExceededException
- PreconditionFailedException
- ProvisionedConcurrencyConfigNotFoundException
- PublicPolicyException
- RecursiveInvocationException
- RequestTooLargeException
- ResourceConflictException
- ResourceInUseException
- ResourceNotFoundException
- ResourceNotReadyException
- S3FilesMountConnectivityException
- S3FilesMountFailureException
- S3FilesMountTimeoutException
- SerializedRequestEntityTooLargeException
- ServiceException
- ServiceQuotaExceededException
- SnapStartException
- SnapStartNotReadyException
- SnapStartRegenerationFailureException
- SnapStartTimeoutException
- SubnetIPAddressLimitReachedException
- TooManyRequestsException
- UnsupportedMediaTypeException
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AliasLimitExceededException, CallbackTimeoutException, CapacityProviderLimitExceededException, CodeArtifactUserDeletedException, CodeArtifactUserFailedException, CodeArtifactUserPendingException, CodeSigningConfigNotFoundException, CodeStorageExceededException, CodeVerificationFailedException, DurableExecutionAlreadyStartedException, EC2AccessDeniedException, EC2ThrottledException, EC2UnexpectedException, EFSIOException, EFSMountConnectivityException, EFSMountFailureException, EFSMountTimeoutException, ENILimitReachedException, ENINotReadyException, FunctionVersionsPerCapacityProviderLimitExceededException, InvalidCodeSignatureException, InvalidParameterValueException, InvalidRequestContentException, InvalidRuntimeException, InvalidSecurityGroupIDException, InvalidSubnetIDException, InvalidZipFileException, KMSAccessDeniedException, KMSDisabledException, KMSInvalidStateException, KMSNotFoundException, ModeNotSupportedException, NoPublishedVersionException, PolicyLengthExceededException, PreconditionFailedException, ProvisionedConcurrencyConfigNotFoundException, PublicPolicyException, RecursiveInvocationException, RequestTooLargeException, ResourceConflictException, ResourceInUseException, ResourceNotFoundException, ResourceNotReadyException, S3FilesMountConnectivityException, S3FilesMountFailureException, S3FilesMountTimeoutException, SerializedRequestEntityTooLargeException, ServiceError, ServiceException, ServiceQuotaExceededException, SnapStartException, SnapStartNotReadyException, SnapStartRegenerationFailureException, SnapStartTimeoutException, SubnetIPAddressLimitReachedException, TooManyRequestsException, UnsupportedMediaTypeException