Class: Aws::Lambda::Types::AddLayerVersionPermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::AddLayerVersionPermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
When making an API call, you may pass AddLayerVersionPermissionRequest data as a hash:
{
layer_name: "LayerName", # required
version_number: 1, # required
statement_id: "StatementId", # required
action: "LayerPermissionAllowedAction", # required
principal: "LayerPermissionAllowedPrincipal", # required
organization_id: "OrganizationId",
revision_id: "String",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The API action that grants access to the layer.
-
#layer_name ⇒ String
The name or Amazon Resource Name (ARN) of the layer.
-
#organization_id ⇒ String
With the principal set to `*`, grant permission to all accounts in the specified organization.
-
#principal ⇒ String
An account ID, or `*` to grant layer usage permission to all accounts in an organization, or all Amazon Web Services accounts (if `organizationId` is not specified).
-
#revision_id ⇒ String
Only update the policy if the revision ID matches the ID specified.
-
#statement_id ⇒ String
An identifier that distinguishes the policy from others on the same layer version.
-
#version_number ⇒ Integer
The version number.
Instance Attribute Details
#action ⇒ String
The API action that grants access to the layer. For example, `lambda:GetLayerVersion`.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/aws-sdk-lambda/types.rb', line 125 class AddLayerVersionPermissionRequest < Struct.new( :layer_name, :version_number, :statement_id, :action, :principal, :organization_id, :revision_id) SENSITIVE = [] include Aws::Structure end |
#layer_name ⇒ String
The name or Amazon Resource Name (ARN) of the layer.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/aws-sdk-lambda/types.rb', line 125 class AddLayerVersionPermissionRequest < Struct.new( :layer_name, :version_number, :statement_id, :action, :principal, :organization_id, :revision_id) SENSITIVE = [] include Aws::Structure end |
#organization_id ⇒ String
With the principal set to `*`, grant permission to all accounts in the specified organization.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/aws-sdk-lambda/types.rb', line 125 class AddLayerVersionPermissionRequest < Struct.new( :layer_name, :version_number, :statement_id, :action, :principal, :organization_id, :revision_id) SENSITIVE = [] include Aws::Structure end |
#principal ⇒ String
An account ID, or `*` to grant layer usage permission to all accounts in an organization, or all Amazon Web Services accounts (if `organizationId` is not specified). For the last case, make sure that you really do want all Amazon Web Services accounts to have usage permission to this layer.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/aws-sdk-lambda/types.rb', line 125 class AddLayerVersionPermissionRequest < Struct.new( :layer_name, :version_number, :statement_id, :action, :principal, :organization_id, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Only update the policy if the revision ID matches the ID specified. Use this option to avoid modifying a policy that has changed since you last read it.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/aws-sdk-lambda/types.rb', line 125 class AddLayerVersionPermissionRequest < Struct.new( :layer_name, :version_number, :statement_id, :action, :principal, :organization_id, :revision_id) SENSITIVE = [] include Aws::Structure end |
#statement_id ⇒ String
An identifier that distinguishes the policy from others on the same layer version.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/aws-sdk-lambda/types.rb', line 125 class AddLayerVersionPermissionRequest < Struct.new( :layer_name, :version_number, :statement_id, :action, :principal, :organization_id, :revision_id) SENSITIVE = [] include Aws::Structure end |
#version_number ⇒ Integer
The version number.
125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/aws-sdk-lambda/types.rb', line 125 class AddLayerVersionPermissionRequest < Struct.new( :layer_name, :version_number, :statement_id, :action, :principal, :organization_id, :revision_id) SENSITIVE = [] include Aws::Structure end |