Class: Aws::Lambda::Types::AddPermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Note:

When making an API call, you may pass AddPermissionRequest data as a hash:

{
  function_name: "FunctionName", # required
  statement_id: "StatementId", # required
  action: "Action", # required
  principal: "Principal", # required
  source_arn: "Arn",
  source_account: "SourceOwner",
  event_source_token: "EventSourceToken",
  qualifier: "Qualifier",
  revision_id: "String",
  principal_org_id: "PrincipalOrgID",
  function_url_auth_type: "NONE", # accepts NONE, AWS_IAM
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action that the principal can use on the function. For example, `lambda:InvokeFunction` or `lambda:GetFunction`.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#event_source_tokenString

For Alexa Smart Home functions, a token that must be supplied by the invoker.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the Lambda function, version, or alias.

**Name formats**

  • **Function name** - `my-function` (name-only), `my-function:v1` (with alias).

  • **Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:my-function`.

  • **Partial ARN** - `123456789012:function:my-function`.

You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#function_url_auth_typeString

The type of authentication that your function URL uses. Set to `AWS_IAM` if you want to restrict access to authenticated `IAM` users only. Set to `NONE` if you want to bypass IAM authentication to create a public endpoint. For more information, see [ Security and auth model for Lambda function URLs].

[1]: docs.aws.amazon.com/lambda/latest/dg/urls-auth.html

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#principalString

The Amazon Web Services service or account that invokes the function. If you specify a service, use `SourceArn` or `SourceAccount` to limit who can invoke the function through that service.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#principal_org_idString

The identifier for your organization in Organizations. Use this to grant permissions to all the Amazon Web Services accounts under this organization.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#qualifierString

Specify a version or alias to add permissions to a published version of the function.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

Only update the policy if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_accountString

For Amazon S3, the ID of the account that owns the resource. Use this together with `SourceArn` to ensure that the resource is owned by the specified account. It is possible for an Amazon S3 bucket to be deleted by its owner and recreated by another account.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

For Amazon Web Services services, the ARN of the Amazon Web Services resource that invokes the function. For example, an Amazon S3 bucket or Amazon SNS topic.

Note that Lambda configures the comparison using the `StringLike` operator.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#statement_idString

A statement identifier that differentiates the statement from others in the same policy.

Returns:

  • (String)


258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/aws-sdk-lambda/types.rb', line 258

class AddPermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :action,
  :principal,
  :source_arn,
  :source_account,
  :event_source_token,
  :qualifier,
  :revision_id,
  :principal_org_id,
  :function_url_auth_type)
  SENSITIVE = []
  include Aws::Structure
end