Class: Aws::Lambda::Types::AmazonManagedKafkaEventSourceConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Note:

When making an API call, you may pass AmazonManagedKafkaEventSourceConfig data as a hash:

{
  consumer_group_id: "URI",
}

Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_group_idString

The identifier for the Kafka consumer group to join. The consumer group ID must be unique among all your Kafka event sources. After creating a Kafka event source mapping with the consumer group ID specified, you cannot update this value. For more information, see [Customizable consumer group ID].

[1]: docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-consumer-group-id

Returns:

  • (String)


408
409
410
411
412
# File 'lib/aws-sdk-lambda/types.rb', line 408

class AmazonManagedKafkaEventSourceConfig < Struct.new(
  :consumer_group_id)
  SENSITIVE = []
  include Aws::Structure
end