Class: Aws::Lambda::Types::CapacityProviderScalingConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Configuration that defines how the capacity provider scales compute instances based on demand and policies.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_v_cpu_countInteger

The maximum number of vCPUs that the capacity provider can provision across all compute instances.

Returns:

  • (Integer)


642
643
644
645
646
647
648
# File 'lib/aws-sdk-lambda/types.rb', line 642

class CapacityProviderScalingConfig < Struct.new(
  :max_v_cpu_count,
  :scaling_mode,
  :scaling_policies)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_modeString

The scaling mode that determines how the capacity provider responds to changes in demand.

Returns:

  • (String)


642
643
644
645
646
647
648
# File 'lib/aws-sdk-lambda/types.rb', line 642

class CapacityProviderScalingConfig < Struct.new(
  :max_v_cpu_count,
  :scaling_mode,
  :scaling_policies)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_policiesArray<Types::TargetTrackingScalingPolicy>

A list of scaling policies that define how the capacity provider scales compute instances based on metrics and thresholds.



642
643
644
645
646
647
648
# File 'lib/aws-sdk-lambda/types.rb', line 642

class CapacityProviderScalingConfig < Struct.new(
  :max_v_cpu_count,
  :scaling_mode,
  :scaling_policies)
  SENSITIVE = []
  include Aws::Structure
end