Class: Aws::Lambda::Types::CheckpointDurableExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::CheckpointDurableExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The response from the CheckpointDurableExecution operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checkpoint_token ⇒ String
A new checkpoint token to use for the next checkpoint operation.
-
#new_execution_state ⇒ Types::CheckpointUpdatedExecutionState
Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers.
Instance Attribute Details
#checkpoint_token ⇒ String
A new checkpoint token to use for the next checkpoint operation. This token replaces the one provided in the request and must be used for subsequent checkpoints to maintain proper ordering.
885 886 887 888 889 890 |
# File 'lib/aws-sdk-lambda/types.rb', line 885 class CheckpointDurableExecutionResponse < Struct.new( :checkpoint_token, :new_execution_state) SENSITIVE = [] include Aws::Structure end |
#new_execution_state ⇒ Types::CheckpointUpdatedExecutionState
Updated execution state information that includes any changes that occurred since the last checkpoint, such as completed callbacks or expired timers. This allows the SDK to update its internal state during replay.
885 886 887 888 889 890 |
# File 'lib/aws-sdk-lambda/types.rb', line 885 class CheckpointDurableExecutionResponse < Struct.new( :checkpoint_token, :new_execution_state) SENSITIVE = [] include Aws::Structure end |