Class: Aws::Lambda::Types::CheckpointUpdatedExecutionState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Contains operations that have been updated since the last checkpoint, such as completed asynchronous work like timers or callbacks.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_markerString

Indicates that more results are available. Use this value in a subsequent call to retrieve the next page of results.

Returns:

  • (String)


882
883
884
885
886
887
# File 'lib/aws-sdk-lambda/types.rb', line 882

class CheckpointUpdatedExecutionState < Struct.new(
  :operations,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#operationsArray<Types::Operation>

A list of operations that have been updated since the last checkpoint.

Returns:



882
883
884
885
886
887
# File 'lib/aws-sdk-lambda/types.rb', line 882

class CheckpointUpdatedExecutionState < Struct.new(
  :operations,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end