Class: Aws::Lambda::Types::CodeArtifactUserDeletedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The Lambda function couldn’t be invoked because its code artifact user has been deleted. Wait for Lambda to provision a new code artifact user, or update the function’s code package to recreate it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The exception message.

Returns:

  • (String)


928
929
930
931
932
933
# File 'lib/aws-sdk-lambda/types.rb', line 928

class CodeArtifactUserDeletedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The exception type.

Returns:

  • (String)


928
929
930
931
932
933
# File 'lib/aws-sdk-lambda/types.rb', line 928

class CodeArtifactUserDeletedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end