Class: Aws::Lambda::Types::CodeVerificationFailedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::CodeVerificationFailedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The code signature failed one or more of the validation checks for signature mismatch or expiry, and the code signing policy is set to ENFORCE. Lambda blocks the deployment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
1150 1151 1152 1153 1154 1155 |
# File 'lib/aws-sdk-lambda/types.rb', line 1150 class CodeVerificationFailedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
1150 1151 1152 1153 1154 1155 |
# File 'lib/aws-sdk-lambda/types.rb', line 1150 class CodeVerificationFailedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |