Class: Aws::Lambda::Types::CreateAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::CreateAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the alias.
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#function_version ⇒ String
The function version that the alias invokes.
-
#name ⇒ String
The name of the alias.
-
#routing_config ⇒ Types::AliasRoutingConfiguration
The [routing configuration][1] of the alias.
Instance Attribute Details
#description ⇒ String
A description of the alias.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-lambda/types.rb', line 1348 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-lambda/types.rb', line 1348 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#function_version ⇒ String
The function version that the alias invokes.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-lambda/types.rb', line 1348 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the alias.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-lambda/types.rb', line 1348 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#routing_config ⇒ Types::AliasRoutingConfiguration
The routing configuration of the alias.
1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/aws-sdk-lambda/types.rb', line 1348 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |