Class: Aws::Lambda::Types::CreateFunctionUrlConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::CreateFunctionUrlConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_type ⇒ String
The type of authentication that your function URL uses.
-
#cors ⇒ Types::Cors
The [cross-origin resource sharing (CORS)] settings for your function URL.
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#invoke_mode ⇒ String
Use one of the following options:.
-
#qualifier ⇒ String
The alias name.
Instance Attribute Details
#auth_type ⇒ String
The type of authentication that your function URL uses. Set to ‘AWS_IAM` if you want to restrict access to authenticated users only. Set to `NONE` if you want to bypass IAM authentication to create a public endpoint. For more information, see [Control access to Lambda function URLs].
1484 1485 1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-lambda/types.rb', line 1484 class CreateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors, :invoke_mode) SENSITIVE = [] include Aws::Structure end |
#cors ⇒ Types::Cors
The [cross-origin resource sharing (CORS)] settings for your function URL.
1484 1485 1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-lambda/types.rb', line 1484 class CreateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors, :invoke_mode) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function.
**Name formats**
-
**Function name** – ‘my-function`.
-
**Function ARN** –‘arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – ‘123456789012:function:my-function`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
1484 1485 1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-lambda/types.rb', line 1484 class CreateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors, :invoke_mode) SENSITIVE = [] include Aws::Structure end |
#invoke_mode ⇒ String
Use one of the following options:
-
‘BUFFERED` – This is the default option. Lambda invokes your function using the `Invoke` API operation. Invocation results are available when the payload is complete. The maximum payload size is 6 MB.
-
‘RESPONSE_STREAM` – Your function streams payload results as they become available. Lambda invokes your function using the `InvokeWithResponseStream` API operation. The maximum response payload size is 200 MB.
1484 1485 1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-lambda/types.rb', line 1484 class CreateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors, :invoke_mode) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
The alias name.
1484 1485 1486 1487 1488 1489 1490 1491 1492 |
# File 'lib/aws-sdk-lambda/types.rb', line 1484 class CreateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors, :invoke_mode) SENSITIVE = [] include Aws::Structure end |