Class: Aws::Lambda::Types::DeleteAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::DeleteAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#name ⇒ String
The name of the alias.
Instance Attribute Details
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
2151 2152 2153 2154 2155 2156 |
# File 'lib/aws-sdk-lambda/types.rb', line 2151 class DeleteAliasRequest < Struct.new( :function_name, :name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the alias.
2151 2152 2153 2154 2155 2156 |
# File 'lib/aws-sdk-lambda/types.rb', line 2151 class DeleteAliasRequest < Struct.new( :function_name, :name) SENSITIVE = [] include Aws::Structure end |