Class: Aws::Lambda::Types::DeleteFunctionCodeSigningConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::DeleteFunctionCodeSigningConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name or ARN of the Lambda function.
Instance Attribute Details
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
2128 2129 2130 2131 2132 |
# File 'lib/aws-sdk-lambda/types.rb', line 2128 class DeleteFunctionCodeSigningConfigRequest < Struct.new( :function_name) SENSITIVE = [] include Aws::Structure end |