Class: Aws::Lambda::Types::DeleteFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::DeleteFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Note:
When making an API call, you may pass DeleteFunctionRequest data as a hash:
{
function_name: "FunctionName", # required
qualifier: "Qualifier",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name of the Lambda function or version.
-
#qualifier ⇒ String
Specify a version to delete.
Instance Attribute Details
#function_name ⇒ String
The name of the Lambda function or version.
**Name formats**
-
**Function name** - `my-function` (name-only), `my-function:1` (with version).
-
**Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** - `123456789012:function:my-function`.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-lambda/types.rb', line 1609 class DeleteFunctionRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
Specify a version to delete. You can't delete a version that's referenced by an alias.
1609 1610 1611 1612 1613 1614 |
# File 'lib/aws-sdk-lambda/types.rb', line 1609 class DeleteFunctionRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |