Class: Aws::Lambda::Types::DeleteFunctionUrlConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Note:

When making an API call, you may pass DeleteFunctionUrlConfigRequest data as a hash:

{
  function_name: "FunctionName", # required
  qualifier: "FunctionUrlQualifier",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_nameString

The name of the Lambda function.

**Name formats**

  • **Function name** – `my-function`.

  • **Function ARN** – `arn:aws:lambda:us-west-2:123456789012:function:my-function`.

  • **Partial ARN** – `123456789012:function:my-function`.

The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


1662
1663
1664
1665
1666
1667
# File 'lib/aws-sdk-lambda/types.rb', line 1662

class DeleteFunctionUrlConfigRequest < Struct.new(
  :function_name,
  :qualifier)
  SENSITIVE = []
  include Aws::Structure
end

#qualifierString

The alias name.

Returns:

  • (String)


1662
1663
1664
1665
1666
1667
# File 'lib/aws-sdk-lambda/types.rb', line 1662

class DeleteFunctionUrlConfigRequest < Struct.new(
  :function_name,
  :qualifier)
  SENSITIVE = []
  include Aws::Structure
end