Class: Aws::Lambda::Types::DeleteResourcePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the Lambda resource you want to delete the policy from. You can use a qualified or an unqualified ARN. The value must be a complete ARN, and the operation does not accept wildcard characters.

Returns:

  • (String)


2480
2481
2482
2483
2484
2485
# File 'lib/aws-sdk-lambda/types.rb', line 2480

class DeleteResourcePolicyRequest < Struct.new(
  :resource_arn,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

The revision ID that the existing policy must match for the deletion to proceed. If the revision ID doesn't match, the operation fails with a PreconditionFailedException error. To retrieve the current revision ID, use the GetResourcePolicy operation.

Returns:

  • (String)


2480
2481
2482
2483
2484
2485
# File 'lib/aws-sdk-lambda/types.rb', line 2480

class DeleteResourcePolicyRequest < Struct.new(
  :resource_arn,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end