Class: Aws::Lambda::Types::ENINotReadyException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Lambda couldn’t invoke the Lambda function because the elastic network interface (ENI) configured for its VPC connection isn’t ready yet. Wait a few moments and try the request again. For more information about VPC configuration, see [Configuring a Lambda function to access resources in a VPC].

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The exception message.

Returns:

  • (String)


2687
2688
2689
2690
2691
2692
# File 'lib/aws-sdk-lambda/types.rb', line 2687

class ENINotReadyException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The exception type.

Returns:

  • (String)


2687
2688
2689
2690
2691
2692
# File 'lib/aws-sdk-lambda/types.rb', line 2687

class ENINotReadyException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end