Class: Aws::Lambda::Types::EventError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::EventError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Error information for an event.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#payload ⇒ Types::ErrorObject
The error payload.
-
#truncated ⇒ Boolean
Indicates if the error payload was truncated due to size limits.
Instance Attribute Details
#payload ⇒ Types::ErrorObject
The error payload.
2866 2867 2868 2869 2870 2871 |
# File 'lib/aws-sdk-lambda/types.rb', line 2866 class EventError < Struct.new( :payload, :truncated) SENSITIVE = [] include Aws::Structure end |
#truncated ⇒ Boolean
Indicates if the error payload was truncated due to size limits.
2866 2867 2868 2869 2870 2871 |
# File 'lib/aws-sdk-lambda/types.rb', line 2866 class EventError < Struct.new( :payload, :truncated) SENSITIVE = [] include Aws::Structure end |