Class: Aws::Lambda::Types::EventResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::EventResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Result information for an event.
Constant Summary collapse
- SENSITIVE =
[:payload]
Instance Attribute Summary collapse
-
#payload ⇒ String
The result payload.
-
#truncated ⇒ Boolean
Indicates if the error payload was truncated due to size limits.
Instance Attribute Details
#payload ⇒ String
The result payload.
3032 3033 3034 3035 3036 3037 |
# File 'lib/aws-sdk-lambda/types.rb', line 3032 class EventResult < Struct.new( :payload, :truncated) SENSITIVE = [:payload] include Aws::Structure end |
#truncated ⇒ Boolean
Indicates if the error payload was truncated due to size limits.
3032 3033 3034 3035 3036 3037 |
# File 'lib/aws-sdk-lambda/types.rb', line 3032 class EventResult < Struct.new( :payload, :truncated) SENSITIVE = [:payload] include Aws::Structure end |