Class: Aws::Lambda::Types::EventSourceMappingLoggingConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

(Amazon MSK, and self-managed Apache Kafka only) The logging configuration for your event source. Use this configuration object to define the level of logs for your event source mapping.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#system_log_levelString

The log level you want your event source mapping to use. Lambda event poller only sends system logs at the selected level of detail and lower, where ‘DEBUG` is the highest level and `WARN` is the lowest. For more information about these metrics, see [ Event source mapping logging].

[1]: docs.aws.amazon.com/lambda/latest/dg/esm-logging.html

Returns:

  • (String)


3205
3206
3207
3208
3209
# File 'lib/aws-sdk-lambda/types.rb', line 3205

class EventSourceMappingLoggingConfig < Struct.new(
  :system_log_level)
  SENSITIVE = []
  include Aws::Structure
end