Class: Aws::Lambda::Types::Execution
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::Execution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Information about a durable execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.
-
#durable_execution_name ⇒ String
The unique name of the durable execution, if one was provided when the execution was started.
-
#end_timestamp ⇒ Time
The date and time when the durable execution ended, in [ISO-8601 format][1] (YYYY-MM-DDThh:mm:ss.sTZD).
-
#function_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function.
-
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that is used to encrypt your durable execution's payload data, including input, output, and error payloads.
-
#start_timestamp ⇒ Time
The date and time when the durable execution started, in [ISO-8601 format][1] (YYYY-MM-DDThh:mm:ss.sTZD).
-
#status ⇒ String
The current status of the durable execution.
Instance Attribute Details
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.
3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-lambda/types.rb', line 3512 class Execution < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :status, :start_timestamp, :end_timestamp, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#durable_execution_name ⇒ String
The unique name of the durable execution, if one was provided when the execution was started.
3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-lambda/types.rb', line 3512 class Execution < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :status, :start_timestamp, :end_timestamp, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#end_timestamp ⇒ Time
The date and time when the durable execution ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-lambda/types.rb', line 3512 class Execution < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :status, :start_timestamp, :end_timestamp, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#function_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function.
3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-lambda/types.rb', line 3512 class Execution < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :status, :start_timestamp, :end_timestamp, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that is used to encrypt your durable execution's payload data, including input, output, and error payloads.
3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-lambda/types.rb', line 3512 class Execution < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :status, :start_timestamp, :end_timestamp, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#start_timestamp ⇒ Time
The date and time when the durable execution started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).
3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-lambda/types.rb', line 3512 class Execution < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :status, :start_timestamp, :end_timestamp, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the durable execution.
3512 3513 3514 3515 3516 3517 3518 3519 3520 3521 3522 |
# File 'lib/aws-sdk-lambda/types.rb', line 3512 class Execution < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :status, :start_timestamp, :end_timestamp, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |