Class: Aws::Lambda::Types::FileSystemConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Details about the connection between a Lambda function and an Amazon EFS file system or an Amazon S3 Files file system.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the Amazon EFS or Amazon S3 Files access point that provides access to the file system.

Returns:

  • (String)


3430
3431
3432
3433
3434
3435
# File 'lib/aws-sdk-lambda/types.rb', line 3430

class FileSystemConfig < Struct.new(
  :arn,
  :local_mount_path)
  SENSITIVE = []
  include Aws::Structure
end

#local_mount_pathString

The path where the function can access the file system, starting with /mnt/.

Returns:

  • (String)


3430
3431
3432
3433
3434
3435
# File 'lib/aws-sdk-lambda/types.rb', line 3430

class FileSystemConfig < Struct.new(
  :arn,
  :local_mount_path)
  SENSITIVE = []
  include Aws::Structure
end