Class: Aws::Lambda::Types::FunctionCode
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::FunctionCode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The code for the Lambda function. You can either specify an object in Amazon S3, upload a .zip file archive deployment package directly, or specify the URI of a container image.
Constant Summary collapse
- SENSITIVE =
[:zip_file]
Instance Attribute Summary collapse
-
#image_uri ⇒ String
URI of a [container image][1] in the Amazon ECR registry.
-
#s3_bucket ⇒ String
An Amazon S3 bucket in the same Amazon Web Services Region as your function.
-
#s3_key ⇒ String
The Amazon S3 key of the deployment package.
-
#s3_object_storage_mode ⇒ String
Specifies how the deployment package is stored.
-
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
-
#source_kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package.
-
#zip_file ⇒ String
The base64-encoded contents of the deployment package.
Instance Attribute Details
#image_uri ⇒ String
URI of a container image in the Amazon ECR registry.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 |
# File 'lib/aws-sdk-lambda/types.rb', line 3744 class FunctionCode < Struct.new( :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_bucket ⇒ String
An Amazon S3 bucket in the same Amazon Web Services Region as your function. The bucket can be in a different Amazon Web Services account.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 |
# File 'lib/aws-sdk-lambda/types.rb', line 3744 class FunctionCode < Struct.new( :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_key ⇒ String
The Amazon S3 key of the deployment package.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 |
# File 'lib/aws-sdk-lambda/types.rb', line 3744 class FunctionCode < Struct.new( :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_storage_mode ⇒ String
Specifies how the deployment package is stored. Use COPY (default)
to upload a copy of your deployment package to Lambda. Use
REFERENCE to have Lambda reference the deployment package from the
specified Amazon S3 bucket.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 |
# File 'lib/aws-sdk-lambda/types.rb', line 3744 class FunctionCode < Struct.new( :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 |
# File 'lib/aws-sdk-lambda/types.rb', line 3744 class FunctionCode < Struct.new( :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#source_kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an Amazon Web Services owned key.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 |
# File 'lib/aws-sdk-lambda/types.rb', line 3744 class FunctionCode < Struct.new( :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#zip_file ⇒ String
The base64-encoded contents of the deployment package. Amazon Web Services SDK and CLI clients handle the encoding for you.
3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 |
# File 'lib/aws-sdk-lambda/types.rb', line 3744 class FunctionCode < Struct.new( :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |