Class: Aws::Lambda::Types::FunctionCodeLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Details about a function's deployment package.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::FunctionCodeLocationError

An object that contains details about an error related to function deployment package retrieval.



3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-lambda/types.rb', line 3724

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri,
  :resolved_s3_object,
  :source_kms_key_arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#image_uriString

URI of a container image in the Amazon ECR registry.

Returns:

  • (String)


3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-lambda/types.rb', line 3724

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri,
  :resolved_s3_object,
  :source_kms_key_arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

A presigned URL that you can use to download the deployment package.

Returns:

  • (String)


3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-lambda/types.rb', line 3724

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri,
  :resolved_s3_object,
  :source_kms_key_arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#repository_typeString

The service that's hosting the file.

Returns:

  • (String)


3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-lambda/types.rb', line 3724

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri,
  :resolved_s3_object,
  :source_kms_key_arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_image_uriString

The resolved URI for the image.

Returns:

  • (String)


3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-lambda/types.rb', line 3724

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri,
  :resolved_s3_object,
  :source_kms_key_arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_s3_objectTypes::ResolvedS3Object

The resolved Amazon S3 object that contains the deployment package.



3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-lambda/types.rb', line 3724

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri,
  :resolved_s3_object,
  :source_kms_key_arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#source_kms_key_arnString

The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an Amazon Web Services owned key.

Returns:

  • (String)


3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
# File 'lib/aws-sdk-lambda/types.rb', line 3724

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri,
  :resolved_s3_object,
  :source_kms_key_arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end