Class: Aws::Lambda::Types::FunctionCodeLocationError

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Contains details about an error that occurred when Lambda attempted to retrieve a function's deployment package.

Constant Summary collapse

SENSITIVE =
[:message]

Instance Attribute Summary collapse

Instance Attribute Details

#error_codeString

The error code that identifies why Lambda failed to retrieve the deployment package.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
# File 'lib/aws-sdk-lambda/types.rb', line 3826

class FunctionCodeLocationError < Struct.new(
  :error_code,
  :message)
  SENSITIVE = [:message]
  include Aws::Structure
end

#messageString

The human-readable message that describes why Lambda failed to retrieve the deployment package.

Returns:

  • (String)


3826
3827
3828
3829
3830
3831
# File 'lib/aws-sdk-lambda/types.rb', line 3826

class FunctionCodeLocationError < Struct.new(
  :error_code,
  :message)
  SENSITIVE = [:message]
  include Aws::Structure
end