Class: Aws::Lambda::Types::FunctionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Details about a function’s configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architecturesArray<String>

The instruction set architecture that the function supports. Architecture is a string array with one of the valid values. The default architecture value is ‘x86_64`.

Returns:

  • (Array<String>)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_provider_configTypes::CapacityProviderConfig

Configuration for the capacity provider that manages compute resources for Lambda functions.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#code_sha_256String

The SHA256 hash of the function’s deployment package.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#code_sizeInteger

The size of the function’s deployment package, in bytes.

Returns:

  • (Integer)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#config_sha_256String

The SHA256 hash of the function configuration.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#dead_letter_configTypes::DeadLetterConfig

The function’s dead letter queue.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The function’s description.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#durable_configTypes::DurableConfig

The function’s durable execution configuration settings, if the function is configured for durability.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#environmentTypes::EnvironmentResponse

The function’s [environment variables]. Omitted from CloudTrail logs.

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeral_storageTypes::EphemeralStorage

The size of the function’s ‘/tmp` directory in MB. The default value is 512, but can be any whole number between 512 and 10,240 MB. For more information, see [Configuring ephemeral storage (console)].

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-function-common.html#configuration-ephemeral-storage



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_configsArray<Types::FileSystemConfig>

Connection settings for an [Amazon EFS file system] or an [Amazon S3 Files file system].

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-filesystem.html

Returns:



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_arnString

The function’s Amazon Resource Name (ARN).

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the function.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#handlerString

The function that Lambda calls to begin running your function.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#image_config_responseTypes::ImageConfigResponse

The function’s image configuration values.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The ARN of the Key Management Service (KMS) customer managed key that’s used to encrypt the following resources:

  • The function’s [environment variables].

  • The function’s [Lambda SnapStart] snapshots.

  • When used with ‘SourceKMSKeyArn`, the unzipped version of the .zip deployment package that’s used for function invocations. For more information, see [ Specifying a customer managed key for Lambda].

  • The optimized version of the container image that’s used for function invocations. Note that this is not the same key that’s used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see [Function lifecycle].

If you don’t provide a customer managed key, Lambda uses an [Amazon Web Services owned key] or an [Amazon Web Services managed key].

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html#configuration-envvars-encryption [2]: docs.aws.amazon.com/lambda/latest/dg/snapstart-security.html [3]: docs.aws.amazon.com/lambda/latest/dg/encrypt-zip-package.html#enable-zip-custom-encryption [4]: docs.aws.amazon.com/lambda/latest/dg/images-create.html#images-lifecycle [5]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk [6]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The date and time that the function was last updated, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).

[1]: www.w3.org/TR/NOTE-datetime

Returns:

  • (Time)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_statusString

The status of the last update that was performed on the function. This is first set to ‘Successful` after function creation completes.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_status_reasonString

The reason for the last update that was performed on the function.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_status_reason_codeString

The reason code for the last update that was performed on the function.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#layersArray<Types::Layer>

Returns:



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configTypes::LoggingConfig

The function’s Amazon CloudWatch Logs configuration settings.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#master_arnString

For Lambda@Edge functions, the ARN of the main function.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#memory_sizeInteger

The amount of memory available to the function at runtime.

Returns:

  • (Integer)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#package_typeString

The type of deployment package. Set to ‘Image` for container image and set `Zip` for .zip file archive.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

The latest updated revision of the function or alias.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The function’s execution role.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

The identifier of the function’s [ runtime]. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you’re deploying a function using a container image.

The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see [Runtime use after deprecation].

For a list of all currently supported runtimes, see [Supported runtimes].

[1]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html [2]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtime-deprecation-levels [3]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtimes-supported

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_version_configTypes::RuntimeVersionConfig

The ARN of the runtime and any errors that occured.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#signing_job_arnString

The ARN of the signing job.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#signing_profile_version_arnString

The ARN of the signing profile version.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#snap_startTypes::SnapStartResponse

Set ‘ApplyOn` to `PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version. For more information, see [Improving startup performance with Lambda SnapStart].

[1]: docs.aws.amazon.com/lambda/latest/dg/snapstart.html



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the function. When the state is ‘Inactive`, you can reactivate the function by invoking it.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

The reason for the function’s current state.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#state_reason_codeString

The reason code for the function’s current state. When the code is ‘Creating`, you can’t invoke or modify the function.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#tenancy_configTypes::TenancyConfig

The function’s tenant isolation configuration settings. Determines whether the Lambda function runs on a shared or dedicated infrastructure per unique tenant.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The amount of time in seconds that Lambda allows a function to run before stopping it.

Returns:

  • (Integer)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#tracing_configTypes::TracingConfigResponse

The function’s X-Ray tracing configuration.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the Lambda function.

Returns:

  • (String)


3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfigResponse

The function’s networking configuration.



3972
3973
3974
3975
3976
3977
3978
3979
3980
3981
3982
3983
3984
3985
3986
3987
3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
# File 'lib/aws-sdk-lambda/types.rb', line 3972

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :signing_profile_version_arn,
  :signing_job_arn,
  :package_type,
  :image_config_response,
  :architectures,
  :ephemeral_storage,
  :snap_start,
  :runtime_version_config,
  :logging_config,
  :tenancy_config,
  :capacity_provider_config,
  :config_sha_256,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end