Class: Aws::Lambda::Types::GetDurableExecutionHistoryRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durable_execution_arnString

The Amazon Resource Name (ARN) of the durable execution.

Returns:

  • (String)


4403
4404
4405
4406
4407
4408
4409
4410
4411
# File 'lib/aws-sdk-lambda/types.rb', line 4403

class GetDurableExecutionHistoryRequest < Struct.new(
  :durable_execution_arn,
  :include_execution_data,
  :max_items,
  :marker,
  :reverse_order)
  SENSITIVE = []
  include Aws::Structure
end

#include_execution_dataBoolean

Specifies whether to include execution data such as step results and callback payloads in the history events. Set to true to include data, or false to exclude it for a more compact response. The default is true.

Returns:

  • (Boolean)


4403
4404
4405
4406
4407
4408
4409
4410
4411
# File 'lib/aws-sdk-lambda/types.rb', line 4403

class GetDurableExecutionHistoryRequest < Struct.new(
  :durable_execution_arn,
  :include_execution_data,
  :max_items,
  :marker,
  :reverse_order)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

If NextMarker was returned from a previous request, use this value to retrieve the next page of results. Each pagination token expires after 24 hours.

Returns:

  • (String)


4403
4404
4405
4406
4407
4408
4409
4410
4411
# File 'lib/aws-sdk-lambda/types.rb', line 4403

class GetDurableExecutionHistoryRequest < Struct.new(
  :durable_execution_arn,
  :include_execution_data,
  :max_items,
  :marker,
  :reverse_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The maximum number of history events to return per call. You can use Marker to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.

Returns:

  • (Integer)


4403
4404
4405
4406
4407
4408
4409
4410
4411
# File 'lib/aws-sdk-lambda/types.rb', line 4403

class GetDurableExecutionHistoryRequest < Struct.new(
  :durable_execution_arn,
  :include_execution_data,
  :max_items,
  :marker,
  :reverse_order)
  SENSITIVE = []
  include Aws::Structure
end

#reverse_orderBoolean

When set to true, returns the history events in reverse chronological order (newest first). By default, events are returned in chronological order (oldest first).

Returns:

  • (Boolean)


4403
4404
4405
4406
4407
4408
4409
4410
4411
# File 'lib/aws-sdk-lambda/types.rb', line 4403

class GetDurableExecutionHistoryRequest < Struct.new(
  :durable_execution_arn,
  :include_execution_data,
  :max_items,
  :marker,
  :reverse_order)
  SENSITIVE = []
  include Aws::Structure
end