Class: Aws::Lambda::Types::GetDurableExecutionHistoryResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetDurableExecutionHistoryResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The response from the GetDurableExecutionHistory operation, containing the execution history and events.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::Event>
An array of execution history events, ordered chronologically unless ‘ReverseOrder` is set to `true`.
-
#next_marker ⇒ String
If present, indicates that more history events are available.
Instance Attribute Details
#events ⇒ Array<Types::Event>
An array of execution history events, ordered chronologically unless ‘ReverseOrder` is set to `true`. Each event represents a significant occurrence during the execution, such as step completion or callback resolution.
4247 4248 4249 4250 4251 4252 |
# File 'lib/aws-sdk-lambda/types.rb', line 4247 class GetDurableExecutionHistoryResponse < Struct.new( :events, :next_marker) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If present, indicates that more history events are available. Use this value as the ‘Marker` parameter in a subsequent request to retrieve the next page of results.
4247 4248 4249 4250 4251 4252 |
# File 'lib/aws-sdk-lambda/types.rb', line 4247 class GetDurableExecutionHistoryResponse < Struct.new( :events, :next_marker) SENSITIVE = [] include Aws::Structure end |