Class: Aws::Lambda::Types::GetDurableExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durable_execution_arnString

The Amazon Resource Name (ARN) of the durable execution.

Returns:

  • (String)


4451
4452
4453
4454
4455
4456
# File 'lib/aws-sdk-lambda/types.rb', line 4451

class GetDurableExecutionRequest < Struct.new(
  :durable_execution_arn,
  :include_execution_data)
  SENSITIVE = []
  include Aws::Structure
end

#include_execution_dataBoolean

Specifies whether to include execution data such as input payload, result, and error information in the response. Set to false for a more compact response that includes only execution metadata. The default value is set to true.

Returns:

  • (Boolean)


4451
4452
4453
4454
4455
4456
# File 'lib/aws-sdk-lambda/types.rb', line 4451

class GetDurableExecutionRequest < Struct.new(
  :durable_execution_arn,
  :include_execution_data)
  SENSITIVE = []
  include Aws::Structure
end