Class: Aws::Lambda::Types::GetDurableExecutionStateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The response from the GetDurableExecutionState operation, containing the current execution state for replay.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_markerString

If present, indicates that more operations are available. Use this value as the ‘Marker` parameter in a subsequent request to retrieve the next page of results.

Returns:

  • (String)


4412
4413
4414
4415
4416
4417
# File 'lib/aws-sdk-lambda/types.rb', line 4412

class GetDurableExecutionStateResponse < Struct.new(
  :operations,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end

#operationsArray<Types::Operation>

An array of operations that represent the current state of the durable execution. Operations are ordered by their start sequence number in ascending order and include information needed for replay processing.

Returns:



4412
4413
4414
4415
4416
4417
# File 'lib/aws-sdk-lambda/types.rb', line 4412

class GetDurableExecutionStateResponse < Struct.new(
  :operations,
  :next_marker)
  SENSITIVE = []
  include Aws::Structure
end