Class: Aws::Lambda::Types::GetFunctionCodeSigningConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_nameString

The name or ARN of the Lambda function.

**Name formats**

  • **Function name** - MyFunction.

  • **Function ARN** - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

  • **Partial ARN** - 123456789012:function:MyFunction.

The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


2845
2846
2847
2848
2849
# File 'lib/aws-sdk-lambda/types.rb', line 2845

class GetFunctionCodeSigningConfigRequest < Struct.new(
  :function_name)
  SENSITIVE = []
  include Aws::Structure
end