Class: Aws::Lambda::Types::GetFunctionConcurrencyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetFunctionConcurrencyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name or ARN of the Lambda function.
Instance Attribute Details
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
4658 4659 4660 4661 4662 |
# File 'lib/aws-sdk-lambda/types.rb', line 4658 class GetFunctionConcurrencyRequest < Struct.new( :function_name) SENSITIVE = [] include Aws::Structure end |