Class: Aws::Lambda::Types::GetFunctionConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_nameString

The name or ARN of the Lambda function, version, or alias.

Name formats

  • Function namemy-function (name-only), my-function:v1 (with alias).

  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

  • Partial ARN123456789012:function:my-function.

You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
# File 'lib/aws-sdk-lambda/types.rb', line 4535

class GetFunctionConfigurationRequest < Struct.new(
  :function_name,
  :qualifier)
  SENSITIVE = []
  include Aws::Structure
end

#qualifierString

Specify a version or alias to get details about a published version of the function.

Returns:

  • (String)


4535
4536
4537
4538
4539
4540
# File 'lib/aws-sdk-lambda/types.rb', line 4535

class GetFunctionConfigurationRequest < Struct.new(
  :function_name,
  :qualifier)
  SENSITIVE = []
  include Aws::Structure
end