Class: Aws::Lambda::Types::GetFunctionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetFunctionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name of the Lambda function, version, or alias.
-
#qualifier ⇒ String
Specify a version or alias to get details about a published version of the function.
Instance Attribute Details
#function_name ⇒ String
The name of the Lambda function, version, or alias.
**Name formats**
-
**Function name** – ‘my-function` (name-only), `my-function:v1` (with alias).
-
**Function ARN** – ‘arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – ‘123456789012:function:my-function`.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-lambda/types.rb', line 2754 class GetFunctionRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
Specify a version or alias to get details about a published version of the function.
2754 2755 2756 2757 2758 2759 |
# File 'lib/aws-sdk-lambda/types.rb', line 2754 class GetFunctionRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |