Class: Aws::Lambda::Types::GetFunctionScalingConfigResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#applied_function_scaling_configTypes::FunctionScalingConfig

The scaling configuration that is currently applied to the function. This represents the actual scaling settings in effect.



4728
4729
4730
4731
4732
4733
4734
# File 'lib/aws-sdk-lambda/types.rb', line 4728

class GetFunctionScalingConfigResponse < Struct.new(
  :function_arn,
  :applied_function_scaling_config,
  :requested_function_scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_arnString

The Amazon Resource Name (ARN) of the function.

Returns:

  • (String)


4728
4729
4730
4731
4732
4733
4734
# File 'lib/aws-sdk-lambda/types.rb', line 4728

class GetFunctionScalingConfigResponse < Struct.new(
  :function_arn,
  :applied_function_scaling_config,
  :requested_function_scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#requested_function_scaling_configTypes::FunctionScalingConfig

The scaling configuration that was requested for the function.



4728
4729
4730
4731
4732
4733
4734
# File 'lib/aws-sdk-lambda/types.rb', line 4728

class GetFunctionScalingConfigResponse < Struct.new(
  :function_arn,
  :applied_function_scaling_config,
  :requested_function_scaling_config)
  SENSITIVE = []
  include Aws::Structure
end