Class: Aws::Lambda::Types::GetLayerVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetLayerVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#compatible_architectures ⇒ Array<String>
A list of compatible [instruction set architectures].
-
#compatible_runtimes ⇒ Array<String>
The layer’s compatible runtimes.
-
#content ⇒ Types::LayerVersionContentOutput
Details about the layer version.
-
#created_date ⇒ Time
The date that the layer version was created, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).
-
#description ⇒ String
The description of the version.
-
#layer_arn ⇒ String
The ARN of the layer.
-
#layer_version_arn ⇒ String
The ARN of the layer version.
-
#license_info ⇒ String
The layer’s software license.
-
#version ⇒ Integer
The version number.
Instance Attribute Details
#compatible_architectures ⇒ Array<String>
A list of compatible [instruction set architectures].
[1]: docs.aws.amazon.com/lambda/latest/dg/foundation-arch.html
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#compatible_runtimes ⇒ Array<String>
The layer’s compatible runtimes.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#content ⇒ Types::LayerVersionContentOutput
Details about the layer version.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date that the layer version was created, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the version.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#layer_arn ⇒ String
The ARN of the layer.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#layer_version_arn ⇒ String
The ARN of the layer version.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#license_info ⇒ String
The layer’s software license.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version number.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-lambda/types.rb', line 3007 class GetLayerVersionResponse < Struct.new( :content, :layer_arn, :layer_version_arn, :description, :created_date, :version, :compatible_runtimes, :license_info, :compatible_architectures) SENSITIVE = [] include Aws::Structure end |