Class: Aws::Lambda::Types::GetPolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetPolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The resource-based policy.
-
#revision_id ⇒ String
A unique identifier for the current revision of the policy.
Instance Attribute Details
#policy ⇒ String
The resource-based policy.
2895 2896 2897 2898 2899 2900 |
# File 'lib/aws-sdk-lambda/types.rb', line 2895 class GetPolicyResponse < Struct.new( :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
A unique identifier for the current revision of the policy.
2895 2896 2897 2898 2899 2900 |
# File 'lib/aws-sdk-lambda/types.rb', line 2895 class GetPolicyResponse < Struct.new( :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |