Class: Aws::Lambda::Types::GetResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the function you want to retrieve the policy for.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the function you want to retrieve the policy for. You can use either a qualified or an unqualified ARN, but the value you specify must be a complete ARN and wildcard characters are not accepted.
3374 3375 3376 3377 3378 |
# File 'lib/aws-sdk-lambda/types.rb', line 3374 class GetResourcePolicyRequest < Struct.new( :resource_arn) SENSITIVE = [] include Aws::Structure end |