Class: Aws::Lambda::Types::GetResourcePolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policyString

The resource-based policy attached to the Lambda resource you specified.

Returns:

  • (String)


5405
5406
5407
5408
5409
5410
# File 'lib/aws-sdk-lambda/types.rb', line 5405

class GetResourcePolicyResponse < Struct.new(
  :policy,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

The revision ID of the policy. Pass this value as the RevisionId in a PutResourcePolicy or DeleteResourcePolicy request. Doing so ensures the operation acts on the expected version of the policy.

Returns:

  • (String)


5405
5406
5407
5408
5409
5410
# File 'lib/aws-sdk-lambda/types.rb', line 5405

class GetResourcePolicyResponse < Struct.new(
  :policy,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end