Class: Aws::Lambda::Types::GetRuntimeManagementConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetRuntimeManagementConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name of the Lambda function.
-
#qualifier ⇒ String
Specify a version of the function.
Instance Attribute Details
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** – `my-function`.
-
**Function ARN** – `arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – `123456789012:function:my-function`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-lambda/types.rb', line 3006 class GetRuntimeManagementConfigRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
Specify a version of the function. This can be `$LATEST` or a published version number. If no value is specified, the configuration for the `$LATEST` version is returned.
3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-lambda/types.rb', line 3006 class GetRuntimeManagementConfigRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |