Class: Aws::Lambda::Types::GetRuntimeManagementConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetRuntimeManagementConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_arn ⇒ String
The Amazon Resource Name (ARN) of your function.
-
#runtime_version_arn ⇒ String
The ARN of the runtime the function is configured to use.
-
#update_runtime_on ⇒ String
The current runtime update mode of the function.
Instance Attribute Details
#function_arn ⇒ String
The Amazon Resource Name (ARN) of your function.
5341 5342 5343 5344 5345 5346 5347 |
# File 'lib/aws-sdk-lambda/types.rb', line 5341 class GetRuntimeManagementConfigResponse < Struct.new( :update_runtime_on, :function_arn, :runtime_version_arn) SENSITIVE = [] include Aws::Structure end |
#runtime_version_arn ⇒ String
The ARN of the runtime the function is configured to use. If the
runtime update mode is Manual, the ARN is returned, otherwise
null is returned.
5341 5342 5343 5344 5345 5346 5347 |
# File 'lib/aws-sdk-lambda/types.rb', line 5341 class GetRuntimeManagementConfigResponse < Struct.new( :update_runtime_on, :function_arn, :runtime_version_arn) SENSITIVE = [] include Aws::Structure end |
#update_runtime_on ⇒ String
The current runtime update mode of the function.
5341 5342 5343 5344 5345 5346 5347 |
# File 'lib/aws-sdk-lambda/types.rb', line 5341 class GetRuntimeManagementConfigResponse < Struct.new( :update_runtime_on, :function_arn, :runtime_version_arn) SENSITIVE = [] include Aws::Structure end |