Class: Aws::Lambda::Types::InvocationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::InvocationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:payload]
Instance Attribute Summary collapse
-
#client_context ⇒ String
Up to 3,583 bytes of base64-encoded data about the invoking client to pass to the function in the context object.
-
#durable_execution_name ⇒ String
A unique name for the durable execution.
-
#function_name ⇒ String
The name or ARN of the Lambda function, version, or alias.
-
#invocation_type ⇒ String
Choose from the following options.
-
#log_type ⇒ String
Set to
Tailto include the execution log in the response. -
#payload ⇒ String
The JSON that you want to provide to your Lambda function as input.
-
#qualifier ⇒ String
Specify a version or alias to invoke a published version of the function.
-
#tenant_id ⇒ String
The identifier of the tenant in a multi-tenant Lambda function.
Instance Attribute Details
#client_context ⇒ String
Up to 3,583 bytes of base64-encoded data about the invoking client
to pass to the function in the context object. Lambda passes the
ClientContext object to your function for synchronous invocations
only.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#durable_execution_name ⇒ String
A unique name for the durable execution. If you invoke a durable
function using a name that already exists with the same payload,
Lambda returns the existing execution instead of creating a
duplicate. If the payload differs, Lambda returns a
DurableExecutionAlreadyStartedException error.
If not specified, Lambda generates a unique identifier automatically. For more information, see Execution names.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name –
my-function(name-only),my-function:v1(with alias). -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#invocation_type ⇒ String
Choose from the following options.
-
RequestResponse(default) – Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API response includes the function response and additional data. -
Event– Invoke the function asynchronously. Send events that fail multiple times to the function's dead-letter queue (if one is configured). The API response only includes a status code. -
DryRun– Validate parameter values and verify that the user or role has permission to invoke the function.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#log_type ⇒ String
Set to Tail to include the execution log in the response. Applies
to synchronously invoked functions only.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#payload ⇒ String
The JSON that you want to provide to your Lambda function as input. The maximum payload size is 6 MB for synchronous invocations and 1 MB for asynchronous invocations.
You can enter the JSON directly. For example, --payload '{ "key": "value" }'. You can also specify a file path. For example,
--payload file://payload.json.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#qualifier ⇒ String
Specify a version or alias to invoke a published version of the function.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#tenant_id ⇒ String
The identifier of the tenant in a multi-tenant Lambda function.
5695 5696 5697 5698 5699 5700 5701 5702 5703 5704 5705 5706 |
# File 'lib/aws-sdk-lambda/types.rb', line 5695 class InvocationRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :durable_execution_name, :payload, :qualifier, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |