Class: Aws::Lambda::Types::InvocationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::InvocationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Upon success, returns an empty response. Otherwise, throws an exception.
Instance Attribute Summary collapse
-
#executed_version ⇒ String
The function version that has been executed.
-
#function_error ⇒ String
Indicates whether an error occurred while executing the Lambda function.
-
#log_result ⇒ String
It is the base64-encoded logs for the Lambda function invocation.
-
#payload ⇒ String
It is the JSON representation of the object returned by the Lambda function.
-
#status_code ⇒ Integer
The HTTP status code will be in the 200 range for successful request.
Instance Attribute Details
#executed_version ⇒ String
The function version that has been executed. This value is returned only if the invocation type is RequestResponse. For more information, see [Traffic Shifting Using Aliases].
[1]: docs.aws.amazon.com/lambda/latest/dg/lambda-traffic-shifting-using-aliases.html
1422 1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-lambda/types.rb', line 1422 class InvocationResponse < Struct.new( :status_code, :function_error, :log_result, :payload, :executed_version) include Aws::Structure end |
#function_error ⇒ String
Indicates whether an error occurred while executing the Lambda function. If an error occurred this field will have one of two values; Handled or Unhandled. Handled errors are errors that are reported by the function while the Unhandled errors are those detected and reported by AWS Lambda. Unhandled errors include out of memory errors and function timeouts. For information about how to report an Handled error, see [Programming Model].
[1]: docs.aws.amazon.com/lambda/latest/dg/programming-model.html
1422 1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-lambda/types.rb', line 1422 class InvocationResponse < Struct.new( :status_code, :function_error, :log_result, :payload, :executed_version) include Aws::Structure end |
#log_result ⇒ String
It is the base64-encoded logs for the Lambda function invocation. This is present only if the invocation type is RequestResponse and the logs were requested.
1422 1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-lambda/types.rb', line 1422 class InvocationResponse < Struct.new( :status_code, :function_error, :log_result, :payload, :executed_version) include Aws::Structure end |
#payload ⇒ String
It is the JSON representation of the object returned by the Lambda function. This is present only if the invocation type is RequestResponse.
In the event of a function error this field contains a message describing the error. For the Handled errors the Lambda function will report this message. For Unhandled errors AWS Lambda reports the message.
1422 1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-lambda/types.rb', line 1422 class InvocationResponse < Struct.new( :status_code, :function_error, :log_result, :payload, :executed_version) include Aws::Structure end |
#status_code ⇒ Integer
The HTTP status code will be in the 200 range for successful request. For the RequestResponse invocation type this status code will be 200. For the Event invocation type this status code will be 202. For the DryRun invocation type the status code will be 204.
1422 1423 1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-lambda/types.rb', line 1422 class InvocationResponse < Struct.new( :status_code, :function_error, :log_result, :payload, :executed_version) include Aws::Structure end |