Class: Aws::Lambda::Types::InvokeAsyncRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::InvokeAsyncRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name of the Lambda function.
-
#invoke_args ⇒ IO
The JSON that you want to provide to your Lambda function as input.
Instance Attribute Details
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** – `my-function`.
-
**Function ARN** – `arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – `123456789012:function:my-function`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-lambda/types.rb', line 3303 class InvokeAsyncRequest < Struct.new( :function_name, :invoke_args) SENSITIVE = [] include Aws::Structure end |
#invoke_args ⇒ IO
The JSON that you want to provide to your Lambda function as input.
3303 3304 3305 3306 3307 3308 |
# File 'lib/aws-sdk-lambda/types.rb', line 3303 class InvokeAsyncRequest < Struct.new( :function_name, :invoke_args) SENSITIVE = [] include Aws::Structure end |