Class: Aws::Lambda::Types::InvokeWithResponseStreamRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::InvokeWithResponseStreamRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:payload]
Instance Attribute Summary collapse
-
#client_context ⇒ String
Up to 3,583 bytes of base64-encoded data about the invoking client to pass to the function in the context object.
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#invocation_type ⇒ String
Use one of the following options:.
-
#log_type ⇒ String
Set to ‘Tail` to include the execution log in the response.
-
#payload ⇒ String
The JSON that you want to provide to your Lambda function as input.
-
#qualifier ⇒ String
The alias name.
-
#tenant_id ⇒ String
The identifier of the tenant in a multi-tenant Lambda function.
Instance Attribute Details
#client_context ⇒ String
Up to 3,583 bytes of base64-encoded data about the invoking client to pass to the function in the context object.
5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 |
# File 'lib/aws-sdk-lambda/types.rb', line 5689 class InvokeWithResponseStreamRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :qualifier, :payload, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function.
**Name formats**
-
**Function name** – ‘my-function`.
-
**Function ARN** –‘arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – ‘123456789012:function:my-function`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 |
# File 'lib/aws-sdk-lambda/types.rb', line 5689 class InvokeWithResponseStreamRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :qualifier, :payload, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#invocation_type ⇒ String
Use one of the following options:
-
‘RequestResponse` (default) – Invoke the function synchronously. Keep the connection open until the function returns a response or times out. The API operation response includes the function response and additional data.
-
‘DryRun` – Validate parameter values and verify that the IAM user or role has permission to invoke the function.
5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 |
# File 'lib/aws-sdk-lambda/types.rb', line 5689 class InvokeWithResponseStreamRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :qualifier, :payload, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#log_type ⇒ String
Set to ‘Tail` to include the execution log in the response. Applies to synchronously invoked functions only.
5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 |
# File 'lib/aws-sdk-lambda/types.rb', line 5689 class InvokeWithResponseStreamRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :qualifier, :payload, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#payload ⇒ String
The JSON that you want to provide to your Lambda function as input.
You can enter the JSON directly. For example, ‘–payload ’{ “key”: “value” }‘`. You can also specify a file path. For example, `–payload file://payload.json`.
5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 |
# File 'lib/aws-sdk-lambda/types.rb', line 5689 class InvokeWithResponseStreamRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :qualifier, :payload, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#qualifier ⇒ String
The alias name.
5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 |
# File 'lib/aws-sdk-lambda/types.rb', line 5689 class InvokeWithResponseStreamRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :qualifier, :payload, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |
#tenant_id ⇒ String
The identifier of the tenant in a multi-tenant Lambda function.
5689 5690 5691 5692 5693 5694 5695 5696 5697 5698 5699 |
# File 'lib/aws-sdk-lambda/types.rb', line 5689 class InvokeWithResponseStreamRequest < Struct.new( :function_name, :invocation_type, :log_type, :client_context, :qualifier, :payload, :tenant_id) SENSITIVE = [:payload] include Aws::Structure end |