Class: Aws::Lambda::Types::KMSInvalidStateException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Lambda was unable to decrypt the environment variables because the KMS key used is in an invalid state for Decrypt. Check the function's KMS key settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3836
3837
3838
3839
3840
3841
# File 'lib/aws-sdk-lambda/types.rb', line 3836

class KMSInvalidStateException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


3836
3837
3838
3839
3840
3841
# File 'lib/aws-sdk-lambda/types.rb', line 3836

class KMSInvalidStateException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end