Class: Aws::Lambda::Types::KafkaSchemaRegistryConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::KafkaSchemaRegistryConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Specific configuration settings for a Kafka schema registry.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_configs ⇒ Array<Types::KafkaSchemaRegistryAccessConfig>
An array of access configuration objects that tell Lambda how to authenticate with your schema registry.
-
#event_record_format ⇒ String
The record format that Lambda delivers to your function after schema validation.
-
#schema_registry_uri ⇒ String
The URI for your schema registry.
-
#schema_validation_configs ⇒ Array<Types::KafkaSchemaValidationConfig>
An array of schema validation configuration objects, which tell Lambda the message attributes you want to validate and filter using your schema registry.
Instance Attribute Details
#access_configs ⇒ Array<Types::KafkaSchemaRegistryAccessConfig>
An array of access configuration objects that tell Lambda how to authenticate with your schema registry.
6027 6028 6029 6030 6031 6032 6033 6034 |
# File 'lib/aws-sdk-lambda/types.rb', line 6027 class KafkaSchemaRegistryConfig < Struct.new( :schema_registry_uri, :event_record_format, :access_configs, :schema_validation_configs) SENSITIVE = [] include Aws::Structure end |
#event_record_format ⇒ String
The record format that Lambda delivers to your function after schema validation.
-
Choose
JSONto have Lambda deliver the record to your function as a standard JSON object. -
Choose
SOURCEto have Lambda deliver the record to your function in its original source format. Lambda removes all schema metadata, such as the schema ID, before sending the record to your function.
6027 6028 6029 6030 6031 6032 6033 6034 |
# File 'lib/aws-sdk-lambda/types.rb', line 6027 class KafkaSchemaRegistryConfig < Struct.new( :schema_registry_uri, :event_record_format, :access_configs, :schema_validation_configs) SENSITIVE = [] include Aws::Structure end |
#schema_registry_uri ⇒ String
The URI for your schema registry. The correct URI format depends on the type of schema registry you're using.
-
For Glue schema registries, use the ARN of the registry.
-
For Confluent schema registries, use the URL of the registry.
6027 6028 6029 6030 6031 6032 6033 6034 |
# File 'lib/aws-sdk-lambda/types.rb', line 6027 class KafkaSchemaRegistryConfig < Struct.new( :schema_registry_uri, :event_record_format, :access_configs, :schema_validation_configs) SENSITIVE = [] include Aws::Structure end |
#schema_validation_configs ⇒ Array<Types::KafkaSchemaValidationConfig>
An array of schema validation configuration objects, which tell Lambda the message attributes you want to validate and filter using your schema registry.
6027 6028 6029 6030 6031 6032 6033 6034 |
# File 'lib/aws-sdk-lambda/types.rb', line 6027 class KafkaSchemaRegistryConfig < Struct.new( :schema_registry_uri, :event_record_format, :access_configs, :schema_validation_configs) SENSITIVE = [] include Aws::Structure end |