Class: Aws::Lambda::Types::KafkaSchemaValidationConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::KafkaSchemaValidationConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Specific schema validation configuration settings that tell Lambda the message attributes you want to validate and filter using your schema registry.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute ⇒ String
The attributes you want your schema registry to validate and filter for.
Instance Attribute Details
#attribute ⇒ String
The attributes you want your schema registry to validate and filter
for. If you selected JSON as the EventRecordFormat, Lambda also
deserializes the selected message attributes.
6228 6229 6230 6231 6232 |
# File 'lib/aws-sdk-lambda/types.rb', line 6228 class KafkaSchemaValidationConfig < Struct.new( :attribute) SENSITIVE = [] include Aws::Structure end |