Class: Aws::Lambda::Types::LayerVersionContentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::LayerVersionContentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
A ZIP archive that contains the contents of an Lambda layer. You can specify either an Amazon S3 location, or upload a layer archive directly.
Constant Summary collapse
- SENSITIVE =
[:zip_file]
Instance Attribute Summary collapse
-
#s3_bucket ⇒ String
The Amazon S3 bucket of the layer archive.
-
#s3_key ⇒ String
The Amazon S3 key of the layer archive.
-
#s3_object_storage_mode ⇒ String
The storage mode for a function's deployment package.
-
#s3_object_version ⇒ String
For versioned objects, the version of the layer archive object to use.
-
#zip_file ⇒ String
The base64-encoded contents of the layer archive.
Instance Attribute Details
#s3_bucket ⇒ String
The Amazon S3 bucket of the layer archive.
6147 6148 6149 6150 6151 6152 6153 6154 6155 |
# File 'lib/aws-sdk-lambda/types.rb', line 6147 class LayerVersionContentInput < Struct.new( :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :zip_file) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_key ⇒ String
The Amazon S3 key of the layer archive.
6147 6148 6149 6150 6151 6152 6153 6154 6155 |
# File 'lib/aws-sdk-lambda/types.rb', line 6147 class LayerVersionContentInput < Struct.new( :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :zip_file) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_storage_mode ⇒ String
The storage mode for a function's deployment package.
6147 6148 6149 6150 6151 6152 6153 6154 6155 |
# File 'lib/aws-sdk-lambda/types.rb', line 6147 class LayerVersionContentInput < Struct.new( :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :zip_file) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_version ⇒ String
For versioned objects, the version of the layer archive object to use.
6147 6148 6149 6150 6151 6152 6153 6154 6155 |
# File 'lib/aws-sdk-lambda/types.rb', line 6147 class LayerVersionContentInput < Struct.new( :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :zip_file) SENSITIVE = [:zip_file] include Aws::Structure end |
#zip_file ⇒ String
The base64-encoded contents of the layer archive. Amazon Web Services SDK and Amazon Web Services CLI clients handle the encoding for you.
6147 6148 6149 6150 6151 6152 6153 6154 6155 |
# File 'lib/aws-sdk-lambda/types.rb', line 6147 class LayerVersionContentInput < Struct.new( :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :zip_file) SENSITIVE = [:zip_file] include Aws::Structure end |