Class: Aws::Lambda::Types::LayerVersionContentOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::LayerVersionContentOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Details about a version of an Lambda layer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_sha_256 ⇒ String
The SHA-256 hash of the layer archive.
-
#code_size ⇒ Integer
The size of the layer archive in bytes.
-
#location ⇒ String
A link to the layer archive in Amazon S3 that is valid for 10 minutes.
-
#resolved_s3_object ⇒ Types::ResolvedS3Object
Details about the resolved Amazon S3 object that contains a function's deployment package.
-
#signing_job_arn ⇒ String
The Amazon Resource Name (ARN) of a signing job.
-
#signing_profile_version_arn ⇒ String
The Amazon Resource Name (ARN) for a signing profile version.
Instance Attribute Details
#code_sha_256 ⇒ String
The SHA-256 hash of the layer archive.
6191 6192 6193 6194 6195 6196 6197 6198 6199 6200 |
# File 'lib/aws-sdk-lambda/types.rb', line 6191 class LayerVersionContentOutput < Struct.new( :location, :code_sha_256, :code_size, :signing_profile_version_arn, :signing_job_arn, :resolved_s3_object) SENSITIVE = [] include Aws::Structure end |
#code_size ⇒ Integer
The size of the layer archive in bytes.
6191 6192 6193 6194 6195 6196 6197 6198 6199 6200 |
# File 'lib/aws-sdk-lambda/types.rb', line 6191 class LayerVersionContentOutput < Struct.new( :location, :code_sha_256, :code_size, :signing_profile_version_arn, :signing_job_arn, :resolved_s3_object) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
A link to the layer archive in Amazon S3 that is valid for 10 minutes.
6191 6192 6193 6194 6195 6196 6197 6198 6199 6200 |
# File 'lib/aws-sdk-lambda/types.rb', line 6191 class LayerVersionContentOutput < Struct.new( :location, :code_sha_256, :code_size, :signing_profile_version_arn, :signing_job_arn, :resolved_s3_object) SENSITIVE = [] include Aws::Structure end |
#resolved_s3_object ⇒ Types::ResolvedS3Object
Details about the resolved Amazon S3 object that contains a function's deployment package.
6191 6192 6193 6194 6195 6196 6197 6198 6199 6200 |
# File 'lib/aws-sdk-lambda/types.rb', line 6191 class LayerVersionContentOutput < Struct.new( :location, :code_sha_256, :code_size, :signing_profile_version_arn, :signing_job_arn, :resolved_s3_object) SENSITIVE = [] include Aws::Structure end |
#signing_job_arn ⇒ String
The Amazon Resource Name (ARN) of a signing job.
6191 6192 6193 6194 6195 6196 6197 6198 6199 6200 |
# File 'lib/aws-sdk-lambda/types.rb', line 6191 class LayerVersionContentOutput < Struct.new( :location, :code_sha_256, :code_size, :signing_profile_version_arn, :signing_job_arn, :resolved_s3_object) SENSITIVE = [] include Aws::Structure end |
#signing_profile_version_arn ⇒ String
The Amazon Resource Name (ARN) for a signing profile version.
6191 6192 6193 6194 6195 6196 6197 6198 6199 6200 |
# File 'lib/aws-sdk-lambda/types.rb', line 6191 class LayerVersionContentOutput < Struct.new( :location, :code_sha_256, :code_size, :signing_profile_version_arn, :signing_job_arn, :resolved_s3_object) SENSITIVE = [] include Aws::Structure end |