Class: Aws::Lambda::Types::ListFunctionEventInvokeConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ListFunctionEventInvokeConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#marker ⇒ String
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
-
#max_items ⇒ Integer
The maximum number of configurations to return.
Instance Attribute Details
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name -
my-function. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN -
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
6800 6801 6802 6803 6804 6805 6806 |
# File 'lib/aws-sdk-lambda/types.rb', line 6800 class ListFunctionEventInvokeConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
6800 6801 6802 6803 6804 6805 6806 |
# File 'lib/aws-sdk-lambda/types.rb', line 6800 class ListFunctionEventInvokeConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of configurations to return.
6800 6801 6802 6803 6804 6805 6806 |
# File 'lib/aws-sdk-lambda/types.rb', line 6800 class ListFunctionEventInvokeConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |