Class: Aws::Lambda::Types::ListFunctionUrlConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ListFunctionUrlConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#marker ⇒ String
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
-
#max_items ⇒ Integer
The maximum number of function URLs to return in the response.
Instance Attribute Details
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
6854 6855 6856 6857 6858 6859 6860 |
# File 'lib/aws-sdk-lambda/types.rb', line 6854 class ListFunctionUrlConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Specify the pagination token that's returned by a previous request to retrieve the next page of results.
6854 6855 6856 6857 6858 6859 6860 |
# File 'lib/aws-sdk-lambda/types.rb', line 6854 class ListFunctionUrlConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of function URLs to return in the response. Note
that ListFunctionUrlConfigs returns a maximum of 50 items in each
response, even if you set the number higher.
6854 6855 6856 6857 6858 6859 6860 |
# File 'lib/aws-sdk-lambda/types.rb', line 6854 class ListFunctionUrlConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |