Class: Aws::Lambda::Types::ListProvisionedConcurrencyConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ListProvisionedConcurrencyConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#marker ⇒ String
Specify the pagination token that’s returned by a previous request to retrieve the next page of results.
-
#max_items ⇒ Integer
Specify a number to limit the number of configurations returned.
Instance Attribute Details
#function_name ⇒ String
The name or ARN of the Lambda function.
**Name formats**
-
**Function name** –
my-function. -
**Function ARN** –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
**Partial ARN** –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-lambda/types.rb', line 6808 class ListProvisionedConcurrencyConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Specify the pagination token that’s returned by a previous request to retrieve the next page of results.
6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-lambda/types.rb', line 6808 class ListProvisionedConcurrencyConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Specify a number to limit the number of configurations returned.
6808 6809 6810 6811 6812 6813 6814 |
# File 'lib/aws-sdk-lambda/types.rb', line 6808 class ListProvisionedConcurrencyConfigsRequest < Struct.new( :function_name, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |