Class: Aws::Lambda::Types::LoggingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::LoggingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The function’s Amazon CloudWatch Logs configuration settings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_log_level ⇒ String
Set this property to filter the application logs for your function that Lambda sends to CloudWatch.
-
#log_format ⇒ String
The format in which Lambda sends your function’s application and system logs to CloudWatch.
-
#log_group ⇒ String
The name of the Amazon CloudWatch log group the function sends logs to.
-
#system_log_level ⇒ String
Set this property to filter the system logs for your function that Lambda sends to CloudWatch.
Instance Attribute Details
#application_log_level ⇒ String
Set this property to filter the application logs for your function that Lambda sends to CloudWatch. Lambda only sends application logs at the selected level of detail and lower, where ‘TRACE` is the highest level and `FATAL` is the lowest.
5612 5613 5614 5615 5616 5617 5618 5619 |
# File 'lib/aws-sdk-lambda/types.rb', line 5612 class LoggingConfig < Struct.new( :log_format, :application_log_level, :system_log_level, :log_group) SENSITIVE = [] include Aws::Structure end |
#log_format ⇒ String
The format in which Lambda sends your function’s application and system logs to CloudWatch. Select between plain text and structured JSON.
5612 5613 5614 5615 5616 5617 5618 5619 |
# File 'lib/aws-sdk-lambda/types.rb', line 5612 class LoggingConfig < Struct.new( :log_format, :application_log_level, :system_log_level, :log_group) SENSITIVE = [] include Aws::Structure end |
#log_group ⇒ String
The name of the Amazon CloudWatch log group the function sends logs to. By default, Lambda functions send logs to a default log group named ‘/aws/lambda/<function name>`. To use a different log group, enter an existing log group or enter a new log group name.
5612 5613 5614 5615 5616 5617 5618 5619 |
# File 'lib/aws-sdk-lambda/types.rb', line 5612 class LoggingConfig < Struct.new( :log_format, :application_log_level, :system_log_level, :log_group) SENSITIVE = [] include Aws::Structure end |
#system_log_level ⇒ String
Set this property to filter the system logs for your function that Lambda sends to CloudWatch. Lambda only sends system logs at the selected level of detail and lower, where ‘DEBUG` is the highest level and `WARN` is the lowest.
5612 5613 5614 5615 5616 5617 5618 5619 |
# File 'lib/aws-sdk-lambda/types.rb', line 5612 class LoggingConfig < Struct.new( :log_format, :application_log_level, :system_log_level, :log_group) SENSITIVE = [] include Aws::Structure end |