Class: Aws::Lambda::Types::PublicAccessBlockConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

An object that defines the public-access settings for a function.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#block_public_policyBoolean

To block the creation of resource-based policies that would grant public access to your function, set ‘BlockPublicPolicy` to `true`. To allow the creation of resource-based policies that would grant public access to your function, set `BlockPublicPolicy` to `false`.

Returns:

  • (Boolean)


5066
5067
5068
5069
5070
5071
# File 'lib/aws-sdk-lambda/types.rb', line 5066

class PublicAccessBlockConfig < Struct.new(
  :block_public_policy,
  :restrict_public_resource)
  SENSITIVE = []
  include Aws::Structure
end

#restrict_public_resourceBoolean

To block public access to your function, even if its resource-based policy allows it, set ‘RestrictPublicResource` to `true`. To allow public access to a function with a resource-based policy that permits it, set `RestrictPublicResource` to `false`.

Returns:

  • (Boolean)


5066
5067
5068
5069
5070
5071
# File 'lib/aws-sdk-lambda/types.rb', line 5066

class PublicAccessBlockConfig < Struct.new(
  :block_public_policy,
  :restrict_public_resource)
  SENSITIVE = []
  include Aws::Structure
end