Class: Aws::Lambda::Types::PublicPolicyException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The resource-based policy you tried to add to the Lambda resource would grant public access to it, which isn't allowed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The exception message.

Returns:

  • (String)


7807
7808
7809
7810
7811
7812
# File 'lib/aws-sdk-lambda/types.rb', line 7807

class PublicPolicyException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The exception type.

Returns:

  • (String)


7807
7808
7809
7810
7811
7812
# File 'lib/aws-sdk-lambda/types.rb', line 7807

class PublicPolicyException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end