Class: Aws::Lambda::Types::PutFunctionCodeSigningConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PutFunctionCodeSigningConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_signing_config_arn ⇒ String
The The Amazon Resource Name (ARN) of the code signing configuration.
-
#function_name ⇒ String
The name of the Lambda function.
Instance Attribute Details
#code_signing_config_arn ⇒ String
The The Amazon Resource Name (ARN) of the code signing configuration.
4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-lambda/types.rb', line 4955 class PutFunctionCodeSigningConfigResponse < Struct.new( :code_signing_config_arn, :function_name) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
4955 4956 4957 4958 4959 4960 |
# File 'lib/aws-sdk-lambda/types.rb', line 4955 class PutFunctionCodeSigningConfigResponse < Struct.new( :code_signing_config_arn, :function_name) SENSITIVE = [] include Aws::Structure end |