Class: Aws::Lambda::Types::PutPublicAccessBlockConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#public_access_block_configTypes::PublicAccessBlockConfig

An object defining the public-access settings you want to apply.

To block the creation of resource-based policies that would grant public access to your function, set ‘BlockPublicPolicy` to `true`. To allow the creation of resource-based policies that would grant public access to your function, set `BlockPublicPolicy` to `false`.

To block public access to your function, even if its resource-based policy allows it, set ‘RestrictPublicResource` to `true`. To allow public access to a function with a resource-based policy that permits it, set `RestrictPublicResource` to `false`.

The default setting for both ‘BlockPublicPolicy` and `RestrictPublicResource` is `true`.



5604
5605
5606
5607
5608
5609
# File 'lib/aws-sdk-lambda/types.rb', line 5604

class PutPublicAccessBlockConfigRequest < Struct.new(
  :resource_arn,
  :public_access_block_config)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the function you want to configure public-access settings for. Public-access settings are applied at the function level, so you can’t apply different settings to function versions or aliases.

Returns:

  • (String)


5604
5605
5606
5607
5608
5609
# File 'lib/aws-sdk-lambda/types.rb', line 5604

class PutPublicAccessBlockConfigRequest < Struct.new(
  :resource_arn,
  :public_access_block_config)
  SENSITIVE = []
  include Aws::Structure
end