Class: Aws::Lambda::Types::PutResourcePolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PutResourcePolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The resource-based policy that Lambda adds to the resource.
-
#revision_id ⇒ String
The revision ID of the policy that Lambda adds to your Lambda resource.
Instance Attribute Details
#policy ⇒ String
The resource-based policy that Lambda adds to the resource.
8407 8408 8409 8410 8411 8412 |
# File 'lib/aws-sdk-lambda/types.rb', line 8407 class PutResourcePolicyResponse < Struct.new( :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The revision ID of the policy that Lambda adds to your Lambda resource.
8407 8408 8409 8410 8411 8412 |
# File 'lib/aws-sdk-lambda/types.rb', line 8407 class PutResourcePolicyResponse < Struct.new( :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |