Class: Aws::Lambda::Types::RetryDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::RetryDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Information about retry attempts for an operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_attempt ⇒ Integer
The current attempt number for this operation.
-
#next_attempt_delay_seconds ⇒ Integer
The delay before the next retry attempt, in seconds.
Instance Attribute Details
#current_attempt ⇒ Integer
The current attempt number for this operation.
8507 8508 8509 8510 8511 8512 |
# File 'lib/aws-sdk-lambda/types.rb', line 8507 class RetryDetails < Struct.new( :current_attempt, :next_attempt_delay_seconds) SENSITIVE = [] include Aws::Structure end |
#next_attempt_delay_seconds ⇒ Integer
The delay before the next retry attempt, in seconds.
8507 8508 8509 8510 8511 8512 |
# File 'lib/aws-sdk-lambda/types.rb', line 8507 class RetryDetails < Struct.new( :current_attempt, :next_attempt_delay_seconds) SENSITIVE = [] include Aws::Structure end |