Class: Aws::Lambda::Types::S3FilesConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::S3FilesConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Setting controls how your function accesses data from an Amazon S3 file system.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#direct_s3_read ⇒ String
Specifies if a function reads from the file system for the lowest latency, or through Amazon S3 Files feature "direct Amazon S3 bucket reads" for the highest throughput.
Instance Attribute Details
#direct_s3_read ⇒ String
Specifies if a function reads from the file system for the lowest latency, or through Amazon S3 Files feature "direct Amazon S3 bucket reads" for the highest throughput. Valid values:
-
AUTO(default) – Direct reads are active for functions you configure with 512 MB or more of memory. -
ENABLED– Enforces all reads are directly from the Amazon S3 bucket, regardless of available memory (less than 512 MB). -
DISABLED– Routes all reads through the file system, regardless of memory configuration.
To use direct reads, you must grant the execution role the
s3:GetObject and s3:GetObjectVersion permissions. If a direct
read fails, Lambda automatically falls back to reading through the
file system.
8811 8812 8813 8814 8815 |
# File 'lib/aws-sdk-lambda/types.rb', line 8811 class S3FilesConfig < Struct.new( :direct_s3_read) SENSITIVE = [] include Aws::Structure end |