Class: Aws::Lambda::Types::SelfManagedKafkaEventSourceConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::SelfManagedKafkaEventSourceConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Specific configuration settings for a self-managed Apache Kafka event source.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_group_id ⇒ String
The identifier for the Kafka consumer group to join.
-
#schema_registry_config ⇒ Types::KafkaSchemaRegistryConfig
Specific configuration settings for a Kafka schema registry.
Instance Attribute Details
#consumer_group_id ⇒ String
The identifier for the Kafka consumer group to join. The consumer group ID must be unique among all your Kafka event sources. After creating a Kafka event source mapping with the consumer group ID specified, you cannot update this value. For more information, see Customizable consumer group ID.
8667 8668 8669 8670 8671 8672 |
# File 'lib/aws-sdk-lambda/types.rb', line 8667 class SelfManagedKafkaEventSourceConfig < Struct.new( :consumer_group_id, :schema_registry_config) SENSITIVE = [] include Aws::Structure end |
#schema_registry_config ⇒ Types::KafkaSchemaRegistryConfig
Specific configuration settings for a Kafka schema registry.
8667 8668 8669 8670 8671 8672 |
# File 'lib/aws-sdk-lambda/types.rb', line 8667 class SelfManagedKafkaEventSourceConfig < Struct.new( :consumer_group_id, :schema_registry_config) SENSITIVE = [] include Aws::Structure end |