Class: Aws::Lambda::Types::SnapStart

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The function's Lambda SnapStart setting. Set ApplyOn to PublishedVersions to create a snapshot of the initialized execution environment when you publish a function version.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apply_onString

Set to PublishedVersions to create a snapshot of the initialized execution environment when you publish a function version.

Returns:

  • (String)


8811
8812
8813
8814
8815
# File 'lib/aws-sdk-lambda/types.rb', line 8811

class SnapStart < Struct.new(
  :apply_on)
  SENSITIVE = []
  include Aws::Structure
end