Class: Aws::Lambda::Types::StepDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Details about a step operation.

Constant Summary collapse

SENSITIVE =
[:result]

Instance Attribute Summary collapse

Instance Attribute Details

#attemptInteger

The current attempt number for this step.

Returns:

  • (Integer)


9024
9025
9026
9027
9028
9029
9030
9031
# File 'lib/aws-sdk-lambda/types.rb', line 9024

class StepDetails < Struct.new(
  :attempt,
  :next_attempt_timestamp,
  :result,
  :error)
  SENSITIVE = [:result]
  include Aws::Structure
end

#errorTypes::ErrorObject

Details about the step failure.

Returns:



9024
9025
9026
9027
9028
9029
9030
9031
# File 'lib/aws-sdk-lambda/types.rb', line 9024

class StepDetails < Struct.new(
  :attempt,
  :next_attempt_timestamp,
  :result,
  :error)
  SENSITIVE = [:result]
  include Aws::Structure
end

#next_attempt_timestampTime

The date and time when the next attempt is scheduled, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD). Only populated when the step is in a pending state.

Returns:

  • (Time)


9024
9025
9026
9027
9028
9029
9030
9031
# File 'lib/aws-sdk-lambda/types.rb', line 9024

class StepDetails < Struct.new(
  :attempt,
  :next_attempt_timestamp,
  :result,
  :error)
  SENSITIVE = [:result]
  include Aws::Structure
end

#resultString

The JSON response payload from the step operation.

Returns:

  • (String)


9024
9025
9026
9027
9028
9029
9030
9031
# File 'lib/aws-sdk-lambda/types.rb', line 9024

class StepDetails < Struct.new(
  :attempt,
  :next_attempt_timestamp,
  :result,
  :error)
  SENSITIVE = [:result]
  include Aws::Structure
end