Class: Aws::Lambda::Types::StepOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::StepOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Configuration options for a step operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_attempt_delay_seconds ⇒ Integer
The delay in seconds before the next retry attempt.
Instance Attribute Details
#next_attempt_delay_seconds ⇒ Integer
The delay in seconds before the next retry attempt.
8756 8757 8758 8759 8760 |
# File 'lib/aws-sdk-lambda/types.rb', line 8756 class StepOptions < Struct.new( :next_attempt_delay_seconds) SENSITIVE = [] include Aws::Structure end |