Class: Aws::Lambda::Types::UpdateAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the alias.
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#function_version ⇒ String
The function version that the alias invokes.
-
#name ⇒ String
The name of the alias.
-
#revision_id ⇒ String
Only update the alias if the revision ID matches the ID that's specified.
-
#routing_config ⇒ Types::AliasRoutingConfiguration
The [routing configuration][1] of the alias.
Instance Attribute Details
#description ⇒ String
A description of the alias.
9486 9487 9488 9489 9490 9491 9492 9493 9494 9495 |
# File 'lib/aws-sdk-lambda/types.rb', line 9486 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
9486 9487 9488 9489 9490 9491 9492 9493 9494 9495 |
# File 'lib/aws-sdk-lambda/types.rb', line 9486 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#function_version ⇒ String
The function version that the alias invokes.
9486 9487 9488 9489 9490 9491 9492 9493 9494 9495 |
# File 'lib/aws-sdk-lambda/types.rb', line 9486 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the alias.
9486 9487 9488 9489 9490 9491 9492 9493 9494 9495 |
# File 'lib/aws-sdk-lambda/types.rb', line 9486 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Only update the alias if the revision ID matches the ID that's specified. Use this option to avoid modifying an alias that has changed since you last read it.
9486 9487 9488 9489 9490 9491 9492 9493 9494 9495 |
# File 'lib/aws-sdk-lambda/types.rb', line 9486 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#routing_config ⇒ Types::AliasRoutingConfiguration
The routing configuration of the alias.
9486 9487 9488 9489 9490 9491 9492 9493 9494 9495 |
# File 'lib/aws-sdk-lambda/types.rb', line 9486 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |