Class: Aws::Lambda::Types::UpdateCapacityProviderRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateCapacityProviderRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_provider_name ⇒ String
The name of the capacity provider to update.
-
#capacity_provider_scaling_config ⇒ Types::CapacityProviderScalingConfig
The updated scaling configuration for the capacity provider.
-
#propagate_tags ⇒ Types::PropagateTags
Configuration for tag propagation to managed resources launched by the capacity provider.
-
#telemetry_config ⇒ Types::CapacityProviderTelemetryConfig
The updated telemetry configuration for the capacity provider.
Instance Attribute Details
#capacity_provider_name ⇒ String
The name of the capacity provider to update.
9507 9508 9509 9510 9511 9512 9513 9514 |
# File 'lib/aws-sdk-lambda/types.rb', line 9507 class UpdateCapacityProviderRequest < Struct.new( :capacity_provider_name, :capacity_provider_scaling_config, :propagate_tags, :telemetry_config) SENSITIVE = [] include Aws::Structure end |
#capacity_provider_scaling_config ⇒ Types::CapacityProviderScalingConfig
The updated scaling configuration for the capacity provider.
9507 9508 9509 9510 9511 9512 9513 9514 |
# File 'lib/aws-sdk-lambda/types.rb', line 9507 class UpdateCapacityProviderRequest < Struct.new( :capacity_provider_name, :capacity_provider_scaling_config, :propagate_tags, :telemetry_config) SENSITIVE = [] include Aws::Structure end |
#propagate_tags ⇒ Types::PropagateTags
Configuration for tag propagation to managed resources launched by the capacity provider.
9507 9508 9509 9510 9511 9512 9513 9514 |
# File 'lib/aws-sdk-lambda/types.rb', line 9507 class UpdateCapacityProviderRequest < Struct.new( :capacity_provider_name, :capacity_provider_scaling_config, :propagate_tags, :telemetry_config) SENSITIVE = [] include Aws::Structure end |
#telemetry_config ⇒ Types::CapacityProviderTelemetryConfig
The updated telemetry configuration for the capacity provider.
9507 9508 9509 9510 9511 9512 9513 9514 |
# File 'lib/aws-sdk-lambda/types.rb', line 9507 class UpdateCapacityProviderRequest < Struct.new( :capacity_provider_name, :capacity_provider_scaling_config, :propagate_tags, :telemetry_config) SENSITIVE = [] include Aws::Structure end |