Class: Aws::Lambda::Types::UpdateEventSourceMappingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_sizeInteger

The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function. Lambda passes all of the records in the batch to the function in a single call, up to the payload limit for synchronous invocation (6 MB).

  • **Amazon Kinesis** – Default 100. Max 10,000.

  • **Amazon DynamoDB Streams** – Default 100. Max 10,000.

  • **Amazon Simple Queue Service** – Default 10. For standard queues the max is 10,000. For FIFO queues the max is 10.

  • **Amazon Managed Streaming for Apache Kafka** – Default 100. Max 10,000.

  • **Self-managed Apache Kafka** – Default 100. Max 10,000.

  • **Amazon MQ (ActiveMQ and RabbitMQ)** – Default 100. Max 10,000.

Returns:

  • (Integer)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#bisect_batch_on_function_errorBoolean

(Streams only) If the function returns an error, split the batch in two and retry.

Returns:

  • (Boolean)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#destination_configTypes::DestinationConfig

(Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records.



5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

When true, the event source mapping is active. When false, Lambda pauses polling and invocation.

Default: True

Returns:

  • (Boolean)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#filter_criteriaTypes::FilterCriteria

An object that defines the filter criteria that determine whether Lambda should process an event. For more information, see [Lambda event filtering].

[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html



5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the Lambda function.

**Name formats**

  • **Function name** – `MyFunction`.

  • **Function ARN** – `arn:aws:lambda:us-west-2:123456789012:function:MyFunction`.

  • **Version or Alias ARN** – `arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD`.

  • **Partial ARN** – `123456789012:function:MyFunction`.

The length constraint applies only to the full ARN. If you specify only the function name, it's limited to 64 characters in length.

Returns:

  • (String)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_response_typesArray<String>

(Streams and Amazon SQS) A list of current response type enums applied to the event source mapping.

Returns:

  • (Array<String>)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_batching_window_in_secondsInteger

The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function. You can configure `MaximumBatchingWindowInSeconds` to any value from 0 seconds to 300 seconds in increments of seconds.

For streams and Amazon SQS event sources, the default batching window is 0 seconds. For Amazon MSK, Self-managed Apache Kafka, and Amazon MQ event sources, the default batching window is 500 ms. Note that because you can only change `MaximumBatchingWindowInSeconds` in increments of seconds, you cannot revert back to the 500 ms default batching window after you have changed it. To restore the default batching window, you must create a new event source mapping.

Related setting: For streams and Amazon SQS event sources, when you set `BatchSize` to a value greater than 10, you must set `MaximumBatchingWindowInSeconds` to at least 1.

Returns:

  • (Integer)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_record_age_in_secondsInteger

(Streams only) Discard records older than the specified age. The default value is infinite (-1).

Returns:

  • (Integer)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_retry_attemptsInteger

(Streams only) Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.

Returns:

  • (Integer)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#parallelization_factorInteger

(Streams only) The number of batches to process from each shard concurrently.

Returns:

  • (Integer)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#scaling_configTypes::ScalingConfig

(Amazon SQS only) The scaling configuration for the event source. For more information, see [Configuring maximum concurrency for Amazon SQS event sources].

[1]: docs.aws.amazon.com/lambda/latest/dg/with-sqs.html#events-sqs-max-concurrency



5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#source_access_configurationsArray<Types::SourceAccessConfiguration>

An array of authentication protocols or VPC components required to secure your event source.



5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#tumbling_window_in_secondsInteger

(Streams only) The duration in seconds of a processing window. The range is between 1 second and 900 seconds.

Returns:

  • (Integer)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The identifier of the event source mapping.

Returns:

  • (String)


5506
5507
5508
5509
5510
5511
5512
5513
5514
5515
5516
5517
5518
5519
5520
5521
5522
5523
5524
# File 'lib/aws-sdk-lambda/types.rb', line 5506

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types,
  :scaling_config)
  SENSITIVE = []
  include Aws::Structure
end