Class: Aws::Lambda::Types::UpdateFunctionCodeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateFunctionCodeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:zip_file]
Instance Attribute Summary collapse
-
#architectures ⇒ Array<String>
The instruction set architecture that the function supports.
-
#dry_run ⇒ Boolean
Set to true to validate the request parameters and access permissions without modifying the function code.
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#image_uri ⇒ String
URI of a container image in the Amazon ECR registry.
-
#publish ⇒ Boolean
Set to true to publish a new version of the function after updating the code.
-
#publish_to ⇒ String
Specifies where to publish the function version or configuration.
-
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that's specified.
-
#s3_bucket ⇒ String
An Amazon S3 bucket in the same Amazon Web Services Region as your function.
-
#s3_key ⇒ String
The Amazon S3 key of the deployment package.
-
#s3_object_storage_mode ⇒ String
Specifies how the deployment package is stored.
-
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
-
#source_kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package.
-
#zip_file ⇒ String
The base64-encoded contents of the deployment package.
Instance Attribute Details
#architectures ⇒ Array<String>
The instruction set architecture that the function supports. Enter a
string array with one of the valid values (arm64 or x86_64). The
default value is x86_64.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#dry_run ⇒ Boolean
Set to true to validate the request parameters and access permissions without modifying the function code.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#image_uri ⇒ String
URI of a container image in the Amazon ECR registry. Do not use for a function defined with a .zip file archive.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#publish ⇒ Boolean
Set to true to publish a new version of the function after updating the code. This has the same effect as calling PublishVersion separately.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#publish_to ⇒ String
Specifies where to publish the function version or configuration.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_bucket ⇒ String
An Amazon S3 bucket in the same Amazon Web Services Region as your function. The bucket can be in a different Amazon Web Services account. Use only with a function defined with a .zip file archive deployment package.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_key ⇒ String
The Amazon S3 key of the deployment package. Use only with a function defined with a .zip file archive deployment package.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_storage_mode ⇒ String
Specifies how the deployment package is stored. Valid values:
-
COPY(default) – Uploads a copy of your deployment package to Lambda. -
REFERENCE– Lambda references the deployment package from the specified Amazon S3 bucket.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#source_kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an Amazon Web Services managed key.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |
#zip_file ⇒ String
The base64-encoded contents of the deployment package. Amazon Web Services SDK and CLI clients handle the encoding for you. Use only with a function defined with a .zip file archive deployment package.
9887 9888 9889 9890 9891 9892 9893 9894 9895 9896 9897 9898 9899 9900 9901 9902 9903 |
# File 'lib/aws-sdk-lambda/types.rb', line 9887 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :s3_object_storage_mode, :image_uri, :architectures, :publish, :publish_to, :dry_run, :revision_id, :source_kms_key_arn) SENSITIVE = [:zip_file] include Aws::Structure end |