Class: Aws::Lambda::Types::UpdateFunctionConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateFunctionConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_provider_config ⇒ Types::CapacityProviderConfig
Configuration for the capacity provider that manages compute resources for Lambda functions.
-
#dead_letter_config ⇒ Types::DeadLetterConfig
A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing.
-
#description ⇒ String
A description of the function.
-
#durable_config ⇒ Types::DurableConfig
Configuration settings for durable functions.
-
#environment ⇒ Types::Environment
Environment variables that are accessible from function code during execution.
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function's
/tmpdirectory in MB. -
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#handler ⇒ String
The name of the method within your code that Lambda calls to run your function.
-
#image_config ⇒ Types::ImageConfig
[Container image configuration values][1] that override the values in the container image Docker file.
-
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt the following resources:.
-
#layers ⇒ Array<String>
A list of [function layers][1] to add to the function's execution environment.
-
#logging_config ⇒ Types::LoggingConfig
The function's Amazon CloudWatch Logs configuration settings.
-
#memory_size ⇒ Integer
The amount of [memory available to the function][1] at runtime.
-
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that's specified.
-
#role ⇒ String
The Amazon Resource Name (ARN) of the function's execution role.
-
#runtime ⇒ String
The identifier of the function's [ runtime][1].
-
#snap_start ⇒ Types::SnapStart
The function's [SnapStart][1] setting.
-
#timeout ⇒ Integer
The amount of time (in seconds) that Lambda allows a function to run before stopping it.
-
#tracing_config ⇒ Types::TracingConfig
Set
ModetoActiveto sample and trace a subset of incoming requests with [X-Ray][1]. -
#vpc_config ⇒ Types::VpcConfig
For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC.
Instance Attribute Details
#capacity_provider_config ⇒ Types::CapacityProviderConfig
Configuration for the capacity provider that manages compute resources for Lambda functions.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#dead_letter_config ⇒ Types::DeadLetterConfig
A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see Dead-letter queues.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the function.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#durable_config ⇒ Types::DurableConfig
Configuration settings for durable functions. Allows updating execution timeout and retention period for functions with durability enabled.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Types::Environment
Environment variables that are accessible from function code during execution.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function's /tmp directory in MB. The default
value is 512, but can be any whole number between 512 and 10,240 MB.
For more information, see Configuring ephemeral storage
(console).
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name –
my-function. -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#handler ⇒ String
The name of the method within your code that Lambda calls to run your function. Handler is required if the deployment package is a .zip file archive. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see Lambda programming model.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#image_config ⇒ Types::ImageConfig
Container image configuration values that override the values in the container image Docker file.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt the following resources:
-
The function's environment variables.
-
The function's Lambda SnapStart snapshots.
-
When used with
SourceKMSKeyArn, the unzipped version of the .zip deployment package that's used for function invocations. For more information, see Specifying a customer managed key for Lambda. -
The optimized version of the container image that's used for function invocations. Note that this is not the same key that's used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see Function lifecycle.
If you don't provide a customer managed key, Lambda uses an Amazon Web Services owned key or an Amazon Web Services managed key.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#layers ⇒ Array<String>
A list of function layers to add to the function's execution environment. Specify each layer by its ARN, including the version.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#logging_config ⇒ Types::LoggingConfig
The function's Amazon CloudWatch Logs configuration settings.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#memory_size ⇒ Integer
The amount of memory available to the function at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The Amazon Resource Name (ARN) of the function's execution role.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
The identifier of the function's runtime. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you're deploying a function using a container image.
The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see Runtime use after deprecation.
For a list of all currently supported runtimes, see Supported runtimes.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#snap_start ⇒ Types::SnapStart
The function's SnapStart setting.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The amount of time (in seconds) that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For more information, see Lambda execution environment.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#tracing_config ⇒ Types::TracingConfig
Set Mode to Active to sample and trace a subset of incoming
requests with X-Ray.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can access resources and the internet only through that VPC. For more information, see Configuring a Lambda function to access resources in a VPC.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 9659 9660 9661 9662 9663 9664 9665 9666 |
# File 'lib/aws-sdk-lambda/types.rb', line 9642 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start, :logging_config, :capacity_provider_config, :durable_config) SENSITIVE = [] include Aws::Structure end |