Class: Aws::Lambda::Types::VpcConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::VpcConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The VPC security groups and subnets that are attached to a Lambda function. For more information, see [Configuring a Lambda function to access resources in a VPC].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#security_group_ids ⇒ Array<String>
A list of VPC security group IDs.
-
#subnet_ids ⇒ Array<String>
A list of VPC subnet IDs.