Class: Aws::Lambda::Waiters::FunctionActiveV2

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-lambda/waiters.rb,
sig/waiters.rbs

Overview

Waits for the function's State to be Active. This waiter uses GetFunction API. This should be used after new function creation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ FunctionActiveV2

Returns a new instance of FunctionActiveV2.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 300
  • :delay (Integer) — default: 1
  • :before_attempt (Proc)
  • :before_wait (Proc)


141
142
# File 'lib/aws-sdk-lambda/waiters.rb', line 141

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



179
180
181
# File 'lib/aws-sdk-lambda/waiters.rb', line 179

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetFunctionResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :function_name (required, String)

    The name or ARN of the Lambda function, version, or alias.

    Name formats

    • Function namemy-function (name-only), my-function:v1 (with alias).

    • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

    • Partial ARN123456789012:function:my-function.

    You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

  • :qualifier (String)

    Specify a version or alias to get details about a published version of the function.

Returns:



174
# File 'lib/aws-sdk-lambda/waiters.rb', line 174

def wait: (