Class: Aws::Lambda::Types::AliasLimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::AliasLimitExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Lambda couldn’t create the alias because your Amazon Web Services account has exceeded the maximum number of aliases allowed per Lambda function. For more information, see [Lambda quotas].
[1]: docs.aws.amazon.com/lambda/latest/dg/gettingstarted-limits.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The exception message.
-
#type ⇒ String
The exception type.
Instance Attribute Details
#message ⇒ String
The exception message.
328 329 330 331 332 333 |
# File 'lib/aws-sdk-lambda/types.rb', line 328 class AliasLimitExceededException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The exception type.
328 329 330 331 332 333 |
# File 'lib/aws-sdk-lambda/types.rb', line 328 class AliasLimitExceededException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |