Class: Aws::Lambda::Types::CheckpointDurableExecutionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::CheckpointDurableExecutionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checkpoint_token ⇒ String
A unique token that identifies the current checkpoint state.
-
#client_token ⇒ String
An optional idempotency token to ensure that duplicate checkpoint requests are handled correctly.
-
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
-
#updates ⇒ Array<Types::OperationUpdate>
An array of state updates to apply during this checkpoint.
Instance Attribute Details
#checkpoint_token ⇒ String
A unique token that identifies the current checkpoint state. This token is provided by the Lambda runtime and must be used to ensure checkpoints are applied in the correct order. Each checkpoint operation consumes this token and returns a new one.
834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-lambda/types.rb', line 834 class CheckpointDurableExecutionRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :updates, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
An optional idempotency token to ensure that duplicate checkpoint requests are handled correctly. If provided, Lambda uses this token to detect and handle duplicate requests within a 15-minute window.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-lambda/types.rb', line 834 class CheckpointDurableExecutionRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :updates, :client_token) SENSITIVE = [] include Aws::Structure end |
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-lambda/types.rb', line 834 class CheckpointDurableExecutionRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :updates, :client_token) SENSITIVE = [] include Aws::Structure end |
#updates ⇒ Array<Types::OperationUpdate>
An array of state updates to apply during this checkpoint. Each update represents a change to the execution state, such as completing a step, starting a callback, or scheduling a timer. Updates are applied atomically as part of the checkpoint operation.
834 835 836 837 838 839 840 841 |
# File 'lib/aws-sdk-lambda/types.rb', line 834 class CheckpointDurableExecutionRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :updates, :client_token) SENSITIVE = [] include Aws::Structure end |