Class: Aws::Lambda::Types::CodeArtifactUserPendingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The Lambda function couldn't be invoked because its code artifact user is still being provisioned. Wait for the function's State to become Active and try the request again.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The exception message.

Returns:

  • (String)


971
972
973
974
975
976
# File 'lib/aws-sdk-lambda/types.rb', line 971

class CodeArtifactUserPendingException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The exception type.

Returns:

  • (String)


971
972
973
974
975
976
# File 'lib/aws-sdk-lambda/types.rb', line 971

class CodeArtifactUserPendingException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end