Class: Aws::Lambda::Types::CodeVerificationFailedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The code signature failed one or more of the validation checks for signature mismatch or expiry, and the code signing policy is set to ENFORCE. Lambda blocks the deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1101
1102
1103
1104
1105
1106
# File 'lib/aws-sdk-lambda/types.rb', line 1101

class CodeVerificationFailedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


1101
1102
1103
1104
1105
1106
# File 'lib/aws-sdk-lambda/types.rb', line 1101

class CodeVerificationFailedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end