Class: Aws::Lambda::Types::CodeVerificationFailedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The code signature failed one or more of the validation checks for signature mismatch or expiry, and the code signing policy is set to ENFORCE. Lambda blocks the deployment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


651
652
653
654
655
656
# File 'lib/aws-sdk-lambda/types.rb', line 651

class CodeVerificationFailedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


651
652
653
654
655
656
# File 'lib/aws-sdk-lambda/types.rb', line 651

class CodeVerificationFailedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end