Class: Aws::Lambda::Types::CreateAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::CreateAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
When making an API call, you may pass CreateAliasRequest data as a hash:
{
function_name: "FunctionName", # required
name: "Alias", # required
function_version: "Version", # required
description: "Description",
routing_config: {
additional_version_weights: {
"AdditionalVersion" => 1.0,
},
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the alias.
-
#function_name ⇒ String
The name of the Lambda function.
-
#function_version ⇒ String
The function version that the alias invokes.
-
#name ⇒ String
The name of the alias.
-
#routing_config ⇒ Types::AliasRoutingConfiguration
The [routing configuration] of the alias.
Instance Attribute Details
#description ⇒ String
A description of the alias.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-lambda/types.rb', line 686 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** - `MyFunction`.
-
**Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:MyFunction`.
-
**Partial ARN** - `123456789012:function:MyFunction`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-lambda/types.rb', line 686 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#function_version ⇒ String
The function version that the alias invokes.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-lambda/types.rb', line 686 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the alias.
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-lambda/types.rb', line 686 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |
#routing_config ⇒ Types::AliasRoutingConfiguration
The [routing configuration] of the alias.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-aliases.html#configuring-alias-routing
686 687 688 689 690 691 692 693 694 |
# File 'lib/aws-sdk-lambda/types.rb', line 686 class CreateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config) SENSITIVE = [] include Aws::Structure end |