Class: Aws::Lambda::Types::CreateEventSourceMappingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::CreateEventSourceMappingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
When making an API call, you may pass CreateEventSourceMappingRequest data as a hash:
{
event_source_arn: "Arn",
function_name: "FunctionName", # required
enabled: false,
batch_size: 1,
filter_criteria: {
filters: [
{
pattern: "Pattern",
},
],
},
maximum_batching_window_in_seconds: 1,
parallelization_factor: 1,
starting_position: "TRIM_HORIZON", # accepts TRIM_HORIZON, LATEST, AT_TIMESTAMP
starting_position_timestamp: Time.now,
destination_config: {
on_success: {
destination: "DestinationArn",
},
on_failure: {
destination: "DestinationArn",
},
},
maximum_record_age_in_seconds: 1,
bisect_batch_on_function_error: false,
maximum_retry_attempts: 1,
tumbling_window_in_seconds: 1,
topics: ["Topic"],
queues: ["Queue"],
source_access_configurations: [
{
type: "BASIC_AUTH", # accepts BASIC_AUTH, VPC_SUBNET, VPC_SECURITY_GROUP, SASL_SCRAM_512_AUTH, SASL_SCRAM_256_AUTH, VIRTUAL_HOST, CLIENT_CERTIFICATE_TLS_AUTH, SERVER_ROOT_CA_CERTIFICATE
uri: "URI",
},
],
self_managed_event_source: {
endpoints: {
"KAFKA_BOOTSTRAP_SERVERS" => ["Endpoint"],
},
},
function_response_types: ["ReportBatchItemFailures"], # accepts ReportBatchItemFailures
amazon_managed_kafka_event_source_config: {
consumer_group_id: "URI",
},
self_managed_kafka_event_source_config: {
consumer_group_id: "URI",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_managed_kafka_event_source_config ⇒ Types::AmazonManagedKafkaEventSourceConfig
Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.
-
#batch_size ⇒ Integer
The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function.
-
#bisect_batch_on_function_error ⇒ Boolean
(Streams only) If the function returns an error, split the batch in two and retry.
-
#destination_config ⇒ Types::DestinationConfig
(Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records.
-
#enabled ⇒ Boolean
When true, the event source mapping is active.
-
#event_source_arn ⇒ String
The Amazon Resource Name (ARN) of the event source.
-
#filter_criteria ⇒ Types::FilterCriteria
(Streams and Amazon SQS) An object that defines the filter criteria that determine whether Lambda should process an event.
-
#function_name ⇒ String
The name of the Lambda function.
-
#function_response_types ⇒ Array<String>
(Streams and Amazon SQS) A list of current response type enums applied to the event source mapping.
-
#maximum_batching_window_in_seconds ⇒ Integer
(Streams and Amazon SQS standard queues) The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function.
-
#maximum_record_age_in_seconds ⇒ Integer
(Streams only) Discard records older than the specified age.
-
#maximum_retry_attempts ⇒ Integer
(Streams only) Discard records after the specified number of retries.
-
#parallelization_factor ⇒ Integer
(Streams only) The number of batches to process from each shard concurrently.
-
#queues ⇒ Array<String>
(MQ) The name of the Amazon MQ broker destination queue to consume.
-
#self_managed_event_source ⇒ Types::SelfManagedEventSource
The self-managed Apache Kafka cluster to receive records from.
-
#self_managed_kafka_event_source_config ⇒ Types::SelfManagedKafkaEventSourceConfig
Specific configuration settings for a self-managed Apache Kafka event source.
-
#source_access_configurations ⇒ Array<Types::SourceAccessConfiguration>
An array of authentication protocols or VPC components required to secure your event source.
-
#starting_position ⇒ String
The position in a stream from which to start reading.
-
#starting_position_timestamp ⇒ Time
With `StartingPosition` set to `AT_TIMESTAMP`, the time from which to start reading.
-
#topics ⇒ Array<String>
The name of the Kafka topic.
-
#tumbling_window_in_seconds ⇒ Integer
(Streams only) The duration in seconds of a processing window.
Instance Attribute Details
#amazon_managed_kafka_event_source_config ⇒ Types::AmazonManagedKafkaEventSourceConfig
Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#batch_size ⇒ Integer
The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function. Lambda passes all of the records in the batch to the function in a single call, up to the payload limit for synchronous invocation (6 MB).
-
**Amazon Kinesis** - Default 100. Max 10,000.
-
**Amazon DynamoDB Streams** - Default 100. Max 10,000.
-
**Amazon Simple Queue Service** - Default 10. For standard queues the max is 10,000. For FIFO queues the max is 10.
-
**Amazon Managed Streaming for Apache Kafka** - Default 100. Max 10,000.
-
**Self-managed Apache Kafka** - Default 100. Max 10,000.
-
**Amazon MQ (ActiveMQ and RabbitMQ)** - Default 100. Max 10,000.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#bisect_batch_on_function_error ⇒ Boolean
(Streams only) If the function returns an error, split the batch in two and retry.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#destination_config ⇒ Types::DestinationConfig
(Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#enabled ⇒ Boolean
When true, the event source mapping is active. When false, Lambda pauses polling and invocation.
Default: True
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#event_source_arn ⇒ String
The Amazon Resource Name (ARN) of the event source.
-
**Amazon Kinesis** - The ARN of the data stream or a stream consumer.
-
**Amazon DynamoDB Streams** - The ARN of the stream.
-
**Amazon Simple Queue Service** - The ARN of the queue.
-
**Amazon Managed Streaming for Apache Kafka** - The ARN of the cluster.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#filter_criteria ⇒ Types::FilterCriteria
(Streams and Amazon SQS) An object that defines the filter criteria that determine whether Lambda should process an event. For more information, see [Lambda event filtering].
[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** - `MyFunction`.
-
**Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:MyFunction`.
-
**Version or Alias ARN** - `arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD`.
-
**Partial ARN** - `123456789012:function:MyFunction`.
The length constraint applies only to the full ARN. If you specify only the function name, it's limited to 64 characters in length.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#function_response_types ⇒ Array<String>
(Streams and Amazon SQS) A list of current response type enums applied to the event source mapping.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#maximum_batching_window_in_seconds ⇒ Integer
(Streams and Amazon SQS standard queues) The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function.
Default: 0
Related setting: When you set `BatchSize` to a value greater than 10, you must set `MaximumBatchingWindowInSeconds` to at least 1.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#maximum_record_age_in_seconds ⇒ Integer
(Streams only) Discard records older than the specified age. The default value is infinite (-1).
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#maximum_retry_attempts ⇒ Integer
(Streams only) Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records are retried until the record expires.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#parallelization_factor ⇒ Integer
(Streams only) The number of batches to process from each shard concurrently.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#queues ⇒ Array<String>
(MQ) The name of the Amazon MQ broker destination queue to consume.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#self_managed_event_source ⇒ Types::SelfManagedEventSource
The self-managed Apache Kafka cluster to receive records from.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#self_managed_kafka_event_source_config ⇒ Types::SelfManagedKafkaEventSourceConfig
Specific configuration settings for a self-managed Apache Kafka event source.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#source_access_configurations ⇒ Array<Types::SourceAccessConfiguration>
An array of authentication protocols or VPC components required to secure your event source.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#starting_position ⇒ String
The position in a stream from which to start reading. Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK Streams sources. `AT_TIMESTAMP` is supported only for Amazon Kinesis streams.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#starting_position_timestamp ⇒ Time
With `StartingPosition` set to `AT_TIMESTAMP`, the time from which to start reading.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#topics ⇒ Array<String>
The name of the Kafka topic.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#tumbling_window_in_seconds ⇒ Integer
(Streams only) The duration in seconds of a processing window. The range is between 1 second and 900 seconds.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 |
# File 'lib/aws-sdk-lambda/types.rb', line 955 class CreateEventSourceMappingRequest < Struct.new( :event_source_arn, :function_name, :enabled, :batch_size, :filter_criteria, :maximum_batching_window_in_seconds, :parallelization_factor, :starting_position, :starting_position_timestamp, :destination_config, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :topics, :queues, :source_access_configurations, :self_managed_event_source, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |