Class: Aws::Lambda::Types::CreateEventSourceMappingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Note:

When making an API call, you may pass CreateEventSourceMappingRequest data as a hash:

{
  event_source_arn: "Arn", # required
  function_name: "FunctionName", # required
  enabled: false,
  batch_size: 1,
  starting_position: "TRIM_HORIZON", # accepts TRIM_HORIZON, LATEST, AT_TIMESTAMP
  starting_position_timestamp: Time.now,
}

Instance Attribute Summary collapse

Instance Attribute Details

#batch_sizeInteger

The maximum number of items to retrieve in a single batch.

  • **Amazon Kinesis** - Default 100. Max 10,000.

  • **Amazon DynamoDB Streams** - Default 100. Max 1,000.

  • **Amazon Simple Queue Service** - Default 10. Max 10.



421
422
423
424
425
426
427
428
429
# File 'lib/aws-sdk-lambda/types.rb', line 421

class CreateEventSourceMappingRequest < Struct.new(
  :event_source_arn,
  :function_name,
  :enabled,
  :batch_size,
  :starting_position,
  :starting_position_timestamp)
  include Aws::Structure
end

#enabledBoolean

Disables the event source mapping to pause polling and invocation.



421
422
423
424
425
426
427
428
429
# File 'lib/aws-sdk-lambda/types.rb', line 421

class CreateEventSourceMappingRequest < Struct.new(
  :event_source_arn,
  :function_name,
  :enabled,
  :batch_size,
  :starting_position,
  :starting_position_timestamp)
  include Aws::Structure
end

#event_source_arnString

The Amazon Resource Name (ARN) of the event source.

  • **Amazon Kinesis** - The ARN of the data stream or a stream consumer.

  • **Amazon DynamoDB Streams** - The ARN of the stream.

  • **Amazon Simple Queue Service** - The ARN of the queue.



421
422
423
424
425
426
427
428
429
# File 'lib/aws-sdk-lambda/types.rb', line 421

class CreateEventSourceMappingRequest < Struct.new(
  :event_source_arn,
  :function_name,
  :enabled,
  :batch_size,
  :starting_position,
  :starting_position_timestamp)
  include Aws::Structure
end

#function_nameString

The name of the Lambda function.

**Name formats**

  • **Function name** - MyFunction.

  • **Function ARN** - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

  • **Version or Alias ARN** - arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD.

  • **Partial ARN** - 123456789012:function:MyFunction.

The length constraint applies only to the full ARN. If you specify only the function name, it’s limited to 64 characters in length.



421
422
423
424
425
426
427
428
429
# File 'lib/aws-sdk-lambda/types.rb', line 421

class CreateEventSourceMappingRequest < Struct.new(
  :event_source_arn,
  :function_name,
  :enabled,
  :batch_size,
  :starting_position,
  :starting_position_timestamp)
  include Aws::Structure
end

#starting_positionString

The position in a stream from which to start reading. Required for Amazon Kinesis and Amazon DynamoDB Streams sources. AT_TIMESTAMP is only supported for Amazon Kinesis streams.



421
422
423
424
425
426
427
428
429
# File 'lib/aws-sdk-lambda/types.rb', line 421

class CreateEventSourceMappingRequest < Struct.new(
  :event_source_arn,
  :function_name,
  :enabled,
  :batch_size,
  :starting_position,
  :starting_position_timestamp)
  include Aws::Structure
end

#starting_position_timestampTime

With StartingPosition set to AT_TIMESTAMP, the Unix time in seconds from which to start reading.



421
422
423
424
425
426
427
428
429
# File 'lib/aws-sdk-lambda/types.rb', line 421

class CreateEventSourceMappingRequest < Struct.new(
  :event_source_arn,
  :function_name,
  :enabled,
  :batch_size,
  :starting_position,
  :starting_position_timestamp)
  include Aws::Structure
end