Method: Aws::Lambda::Types::CreateFunctionRequest#function_name
- Defined in:
- lib/aws-sdk-lambda/types.rb
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** -
my-function. -
**Function ARN** -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
**Partial ARN** -
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 |
# File 'lib/aws-sdk-lambda/types.rb', line 708 class CreateFunctionRequest < Struct.new( :function_name, :runtime, :role, :handler, :code, :description, :timeout, :memory_size, :publish, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :tags, :layers) include Aws::Structure end |