Class: Aws::Lambda::Types::DeleteAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_nameString

The name or ARN of the Lambda function.

**Name formats**

  • **Function name** - MyFunction.

  • **Function ARN** - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

  • **Partial ARN** - 123456789012:function:MyFunction.

The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.



1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-lambda/types.rb', line 1349

class DeleteAliasRequest < Struct.new(
  :function_name,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the alias.



1349
1350
1351
1352
1353
1354
# File 'lib/aws-sdk-lambda/types.rb', line 1349

class DeleteAliasRequest < Struct.new(
  :function_name,
  :name)
  SENSITIVE = []
  include Aws::Structure
end