Class: Aws::Lambda::Types::DeleteFunctionEventInvokeConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::DeleteFunctionEventInvokeConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Note:
When making an API call, you may pass DeleteFunctionEventInvokeConfigRequest data as a hash:
{
function_name: "FunctionName", # required
qualifier: "Qualifier",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name of the Lambda function, version, or alias.
-
#qualifier ⇒ String
A version number or alias name.
Instance Attribute Details
#function_name ⇒ String
The name of the Lambda function, version, or alias.
**Name formats**
-
**Function name** - `my-function` (name-only), `my-function:v1` (with alias).
-
**Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** - `123456789012:function:my-function`.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
1569 1570 1571 1572 1573 1574 |
# File 'lib/aws-sdk-lambda/types.rb', line 1569 class DeleteFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
A version number or alias name.
1569 1570 1571 1572 1573 1574 |
# File 'lib/aws-sdk-lambda/types.rb', line 1569 class DeleteFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |