Class: Aws::Lambda::Types::DeleteResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::DeleteResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the function you want to delete the policy from.
-
#revision_id ⇒ String
Delete the existing policy only if its revision ID matches the string you specify.
Instance Attribute Details
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the function you want to delete the policy from. You can use either a qualified or an unqualified ARN, but the value you specify must be a complete ARN and wildcard characters are not accepted.
1560 1561 1562 1563 1564 1565 |
# File 'lib/aws-sdk-lambda/types.rb', line 1560 class DeleteResourcePolicyRequest < Struct.new( :resource_arn, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Delete the existing policy only if its revision ID matches the string you specify. To find the revision ID of the policy currently attached to your function, use the GetResourcePolicy action.
1560 1561 1562 1563 1564 1565 |
# File 'lib/aws-sdk-lambda/types.rb', line 1560 class DeleteResourcePolicyRequest < Struct.new( :resource_arn, :revision_id) SENSITIVE = [] include Aws::Structure end |