Class: Aws::Lambda::Types::DeleteResourcePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the function you want to delete the policy from. You can use either a qualified or an unqualified ARN, but the value you specify must be a complete ARN and wildcard characters are not accepted.

Returns:

  • (String)


1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-lambda/types.rb', line 1550

class DeleteResourcePolicyRequest < Struct.new(
  :resource_arn,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

Delete the existing policy only if its revision ID matches the string you specify. To find the revision ID of the policy currently attached to your function, use the GetResourcePolicy action.

Returns:

  • (String)


1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-lambda/types.rb', line 1550

class DeleteResourcePolicyRequest < Struct.new(
  :resource_arn,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end