Class: Aws::Lambda::Types::ENILimitReachedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Lambda couldn’t create an elastic network interface in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached. For more information, see [Lambda quotas].

[1]: docs.aws.amazon.com/lambda/latest/dg/gettingstarted-limits.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2571
2572
2573
2574
2575
2576
# File 'lib/aws-sdk-lambda/types.rb', line 2571

class ENILimitReachedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


2571
2572
2573
2574
2575
2576
# File 'lib/aws-sdk-lambda/types.rb', line 2571

class ENILimitReachedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end