Class: Aws::Lambda::Types::ENILimitReachedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ENILimitReachedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Lambda couldn’t create an elastic network interface in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached. For more information, see [Lambda quotas].
[1]: docs.aws.amazon.com/lambda/latest/dg/gettingstarted-limits.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
1692 1693 1694 1695 1696 1697 |
# File 'lib/aws-sdk-lambda/types.rb', line 1692 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
1692 1693 1694 1695 1696 1697 |
# File 'lib/aws-sdk-lambda/types.rb', line 1692 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |