Class: Aws::Lambda::Types::ENILimitReachedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ENILimitReachedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Lambda was not able to create an elastic network interface in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-lambda/types.rb', line 1877 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-lambda/types.rb', line 1877 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |