Class: Aws::Lambda::Types::ENILimitReachedException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Lambda was not able to create an elastic network interface in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


1583
1584
1585
1586
1587
1588
# File 'lib/aws-sdk-lambda/types.rb', line 1583

class ENILimitReachedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


1583
1584
1585
1586
1587
1588
# File 'lib/aws-sdk-lambda/types.rb', line 1583

class ENILimitReachedException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end