Class: Aws::Lambda::Types::ENILimitReachedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ENILimitReachedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Lambda was not able to create an elastic network interface in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
1575 1576 1577 1578 1579 1580 |
# File 'lib/aws-sdk-lambda/types.rb', line 1575 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
1575 1576 1577 1578 1579 1580 |
# File 'lib/aws-sdk-lambda/types.rb', line 1575 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |