Class: Aws::Lambda::Types::ENILimitReachedException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ENILimitReachedException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Lambda couldn't create an elastic network interface in the VPC, specified as part of Lambda function configuration, because the limit for network interfaces has been reached. For more information, see Lambda quotas.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
2751 2752 2753 2754 2755 2756 |
# File 'lib/aws-sdk-lambda/types.rb', line 2751 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
2751 2752 2753 2754 2755 2756 |
# File 'lib/aws-sdk-lambda/types.rb', line 2751 class ENILimitReachedException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |