Class: Aws::Lambda::Types::ENINotReadyException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ENINotReadyException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Lambda couldn’t invoke the Lambda function because the elastic network interface (ENI) configured for its VPC connection isn’t ready yet. Wait a few moments and try the request again. For more information about VPC configuration, see [Configuring a Lambda function to access resources in a VPC].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The exception message.
-
#type ⇒ String
The exception type.
Instance Attribute Details
#message ⇒ String
The exception message.
2687 2688 2689 2690 2691 2692 |
# File 'lib/aws-sdk-lambda/types.rb', line 2687 class ENINotReadyException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The exception type.
2687 2688 2689 2690 2691 2692 |
# File 'lib/aws-sdk-lambda/types.rb', line 2687 class ENINotReadyException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |