Class: Aws::Lambda::Types::EnvironmentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The results of an operation to update or read environment variables. If the operation succeeds, the response contains the environment variables. If it fails, the response contains details about the error.

Constant Summary collapse

SENSITIVE =
[:variables]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::EnvironmentError

Error messages for environment variables that couldn’t be applied.



1760
1761
1762
1763
1764
1765
# File 'lib/aws-sdk-lambda/types.rb', line 1760

class EnvironmentResponse < Struct.new(
  :variables,
  :error)
  SENSITIVE = [:variables]
  include Aws::Structure
end

#variablesHash<String,String>

Environment variable key-value pairs. Omitted from CloudTrail logs.

Returns:

  • (Hash<String,String>)


1760
1761
1762
1763
1764
1765
# File 'lib/aws-sdk-lambda/types.rb', line 1760

class EnvironmentResponse < Struct.new(
  :variables,
  :error)
  SENSITIVE = [:variables]
  include Aws::Structure
end