Class: Aws::Lambda::Types::EnvironmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::EnvironmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The results of an operation to update or read environment variables. If the operation succeeds, the response contains the environment variables. If it fails, the response contains details about the error.
Constant Summary collapse
- SENSITIVE =
[:variables]
Instance Attribute Summary collapse
-
#error ⇒ Types::EnvironmentError
Error messages for environment variables that couldn't be applied.
-
#variables ⇒ Hash<String,String>
Environment variable key-value pairs.
Instance Attribute Details
#error ⇒ Types::EnvironmentError
Error messages for environment variables that couldn't be applied.
1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-lambda/types.rb', line 1980 class EnvironmentResponse < Struct.new( :variables, :error) SENSITIVE = [:variables] include Aws::Structure end |
#variables ⇒ Hash<String,String>
Environment variable key-value pairs. Omitted from CloudTrail logs.
1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-lambda/types.rb', line 1980 class EnvironmentResponse < Struct.new( :variables, :error) SENSITIVE = [:variables] include Aws::Structure end |