Class: Aws::Lambda::Types::EnvironmentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The results of an operation to update or read environment variables. If the operation is successful, the response contains the environment variables. If it failed, the response contains details about the error.

Constant Summary collapse

SENSITIVE =
[:variables]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::EnvironmentError

Error messages for environment variables that couldn't be applied.



1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-lambda/types.rb', line 1961

class EnvironmentResponse < Struct.new(
  :variables,
  :error)
  SENSITIVE = [:variables]
  include Aws::Structure
end

#variablesHash<String,String>

Environment variable key-value pairs. Omitted from CloudTrail logs.

Returns:

  • (Hash<String,String>)


1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-lambda/types.rb', line 1961

class EnvironmentResponse < Struct.new(
  :variables,
  :error)
  SENSITIVE = [:variables]
  include Aws::Structure
end