Class: Aws::Lambda::Types::EnvironmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::EnvironmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The results of an operation to update or read environment variables. If the operation is successful, the response contains the environment variables. If it failed, the response contains details about the error.
Constant Summary collapse
- SENSITIVE =
[:variables]
Instance Attribute Summary collapse
-
#error ⇒ Types::EnvironmentError
Error messages for environment variables that couldn't be applied.
-
#variables ⇒ Hash<String,String>
Environment variable key-value pairs.
Instance Attribute Details
#error ⇒ Types::EnvironmentError
Error messages for environment variables that couldn't be applied.
1664 1665 1666 1667 1668 1669 |
# File 'lib/aws-sdk-lambda/types.rb', line 1664 class EnvironmentResponse < Struct.new( :variables, :error) SENSITIVE = [:variables] include Aws::Structure end |
#variables ⇒ Hash<String,String>
Environment variable key-value pairs.
1664 1665 1666 1667 1668 1669 |
# File 'lib/aws-sdk-lambda/types.rb', line 1664 class EnvironmentResponse < Struct.new( :variables, :error) SENSITIVE = [:variables] include Aws::Structure end |