Class: Aws::Lambda::Types::EventSourceMappingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

A mapping between an Amazon Web Services resource and a Lambda function. For details, see CreateEventSourceMapping.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amazon_managed_kafka_event_source_configTypes::AmazonManagedKafkaEventSourceConfig

Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#batch_sizeInteger

The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function. Lambda passes all of the records in the batch to the function in a single call, up to the payload limit for synchronous invocation (6 MB).

Default value: Varies by service. For Amazon SQS, the default is 10. For all other services, the default is 100.

Related setting: When you set `BatchSize` to a value greater than 10, you must set `MaximumBatchingWindowInSeconds` to at least 1.

Returns:

  • (Integer)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#bisect_batch_on_function_errorBoolean

(Streams only) If the function returns an error, split the batch in two and retry. The default value is false.

Returns:

  • (Boolean)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#destination_configTypes::DestinationConfig

(Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records.



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#event_source_arnString

The Amazon Resource Name (ARN) of the event source.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#filter_criteriaTypes::FilterCriteria

An object that defines the filter criteria that determine whether Lambda should process an event. For more information, see [Lambda event filtering].

[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_arnString

The ARN of the Lambda function.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_response_typesArray<String>

(Streams and Amazon SQS) A list of current response type enums applied to the event source mapping.

Returns:

  • (Array<String>)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The date that the event source mapping was last updated or that its state changed.

Returns:

  • (Time)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#last_processing_resultString

The result of the last Lambda invocation of your function.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_batching_window_in_secondsInteger

The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function. You can configure `MaximumBatchingWindowInSeconds` to any value from 0 seconds to 300 seconds in increments of seconds.

For streams and Amazon SQS event sources, the default batching window is 0 seconds. For Amazon MSK, Self-managed Apache Kafka, and Amazon MQ event sources, the default batching window is 500 ms. Note that because you can only change `MaximumBatchingWindowInSeconds` in increments of seconds, you cannot revert back to the 500 ms default batching window after you have changed it. To restore the default batching window, you must create a new event source mapping.

Related setting: For streams and Amazon SQS event sources, when you set `BatchSize` to a value greater than 10, you must set `MaximumBatchingWindowInSeconds` to at least 1.

Returns:

  • (Integer)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_record_age_in_secondsInteger

(Streams only) Discard records older than the specified age. The default value is -1, which sets the maximum age to infinite. When the value is set to infinite, Lambda never discards old records.

Returns:

  • (Integer)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_retry_attemptsInteger

(Streams only) Discard records after the specified number of retries. The default value is -1, which sets the maximum number of retries to infinite. When MaximumRetryAttempts is infinite, Lambda retries failed records until the record expires in the event source.

Returns:

  • (Integer)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#parallelization_factorInteger

(Streams only) The number of batches to process concurrently from each shard. The default value is 1.

Returns:

  • (Integer)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#queuesArray<String>

(Amazon MQ) The name of the Amazon MQ broker destination queue to consume.

Returns:

  • (Array<String>)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_event_sourceTypes::SelfManagedEventSource

The self-managed Apache Kafka cluster for your event source.



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#self_managed_kafka_event_source_configTypes::SelfManagedKafkaEventSourceConfig

Specific configuration settings for a self-managed Apache Kafka event source.



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#source_access_configurationsArray<Types::SourceAccessConfiguration>

An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.



2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#starting_positionString

The position in a stream from which to start reading. Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK stream sources. `AT_TIMESTAMP` is supported only for Amazon Kinesis streams.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#starting_position_timestampTime

With `StartingPosition` set to `AT_TIMESTAMP`, the time from which to start reading.

Returns:

  • (Time)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The state of the event source mapping. It can be one of the following: `Creating`, `Enabling`, `Enabled`, `Disabling`, `Disabled`, `Updating`, or `Deleting`.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#state_transition_reasonString

Indicates whether a user or Lambda made the last change to the event source mapping.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#topicsArray<String>

The name of the Kafka topic.

Returns:

  • (Array<String>)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#tumbling_window_in_secondsInteger

(Streams only) The duration in seconds of a processing window. The range is 1–900 seconds.

Returns:

  • (Integer)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The identifier of the event source mapping.

Returns:

  • (String)


2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/aws-sdk-lambda/types.rb', line 2165

class EventSourceMappingConfiguration < Struct.new(
  :uuid,
  :starting_position,
  :starting_position_timestamp,
  :batch_size,
  :maximum_batching_window_in_seconds,
  :parallelization_factor,
  :event_source_arn,
  :filter_criteria,
  :function_arn,
  :last_modified,
  :last_processing_result,
  :state,
  :state_transition_reason,
  :destination_config,
  :topics,
  :queues,
  :source_access_configurations,
  :self_managed_event_source,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :tumbling_window_in_seconds,
  :function_response_types,
  :amazon_managed_kafka_event_source_config,
  :self_managed_kafka_event_source_config)
  SENSITIVE = []
  include Aws::Structure
end