Class: Aws::Lambda::Types::EventSourceMappingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::EventSourceMappingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
A mapping between an Amazon Web Services resource and a Lambda function. For details, see CreateEventSourceMapping.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amazon_managed_kafka_event_source_config ⇒ Types::AmazonManagedKafkaEventSourceConfig
Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.
-
#batch_size ⇒ Integer
The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function.
-
#bisect_batch_on_function_error ⇒ Boolean
(Streams only) If the function returns an error, split the batch in two and retry.
-
#destination_config ⇒ Types::DestinationConfig
(Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records.
-
#event_source_arn ⇒ String
The Amazon Resource Name (ARN) of the event source.
-
#filter_criteria ⇒ Types::FilterCriteria
(Streams and Amazon SQS) An object that defines the filter criteria that determine whether Lambda should process an event.
-
#function_arn ⇒ String
The ARN of the Lambda function.
-
#function_response_types ⇒ Array<String>
(Streams and Amazon SQS) A list of current response type enums applied to the event source mapping.
-
#last_modified ⇒ Time
The date that the event source mapping was last updated or that its state changed.
-
#last_processing_result ⇒ String
The result of the last Lambda invocation of your function.
-
#maximum_batching_window_in_seconds ⇒ Integer
The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function.
-
#maximum_record_age_in_seconds ⇒ Integer
(Streams only) Discard records older than the specified age.
-
#maximum_retry_attempts ⇒ Integer
(Streams only) Discard records after the specified number of retries.
-
#parallelization_factor ⇒ Integer
(Streams only) The number of batches to process concurrently from each shard.
-
#queues ⇒ Array<String>
(Amazon MQ) The name of the Amazon MQ broker destination queue to consume.
-
#self_managed_event_source ⇒ Types::SelfManagedEventSource
The self-managed Apache Kafka cluster for your event source.
-
#self_managed_kafka_event_source_config ⇒ Types::SelfManagedKafkaEventSourceConfig
Specific configuration settings for a self-managed Apache Kafka event source.
-
#source_access_configurations ⇒ Array<Types::SourceAccessConfiguration>
An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.
-
#starting_position ⇒ String
The position in a stream from which to start reading.
-
#starting_position_timestamp ⇒ Time
With `StartingPosition` set to `AT_TIMESTAMP`, the time from which to start reading.
-
#state ⇒ String
The state of the event source mapping.
-
#state_transition_reason ⇒ String
Indicates whether a user or Lambda made the last change to the event source mapping.
-
#topics ⇒ Array<String>
The name of the Kafka topic.
-
#tumbling_window_in_seconds ⇒ Integer
(Streams only) The duration in seconds of a processing window.
-
#uuid ⇒ String
The identifier of the event source mapping.
Instance Attribute Details
#amazon_managed_kafka_event_source_config ⇒ Types::AmazonManagedKafkaEventSourceConfig
Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#batch_size ⇒ Integer
The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function. Lambda passes all of the records in the batch to the function in a single call, up to the payload limit for synchronous invocation (6 MB).
Default value: Varies by service. For Amazon SQS, the default is 10. For all other services, the default is 100.
Related setting: When you set `BatchSize` to a value greater than 10, you must set `MaximumBatchingWindowInSeconds` to at least 1.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#bisect_batch_on_function_error ⇒ Boolean
(Streams only) If the function returns an error, split the batch in two and retry. The default value is false.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#destination_config ⇒ Types::DestinationConfig
(Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#event_source_arn ⇒ String
The Amazon Resource Name (ARN) of the event source.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#filter_criteria ⇒ Types::FilterCriteria
(Streams and Amazon SQS) An object that defines the filter criteria that determine whether Lambda should process an event. For more information, see [Lambda event filtering].
[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#function_arn ⇒ String
The ARN of the Lambda function.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#function_response_types ⇒ Array<String>
(Streams and Amazon SQS) A list of current response type enums applied to the event source mapping.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The date that the event source mapping was last updated or that its state changed.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#last_processing_result ⇒ String
The result of the last Lambda invocation of your function.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#maximum_batching_window_in_seconds ⇒ Integer
The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function. You can configure `MaximumBatchingWindowInSeconds` to any value from 0 seconds to 300 seconds in increments of seconds.
For streams and Amazon SQS event sources, the default batching window is 0 seconds. For Amazon MSK, Self-managed Apache Kafka, and Amazon MQ event sources, the default batching window is 500 ms. Note that because you can only change `MaximumBatchingWindowInSeconds` in increments of seconds, you cannot revert back to the 500 ms default batching window after you have changed it. To restore the default batching window, you must create a new event source mapping.
Related setting: For streams and Amazon SQS event sources, when you set `BatchSize` to a value greater than 10, you must set `MaximumBatchingWindowInSeconds` to at least 1.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#maximum_record_age_in_seconds ⇒ Integer
(Streams only) Discard records older than the specified age. The default value is -1, which sets the maximum age to infinite. When the value is set to infinite, Lambda never discards old records.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#maximum_retry_attempts ⇒ Integer
(Streams only) Discard records after the specified number of retries. The default value is -1, which sets the maximum number of retries to infinite. When MaximumRetryAttempts is infinite, Lambda retries failed records until the record expires in the event source.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#parallelization_factor ⇒ Integer
(Streams only) The number of batches to process concurrently from each shard. The default value is 1.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#queues ⇒ Array<String>
(Amazon MQ) The name of the Amazon MQ broker destination queue to consume.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#self_managed_event_source ⇒ Types::SelfManagedEventSource
The self-managed Apache Kafka cluster for your event source.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#self_managed_kafka_event_source_config ⇒ Types::SelfManagedKafkaEventSourceConfig
Specific configuration settings for a self-managed Apache Kafka event source.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#source_access_configurations ⇒ Array<Types::SourceAccessConfiguration>
An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#starting_position ⇒ String
The position in a stream from which to start reading. Required for Amazon Kinesis, Amazon DynamoDB, and Amazon MSK stream sources. `AT_TIMESTAMP` is supported only for Amazon Kinesis streams.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#starting_position_timestamp ⇒ Time
With `StartingPosition` set to `AT_TIMESTAMP`, the time from which to start reading.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the event source mapping. It can be one of the following: `Creating`, `Enabling`, `Enabled`, `Disabling`, `Disabled`, `Updating`, or `Deleting`.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#state_transition_reason ⇒ String
Indicates whether a user or Lambda made the last change to the event source mapping.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#topics ⇒ Array<String>
The name of the Kafka topic.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#tumbling_window_in_seconds ⇒ Integer
(Streams only) The duration in seconds of a processing window. The range is 1–900 seconds.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |
#uuid ⇒ String
The identifier of the event source mapping.
2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 |
# File 'lib/aws-sdk-lambda/types.rb', line 2146 class EventSourceMappingConfiguration < Struct.new( :uuid, :starting_position, :starting_position_timestamp, :batch_size, :maximum_batching_window_in_seconds, :parallelization_factor, :event_source_arn, :filter_criteria, :function_arn, :last_modified, :last_processing_result, :state, :state_transition_reason, :destination_config, :topics, :queues, :source_access_configurations, :self_managed_event_source, :maximum_record_age_in_seconds, :bisect_batch_on_function_error, :maximum_retry_attempts, :tumbling_window_in_seconds, :function_response_types, :amazon_managed_kafka_event_source_config, :self_managed_kafka_event_source_config) SENSITIVE = [] include Aws::Structure end |