Class: Aws::Lambda::Types::EventSourceMappingMetricsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::EventSourceMappingMetricsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The metrics configuration for your event source. Use this configuration object to define which metrics you want your event source mapping to produce.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metrics ⇒ Array<String>
The metrics you want your event source mapping to produce, including
EventCount,ErrorCount,KafkaMetrics.
Instance Attribute Details
#metrics ⇒ Array<String>
The metrics you want your event source mapping to produce, including
EventCount, ErrorCount, KafkaMetrics.
-
EventCountto receive metrics related to the number of events processed by your event source mapping. -
ErrorCount(Amazon MSK and self-managed Apache Kafka) to receive metrics related to the number of errors in your event source mapping processing. -
KafkaMetrics(Amazon MSK and self-managed Apache Kafka) to receive metrics related to the Kafka consumers from your event source mapping.
For more information about these metrics, see Event source mapping metrics.
3368 3369 3370 3371 3372 |
# File 'lib/aws-sdk-lambda/types.rb', line 3368 class EventSourceMappingMetricsConfig < Struct.new( :metrics) SENSITIVE = [] include Aws::Structure end |