Class: Aws::Lambda::Types::EventSourceMappingMetricsConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::EventSourceMappingMetricsConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The metrics configuration for your event source. Use this configuration object to define which metrics you want your event source mapping to produce.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metrics ⇒ Array<String>
The metrics you want your event source mapping to produce.
Instance Attribute Details
#metrics ⇒ Array<String>
The metrics you want your event source mapping to produce. Include EventCount to receive event source mapping metrics related to the number of events processed by your event source mapping. For more information about these metrics, see [ Event source mapping metrics].
[1]: docs.aws.amazon.com/lambda/latest/dg/monitoring-metrics-types.html#event-source-mapping-metrics
2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-lambda/types.rb', line 2125 class EventSourceMappingMetricsConfig < Struct.new( :metrics) SENSITIVE = [] include Aws::Structure end |