Class: Aws::Lambda::Types::Execution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Information about a durable execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#durable_execution_arnString

The Amazon Resource Name (ARN) of the durable execution, if this execution is a durable execution.

Returns:

  • (String)


3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/aws-sdk-lambda/types.rb', line 3434

class Execution < Struct.new(
  :durable_execution_arn,
  :durable_execution_name,
  :function_arn,
  :status,
  :start_timestamp,
  :end_timestamp,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#durable_execution_nameString

The unique name of the durable execution, if one was provided when the execution was started.

Returns:

  • (String)


3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/aws-sdk-lambda/types.rb', line 3434

class Execution < Struct.new(
  :durable_execution_arn,
  :durable_execution_name,
  :function_arn,
  :status,
  :start_timestamp,
  :end_timestamp,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#end_timestampTime

The date and time when the durable execution ended, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

Returns:

  • (Time)


3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/aws-sdk-lambda/types.rb', line 3434

class Execution < Struct.new(
  :durable_execution_arn,
  :durable_execution_name,
  :function_arn,
  :status,
  :start_timestamp,
  :end_timestamp,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#function_arnString

The Amazon Resource Name (ARN) of the Lambda function.

Returns:

  • (String)


3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/aws-sdk-lambda/types.rb', line 3434

class Execution < Struct.new(
  :durable_execution_arn,
  :durable_execution_name,
  :function_arn,
  :status,
  :start_timestamp,
  :end_timestamp,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The ARN of the Key Management Service (KMS) customer managed key that is used to encrypt your durable execution's payload data, including input, output, and error payloads.

Returns:

  • (String)


3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/aws-sdk-lambda/types.rb', line 3434

class Execution < Struct.new(
  :durable_execution_arn,
  :durable_execution_name,
  :function_arn,
  :status,
  :start_timestamp,
  :end_timestamp,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#start_timestampTime

The date and time when the durable execution started, in ISO-8601 format (YYYY-MM-DDThh:mm:ss.sTZD).

Returns:

  • (Time)


3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/aws-sdk-lambda/types.rb', line 3434

class Execution < Struct.new(
  :durable_execution_arn,
  :durable_execution_name,
  :function_arn,
  :status,
  :start_timestamp,
  :end_timestamp,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the durable execution.

Returns:

  • (String)


3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
# File 'lib/aws-sdk-lambda/types.rb', line 3434

class Execution < Struct.new(
  :durable_execution_arn,
  :durable_execution_name,
  :function_arn,
  :status,
  :start_timestamp,
  :end_timestamp,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end