Class: Aws::Lambda::Types::FunctionCodeLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Details about a function's deployment package.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_uriString

URI of a container image in the Amazon ECR registry.

Returns:

  • (String)


1999
2000
2001
2002
2003
2004
2005
2006
# File 'lib/aws-sdk-lambda/types.rb', line 1999

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

A presigned URL that you can use to download the deployment package.

Returns:

  • (String)


1999
2000
2001
2002
2003
2004
2005
2006
# File 'lib/aws-sdk-lambda/types.rb', line 1999

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri)
  SENSITIVE = []
  include Aws::Structure
end

#repository_typeString

The service that's hosting the file.

Returns:

  • (String)


1999
2000
2001
2002
2003
2004
2005
2006
# File 'lib/aws-sdk-lambda/types.rb', line 1999

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri)
  SENSITIVE = []
  include Aws::Structure
end

#resolved_image_uriString

The resolved URI for the image.

Returns:

  • (String)


1999
2000
2001
2002
2003
2004
2005
2006
# File 'lib/aws-sdk-lambda/types.rb', line 1999

class FunctionCodeLocation < Struct.new(
  :repository_type,
  :location,
  :image_uri,
  :resolved_image_uri)
  SENSITIVE = []
  include Aws::Structure
end