Class: Aws::Lambda::Types::FunctionCodeLocationError
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::FunctionCodeLocationError
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Contains details about an error that occurred when Lambda attempted to retrieve a function's deployment package.
Constant Summary collapse
- SENSITIVE =
[:message]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code that identifies why Lambda failed to retrieve the deployment package.
-
#message ⇒ String
The human-readable message that describes why Lambda failed to retrieve the deployment package.
Instance Attribute Details
#error_code ⇒ String
The error code that identifies why Lambda failed to retrieve the deployment package.
3826 3827 3828 3829 3830 3831 |
# File 'lib/aws-sdk-lambda/types.rb', line 3826 class FunctionCodeLocationError < Struct.new( :error_code, :message) SENSITIVE = [:message] include Aws::Structure end |
#message ⇒ String
The human-readable message that describes why Lambda failed to retrieve the deployment package.
3826 3827 3828 3829 3830 3831 |
# File 'lib/aws-sdk-lambda/types.rb', line 3826 class FunctionCodeLocationError < Struct.new( :error_code, :message) SENSITIVE = [:message] include Aws::Structure end |