Class: Aws::Lambda::Types::FunctionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::FunctionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Details about a function’s configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architectures ⇒ Array<String>
The instruction set architecture that the function supports.
-
#capacity_provider_config ⇒ Types::CapacityProviderConfig
Configuration for the capacity provider that manages compute resources for Lambda functions.
-
#code_sha_256 ⇒ String
The SHA256 hash of the function’s deployment package.
-
#code_size ⇒ Integer
The size of the function’s deployment package, in bytes.
-
#config_sha_256 ⇒ String
The SHA256 hash of the function configuration.
-
#dead_letter_config ⇒ Types::DeadLetterConfig
The function’s dead letter queue.
-
#description ⇒ String
The function’s description.
-
#environment ⇒ Types::EnvironmentResponse
The function’s [environment variables].
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function’s ‘/tmp` directory in MB.
-
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an [Amazon EFS file system].
-
#function_arn ⇒ String
The function’s Amazon Resource Name (ARN).
-
#function_name ⇒ String
The name of the function.
-
#handler ⇒ String
The function that Lambda calls to begin running your function.
-
#image_config_response ⇒ Types::ImageConfigResponse
The function’s image configuration values.
-
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that’s used to encrypt the following resources:.
-
#last_modified ⇒ Time
The date and time that the function was last updated, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).
-
#last_update_status ⇒ String
The status of the last update that was performed on the function.
-
#last_update_status_reason ⇒ String
The reason for the last update that was performed on the function.
-
#last_update_status_reason_code ⇒ String
The reason code for the last update that was performed on the function.
-
#layers ⇒ Array<Types::Layer>
The function’s [layers].
-
#logging_config ⇒ Types::LoggingConfig
The function’s Amazon CloudWatch Logs configuration settings.
-
#master_arn ⇒ String
For Lambda@Edge functions, the ARN of the main function.
-
#memory_size ⇒ Integer
The amount of memory available to the function at runtime.
-
#package_type ⇒ String
The type of deployment package.
-
#revision_id ⇒ String
The latest updated revision of the function or alias.
-
#role ⇒ String
The function’s execution role.
-
#runtime ⇒ String
The identifier of the function’s [ runtime].
-
#runtime_version_config ⇒ Types::RuntimeVersionConfig
The ARN of the runtime and any errors that occured.
-
#signing_job_arn ⇒ String
The ARN of the signing job.
-
#signing_profile_version_arn ⇒ String
The ARN of the signing profile version.
-
#snap_start ⇒ Types::SnapStartResponse
Set ‘ApplyOn` to `PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version.
-
#state ⇒ String
The current state of the function.
-
#state_reason ⇒ String
The reason for the function’s current state.
-
#state_reason_code ⇒ String
The reason code for the function’s current state.
-
#tenancy_config ⇒ Types::TenancyConfig
The function’s tenant isolation configuration settings.
-
#timeout ⇒ Integer
The amount of time in seconds that Lambda allows a function to run before stopping it.
-
#tracing_config ⇒ Types::TracingConfigResponse
The function’s X-Ray tracing configuration.
-
#version ⇒ String
The version of the Lambda function.
-
#vpc_config ⇒ Types::VpcConfigResponse
The function’s networking configuration.
Instance Attribute Details
#architectures ⇒ Array<String>
The instruction set architecture that the function supports. Architecture is a string array with one of the valid values. The default architecture value is ‘x86_64`.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#capacity_provider_config ⇒ Types::CapacityProviderConfig
Configuration for the capacity provider that manages compute resources for Lambda functions.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#code_sha_256 ⇒ String
The SHA256 hash of the function’s deployment package.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#code_size ⇒ Integer
The size of the function’s deployment package, in bytes.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#config_sha_256 ⇒ String
The SHA256 hash of the function configuration.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#dead_letter_config ⇒ Types::DeadLetterConfig
The function’s dead letter queue.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The function’s description.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Types::EnvironmentResponse
The function’s [environment variables]. Omitted from CloudTrail logs.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function’s ‘/tmp` directory in MB. The default value is 512, but can be any whole number between 512 and 10,240 MB. For more information, see [Configuring ephemeral storage (console)].
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an [Amazon EFS file system].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-filesystem.html
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#function_arn ⇒ String
The function’s Amazon Resource Name (ARN).
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#handler ⇒ String
The function that Lambda calls to begin running your function.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#image_config_response ⇒ Types::ImageConfigResponse
The function’s image configuration values.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that’s used to encrypt the following resources:
-
The function’s [environment variables].
-
The function’s [Lambda SnapStart] snapshots.
-
When used with ‘SourceKMSKeyArn`, the unzipped version of the .zip deployment package that’s used for function invocations. For more information, see [ Specifying a customer managed key for Lambda].
-
The optimized version of the container image that’s used for function invocations. Note that this is not the same key that’s used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see [Function lifecycle].
If you don’t provide a customer managed key, Lambda uses an [Amazon Web Services owned key] or an [Amazon Web Services managed key].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html#configuration-envvars-encryption [2]: docs.aws.amazon.com/lambda/latest/dg/snapstart-security.html [3]: docs.aws.amazon.com/lambda/latest/dg/encrypt-zip-package.html#enable-zip-custom-encryption [4]: docs.aws.amazon.com/lambda/latest/dg/images-create.html#images-lifecycle [5]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk [6]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The date and time that the function was last updated, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#last_update_status ⇒ String
The status of the last update that was performed on the function. This is first set to ‘Successful` after function creation completes.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#last_update_status_reason ⇒ String
The reason for the last update that was performed on the function.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#last_update_status_reason_code ⇒ String
The reason code for the last update that was performed on the function.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#layers ⇒ Array<Types::Layer>
The function’s [layers].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#logging_config ⇒ Types::LoggingConfig
The function’s Amazon CloudWatch Logs configuration settings.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#master_arn ⇒ String
For Lambda@Edge functions, the ARN of the main function.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#memory_size ⇒ Integer
The amount of memory available to the function at runtime.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#package_type ⇒ String
The type of deployment package. Set to ‘Image` for container image and set `Zip` for .zip file archive.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The latest updated revision of the function or alias.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The function’s execution role.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
The identifier of the function’s [ runtime]. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you’re deploying a function using a container image.
The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see [Runtime use after deprecation].
For a list of all currently supported runtimes, see [Supported runtimes].
[1]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html [2]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtime-deprecation-levels [3]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtimes-supported
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#runtime_version_config ⇒ Types::RuntimeVersionConfig
The ARN of the runtime and any errors that occured.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#signing_job_arn ⇒ String
The ARN of the signing job.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#signing_profile_version_arn ⇒ String
The ARN of the signing profile version.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#snap_start ⇒ Types::SnapStartResponse
Set ‘ApplyOn` to `PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version. For more information, see [Improving startup performance with Lambda SnapStart].
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the function. When the state is ‘Inactive`, you can reactivate the function by invoking it.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the function’s current state.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#state_reason_code ⇒ String
The reason code for the function’s current state. When the code is ‘Creating`, you can’t invoke or modify the function.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#tenancy_config ⇒ Types::TenancyConfig
The function’s tenant isolation configuration settings. Determines whether the Lambda function runs on a shared or dedicated infrastructure per unique tenant.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The amount of time in seconds that Lambda allows a function to run before stopping it.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#tracing_config ⇒ Types::TracingConfigResponse
The function’s X-Ray tracing configuration.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the Lambda function.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfigResponse
The function’s networking configuration.
2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 |
# File 'lib/aws-sdk-lambda/types.rb', line 2865 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage, :snap_start, :runtime_version_config, :logging_config, :capacity_provider_config, :config_sha_256, :tenancy_config) SENSITIVE = [] include Aws::Structure end |