Class: Aws::Lambda::Types::FunctionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Details about a function's configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#architecturesArray<String>

The instruction set architecture that the function supports. Architecture is a string array with one of the valid values. The default architecture value is `x86_64`.

Returns:

  • (Array<String>)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#code_sha_256String

The SHA256 hash of the function's deployment package.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#code_sizeInteger

The size of the function's deployment package, in bytes.

Returns:

  • (Integer)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#dead_letter_configTypes::DeadLetterConfig

The function's dead letter queue.



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The function's description.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#environmentTypes::EnvironmentResponse

The function's [environment variables]. Omitted from CloudTrail logs.

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeral_storageTypes::EphemeralStorage

The size of the function’s `/tmp` directory in MB. The default value is 512, but it can be any whole number between 512 and 10,240 MB.



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_configsArray<Types::FileSystemConfig>

Connection settings for an [Amazon EFS file system].

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-filesystem.html

Returns:



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#function_arnString

The function's Amazon Resource Name (ARN).

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#handlerString

The function that Lambda calls to begin running your function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#image_config_responseTypes::ImageConfigResponse

The function's image configuration values.



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The KMS key that's used to encrypt the function's environment variables. This key is returned only if you've configured a customer managed key.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#last_modifiedTime

The date and time that the function was last updated, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).

[1]: www.w3.org/TR/NOTE-datetime

Returns:

  • (Time)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_statusString

The status of the last update that was performed on the function. This is first set to `Successful` after function creation completes.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_status_reasonString

The reason for the last update that was performed on the function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_status_reason_codeString

The reason code for the last update that was performed on the function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#layersArray<Types::Layer>

Returns:



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#master_arnString

For Lambda@Edge functions, the ARN of the main function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#memory_sizeInteger

The amount of memory available to the function at runtime.

Returns:

  • (Integer)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#package_typeString

The type of deployment package. Set to `Image` for container image and set `Zip` for .zip file archive.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

The latest updated revision of the function or alias.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The function's execution role.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

The runtime environment for the Lambda function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#signing_job_arnString

The ARN of the signing job.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#signing_profile_version_arnString

The ARN of the signing profile version.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#snap_startTypes::SnapStartResponse

Set `ApplyOn` to `PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version. For more information, see [Reducing startup time with Lambda SnapStart].

[1]: docs.aws.amazon.com/lambda/latest/dg/snapstart.html



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#stateString

The current state of the function. When the state is `Inactive`, you can reactivate the function by invoking it.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#state_reasonString

The reason for the function's current state.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#state_reason_codeString

The reason code for the function's current state. When the code is `Creating`, you can't invoke or modify the function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The amount of time in seconds that Lambda allows a function to run before stopping it.

Returns:

  • (Integer)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#tracing_configTypes::TracingConfigResponse

The function's X-Ray tracing configuration.



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the Lambda function.

Returns:

  • (String)


2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfigResponse

The function's networking configuration.



2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/aws-sdk-lambda/types.rb', line 2541

class FunctionConfiguration < Struct.new(
  :function_name,
  :function_arn,
  :runtime,
  :role,
  :handler,
  :code_size,
  :description,
  :timeout,
  :memory_size,
  :last_modified,
  :code_sha_256,
  :version,
  :vpc_config,
  :dead_letter_config,
  :environment,
  :kms_key_arn,
  :tracing_config,
  :master_arn,
  :revision_id,
  :layers,
  :state,
  :state_reason,
  :state_reason_code,
  :last_update_status,
  :last_update_status_reason,
  :last_update_status_reason_code,
  :file_system_configs,
  :package_type,
  :image_config_response,
  :signing_profile_version_arn,
  :signing_job_arn,
  :architectures,
  :ephemeral_storage,
  :snap_start)
  SENSITIVE = []
  include Aws::Structure
end