Class: Aws::Lambda::Types::FunctionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::FunctionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Details about a function's configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#architectures ⇒ Array<String>
The instruction set architecture that the function supports.
-
#code_sha_256 ⇒ String
The SHA256 hash of the function's deployment package.
-
#code_size ⇒ Integer
The size of the function's deployment package, in bytes.
-
#dead_letter_config ⇒ Types::DeadLetterConfig
The function's dead letter queue.
-
#description ⇒ String
The function's description.
-
#environment ⇒ Types::EnvironmentResponse
The function's [environment variables].
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function’s /tmp directory in MB.
-
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an [Amazon EFS file system].
-
#function_arn ⇒ String
The function's Amazon Resource Name (ARN).
-
#function_name ⇒ String
The name of the function.
-
#handler ⇒ String
The function that Lambda calls to begin executing your function.
-
#image_config_response ⇒ Types::ImageConfigResponse
The function's image configuration values.
-
#kms_key_arn ⇒ String
The KMS key that's used to encrypt the function's environment variables.
-
#last_modified ⇒ Time
The date and time that the function was last updated, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).
-
#last_update_status ⇒ String
The status of the last update that was performed on the function.
-
#last_update_status_reason ⇒ String
The reason for the last update that was performed on the function.
-
#last_update_status_reason_code ⇒ String
The reason code for the last update that was performed on the function.
-
#layers ⇒ Array<Types::Layer>
The function's [ layers].
-
#master_arn ⇒ String
For Lambda@Edge functions, the ARN of the main function.
-
#memory_size ⇒ Integer
The amount of memory available to the function at runtime.
-
#package_type ⇒ String
The type of deployment package.
-
#revision_id ⇒ String
The latest updated revision of the function or alias.
-
#role ⇒ String
The function's execution role.
-
#runtime ⇒ String
The runtime environment for the Lambda function.
-
#signing_job_arn ⇒ String
The ARN of the signing job.
-
#signing_profile_version_arn ⇒ String
The ARN of the signing profile version.
-
#state ⇒ String
The current state of the function.
-
#state_reason ⇒ String
The reason for the function's current state.
-
#state_reason_code ⇒ String
The reason code for the function's current state.
-
#timeout ⇒ Integer
The amount of time in seconds that Lambda allows a function to run before stopping it.
-
#tracing_config ⇒ Types::TracingConfigResponse
The function's X-Ray tracing configuration.
-
#version ⇒ String
The version of the Lambda function.
-
#vpc_config ⇒ Types::VpcConfigResponse
The function's networking configuration.
Instance Attribute Details
#architectures ⇒ Array<String>
The instruction set architecture that the function supports. Architecture is a string array with one of the valid values. The default architecture value is `x86_64`.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#code_sha_256 ⇒ String
The SHA256 hash of the function's deployment package.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#code_size ⇒ Integer
The size of the function's deployment package, in bytes.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#dead_letter_config ⇒ Types::DeadLetterConfig
The function's dead letter queue.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The function's description.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Types::EnvironmentResponse
The function's [environment variables]. Omitted from CloudTrail logs.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function’s /tmp directory in MB. The default value is 512, but can be any whole number between 512 and 10240 MB.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an [Amazon EFS file system].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-filesystem.html
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#function_arn ⇒ String
The function's Amazon Resource Name (ARN).
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#handler ⇒ String
The function that Lambda calls to begin executing your function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#image_config_response ⇒ Types::ImageConfigResponse
The function's image configuration values.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The KMS key that's used to encrypt the function's environment variables. This key is only returned if you've configured a customer managed key.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The date and time that the function was last updated, in [ISO-8601 format] (YYYY-MM-DDThh:mm:ss.sTZD).
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#last_update_status ⇒ String
The status of the last update that was performed on the function. This is first set to `Successful` after function creation completes.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#last_update_status_reason ⇒ String
The reason for the last update that was performed on the function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#last_update_status_reason_code ⇒ String
The reason code for the last update that was performed on the function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#layers ⇒ Array<Types::Layer>
The function's [ layers].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#master_arn ⇒ String
For Lambda@Edge functions, the ARN of the main function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#memory_size ⇒ Integer
The amount of memory available to the function at runtime.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#package_type ⇒ String
The type of deployment package. Set to `Image` for container image and set `Zip` for .zip file archive.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The latest updated revision of the function or alias.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The function's execution role.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
The runtime environment for the Lambda function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#signing_job_arn ⇒ String
The ARN of the signing job.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#signing_profile_version_arn ⇒ String
The ARN of the signing profile version.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the function. When the state is `Inactive`, you can reactivate the function by invoking it.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#state_reason ⇒ String
The reason for the function's current state.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#state_reason_code ⇒ String
The reason code for the function's current state. When the code is `Creating`, you can't invoke or modify the function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The amount of time in seconds that Lambda allows a function to run before stopping it.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#tracing_config ⇒ Types::TracingConfigResponse
The function's X-Ray tracing configuration.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the Lambda function.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfigResponse
The function's networking configuration.
2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/aws-sdk-lambda/types.rb', line 2512 class FunctionConfiguration < Struct.new( :function_name, :function_arn, :runtime, :role, :handler, :code_size, :description, :timeout, :memory_size, :last_modified, :code_sha_256, :version, :vpc_config, :dead_letter_config, :environment, :kms_key_arn, :tracing_config, :master_arn, :revision_id, :layers, :state, :state_reason, :state_reason_code, :last_update_status, :last_update_status_reason, :last_update_status_reason_code, :file_system_configs, :package_type, :image_config_response, :signing_profile_version_arn, :signing_job_arn, :architectures, :ephemeral_storage) SENSITIVE = [] include Aws::Structure end |