Class: Aws::Lambda::Types::GetDurableExecutionHistoryRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetDurableExecutionHistoryRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
-
#include_execution_data ⇒ Boolean
Specifies whether to include execution data such as step results and callback payloads in the history events.
-
#marker ⇒ String
If ‘NextMarker` was returned from a previous request, use this value to retrieve the next page of results.
-
#max_items ⇒ Integer
The maximum number of history events to return per call.
-
#reverse_order ⇒ Boolean
When set to ‘true`, returns the history events in reverse chronological order (newest first).
Instance Attribute Details
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
4219 4220 4221 4222 4223 4224 4225 4226 4227 |
# File 'lib/aws-sdk-lambda/types.rb', line 4219 class GetDurableExecutionHistoryRequest < Struct.new( :durable_execution_arn, :include_execution_data, :max_items, :marker, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#include_execution_data ⇒ Boolean
Specifies whether to include execution data such as step results and callback payloads in the history events. Set to ‘true` to include data, or `false` to exclude it for a more compact response. The default is `true`.
4219 4220 4221 4222 4223 4224 4225 4226 4227 |
# File 'lib/aws-sdk-lambda/types.rb', line 4219 class GetDurableExecutionHistoryRequest < Struct.new( :durable_execution_arn, :include_execution_data, :max_items, :marker, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
If ‘NextMarker` was returned from a previous request, use this value to retrieve the next page of results. Each pagination token expires after 24 hours.
4219 4220 4221 4222 4223 4224 4225 4226 4227 |
# File 'lib/aws-sdk-lambda/types.rb', line 4219 class GetDurableExecutionHistoryRequest < Struct.new( :durable_execution_arn, :include_execution_data, :max_items, :marker, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of history events to return per call. You can use ‘Marker` to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.
4219 4220 4221 4222 4223 4224 4225 4226 4227 |
# File 'lib/aws-sdk-lambda/types.rb', line 4219 class GetDurableExecutionHistoryRequest < Struct.new( :durable_execution_arn, :include_execution_data, :max_items, :marker, :reverse_order) SENSITIVE = [] include Aws::Structure end |
#reverse_order ⇒ Boolean
When set to ‘true`, returns the history events in reverse chronological order (newest first). By default, events are returned in chronological order (oldest first).
4219 4220 4221 4222 4223 4224 4225 4226 4227 |
# File 'lib/aws-sdk-lambda/types.rb', line 4219 class GetDurableExecutionHistoryRequest < Struct.new( :durable_execution_arn, :include_execution_data, :max_items, :marker, :reverse_order) SENSITIVE = [] include Aws::Structure end |