Class: Aws::Lambda::Types::GetDurableExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetDurableExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The response from the GetDurableExecution operation, containing detailed information about the durable execution.
Constant Summary collapse
- SENSITIVE =
[:input_payload, :result]
Instance Attribute Summary collapse
-
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
-
#durable_execution_name ⇒ String
The name of the durable execution.
-
#end_timestamp ⇒ Time
The date and time when the durable execution ended, in Unix timestamp format.
-
#error ⇒ Types::ErrorObject
Error information if the durable execution failed.
-
#function_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function that was invoked to start this durable execution.
-
#input_payload ⇒ String
The JSON input payload that was provided when the durable execution was started.
-
#result ⇒ String
The JSON result returned by the durable execution if it completed successfully.
-
#start_timestamp ⇒ Time
The date and time when the durable execution started, in Unix timestamp format.
-
#status ⇒ String
The current status of the durable execution.
-
#trace_header ⇒ Types::TraceHeader
The trace headers associated with the durable execution.
-
#version ⇒ String
The version of the Lambda function that was invoked for this durable execution.
Instance Attribute Details
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#durable_execution_name ⇒ String
The name of the durable execution. This is either the name you provided when invoking the function, or a system-generated unique identifier if no name was provided.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#end_timestamp ⇒ Time
The date and time when the durable execution ended, in Unix timestamp format. This field is only present if the execution has completed (status is ‘SUCCEEDED`, `FAILED`, `TIMED_OUT`, or `STOPPED`).
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#error ⇒ Types::ErrorObject
Error information if the durable execution failed. This field is only present when the execution status is ‘FAILED`, `TIMED_OUT`, or `STOPPED`. The combined size of all error fields is limited to 256 KB.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#function_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function that was invoked to start this durable execution.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#input_payload ⇒ String
The JSON input payload that was provided when the durable execution was started. For asynchronous invocations, this is limited to 256 KB. For synchronous invocations, this can be up to 6 MB.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#result ⇒ String
The JSON result returned by the durable execution if it completed successfully. This field is only present when the execution status is ‘SUCCEEDED`. The result is limited to 256 KB.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#start_timestamp ⇒ Time
The date and time when the durable execution started, in Unix timestamp format.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#status ⇒ String
The current status of the durable execution. Valid values are ‘RUNNING`, `SUCCEEDED`, `FAILED`, `TIMED_OUT`, and `STOPPED`.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#trace_header ⇒ Types::TraceHeader
The trace headers associated with the durable execution.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |
#version ⇒ String
The version of the Lambda function that was invoked for this durable execution. This ensures that all replays during the execution use the same function version.
4460 4461 4462 4463 4464 4465 4466 4467 4468 4469 4470 4471 4472 4473 4474 |
# File 'lib/aws-sdk-lambda/types.rb', line 4460 class GetDurableExecutionResponse < Struct.new( :durable_execution_arn, :durable_execution_name, :function_arn, :input_payload, :result, :error, :start_timestamp, :status, :end_timestamp, :version, :trace_header) SENSITIVE = [:input_payload, :result] include Aws::Structure end |