Class: Aws::Lambda::Types::GetDurableExecutionStateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetDurableExecutionStateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#checkpoint_token ⇒ String
A checkpoint token that identifies the current state of the execution.
-
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
-
#marker ⇒ String
If ‘NextMarker` was returned from a previous request, use this value to retrieve the next page of operations.
-
#max_items ⇒ Integer
The maximum number of operations to return per call.
Instance Attribute Details
#checkpoint_token ⇒ String
A checkpoint token that identifies the current state of the execution. This token is provided by the Lambda runtime and ensures that state retrieval is consistent with the current execution context.
4385 4386 4387 4388 4389 4390 4391 4392 |
# File 'lib/aws-sdk-lambda/types.rb', line 4385 class GetDurableExecutionStateRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#durable_execution_arn ⇒ String
The Amazon Resource Name (ARN) of the durable execution.
4385 4386 4387 4388 4389 4390 4391 4392 |
# File 'lib/aws-sdk-lambda/types.rb', line 4385 class GetDurableExecutionStateRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
If ‘NextMarker` was returned from a previous request, use this value to retrieve the next page of operations. Each pagination token expires after 24 hours.
4385 4386 4387 4388 4389 4390 4391 4392 |
# File 'lib/aws-sdk-lambda/types.rb', line 4385 class GetDurableExecutionStateRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
The maximum number of operations to return per call. You can use ‘Marker` to retrieve additional pages of results. The default is 100 and the maximum allowed is 1000. A value of 0 uses the default.
4385 4386 4387 4388 4389 4390 4391 4392 |
# File 'lib/aws-sdk-lambda/types.rb', line 4385 class GetDurableExecutionStateRequest < Struct.new( :durable_execution_arn, :checkpoint_token, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |