Class: Aws::Lambda::Types::GetDurableExecutionStateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetDurableExecutionStateResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The response from the GetDurableExecutionState operation, containing the current execution state for replay.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
If present, indicates that more operations are available.
-
#operations ⇒ Array<Types::Operation>
An array of operations that represent the current state of the durable execution.
Instance Attribute Details
#next_marker ⇒ String
If present, indicates that more operations are available. Use this value as the ‘Marker` parameter in a subsequent request to retrieve the next page of results.
4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-lambda/types.rb', line 4412 class GetDurableExecutionStateResponse < Struct.new( :operations, :next_marker) SENSITIVE = [] include Aws::Structure end |
#operations ⇒ Array<Types::Operation>
An array of operations that represent the current state of the durable execution. Operations are ordered by their start sequence number in ascending order and include information needed for replay processing.
4412 4413 4414 4415 4416 4417 |
# File 'lib/aws-sdk-lambda/types.rb', line 4412 class GetDurableExecutionStateResponse < Struct.new( :operations, :next_marker) SENSITIVE = [] include Aws::Structure end |