Class: Aws::Lambda::Types::GetFunctionEventInvokeConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetFunctionEventInvokeConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name of the Lambda function, version, or alias.
-
#qualifier ⇒ String
A version number or alias name.
Instance Attribute Details
#function_name ⇒ String
The name of the Lambda function, version, or alias.
**Name formats**
-
**Function name** - ‘my-function` (name-only), `my-function:v1` (with alias).
-
**Function ARN** - ‘arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** - ‘123456789012:function:my-function`.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
2739 2740 2741 2742 2743 2744 |
# File 'lib/aws-sdk-lambda/types.rb', line 2739 class GetFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
A version number or alias name.
2739 2740 2741 2742 2743 2744 |
# File 'lib/aws-sdk-lambda/types.rb', line 2739 class GetFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier) SENSITIVE = [] include Aws::Structure end |