Class: Aws::Lambda::Types::GetFunctionEventInvokeConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_nameString

The name or ARN of the Lambda function, version, or alias.

**Name formats**

  • **Function name** - my-function (name-only), my-function:v1 (with alias).

  • **Function ARN** - arn:aws:lambda:us-west-2:123456789012:function:my-function.

  • **Partial ARN** - 123456789012:function:my-function.

You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


2955
2956
2957
2958
2959
2960
# File 'lib/aws-sdk-lambda/types.rb', line 2955

class GetFunctionEventInvokeConfigRequest < Struct.new(
  :function_name,
  :qualifier)
  SENSITIVE = []
  include Aws::Structure
end

#qualifierString

A version number or alias name.

Returns:

  • (String)


2955
2956
2957
2958
2959
2960
# File 'lib/aws-sdk-lambda/types.rb', line 2955

class GetFunctionEventInvokeConfigRequest < Struct.new(
  :function_name,
  :qualifier)
  SENSITIVE = []
  include Aws::Structure
end