Class: Aws::Lambda::Types::GetProvisionedConcurrencyConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::GetProvisionedConcurrencyConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_provisioned_concurrent_executions ⇒ Integer
The amount of provisioned concurrency allocated.
-
#available_provisioned_concurrent_executions ⇒ Integer
The amount of provisioned concurrency available.
-
#last_modified ⇒ Time
The date and time that a user last updated the configuration, in [ISO 8601 format].
-
#requested_provisioned_concurrent_executions ⇒ Integer
The amount of provisioned concurrency requested.
-
#status ⇒ String
The status of the allocation process.
-
#status_reason ⇒ String
For failed allocations, the reason that provisioned concurrency could not be allocated.
Instance Attribute Details
#allocated_provisioned_concurrent_executions ⇒ Integer
The amount of provisioned concurrency allocated. When a weighted alias is used during linear and canary deployments, this value fluctuates depending on the amount of concurrency that is provisioned for the function versions.
2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-lambda/types.rb', line 2966 class GetProvisionedConcurrencyConfigResponse < Struct.new( :requested_provisioned_concurrent_executions, :available_provisioned_concurrent_executions, :allocated_provisioned_concurrent_executions, :status, :status_reason, :last_modified) SENSITIVE = [] include Aws::Structure end |
#available_provisioned_concurrent_executions ⇒ Integer
The amount of provisioned concurrency available.
2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-lambda/types.rb', line 2966 class GetProvisionedConcurrencyConfigResponse < Struct.new( :requested_provisioned_concurrent_executions, :available_provisioned_concurrent_executions, :allocated_provisioned_concurrent_executions, :status, :status_reason, :last_modified) SENSITIVE = [] include Aws::Structure end |
#last_modified ⇒ Time
The date and time that a user last updated the configuration, in [ISO 8601 format].
2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-lambda/types.rb', line 2966 class GetProvisionedConcurrencyConfigResponse < Struct.new( :requested_provisioned_concurrent_executions, :available_provisioned_concurrent_executions, :allocated_provisioned_concurrent_executions, :status, :status_reason, :last_modified) SENSITIVE = [] include Aws::Structure end |
#requested_provisioned_concurrent_executions ⇒ Integer
The amount of provisioned concurrency requested.
2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-lambda/types.rb', line 2966 class GetProvisionedConcurrencyConfigResponse < Struct.new( :requested_provisioned_concurrent_executions, :available_provisioned_concurrent_executions, :allocated_provisioned_concurrent_executions, :status, :status_reason, :last_modified) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the allocation process.
2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-lambda/types.rb', line 2966 class GetProvisionedConcurrencyConfigResponse < Struct.new( :requested_provisioned_concurrent_executions, :available_provisioned_concurrent_executions, :allocated_provisioned_concurrent_executions, :status, :status_reason, :last_modified) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
For failed allocations, the reason that provisioned concurrency could not be allocated.
2966 2967 2968 2969 2970 2971 2972 2973 2974 2975 |
# File 'lib/aws-sdk-lambda/types.rb', line 2966 class GetProvisionedConcurrencyConfigResponse < Struct.new( :requested_provisioned_concurrent_executions, :available_provisioned_concurrent_executions, :allocated_provisioned_concurrent_executions, :status, :status_reason, :last_modified) SENSITIVE = [] include Aws::Structure end |