Class: Aws::Lambda::Types::InvalidCodeSignatureException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The code signature failed the integrity check. If the integrity check fails, then Lambda blocks deployment, even if the code signing policy is set to WARN.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3327
3328
3329
3330
3331
3332
# File 'lib/aws-sdk-lambda/types.rb', line 3327

class InvalidCodeSignatureException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


3327
3328
3329
3330
3331
3332
# File 'lib/aws-sdk-lambda/types.rb', line 3327

class InvalidCodeSignatureException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end