Class: Aws::Lambda::Types::InvalidCodeSignatureException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The code signature failed the integrity check. If the integrity check fails, then Lambda blocks deployment, even if the code signing policy is set to WARN.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3266
3267
3268
3269
3270
3271
# File 'lib/aws-sdk-lambda/types.rb', line 3266

class InvalidCodeSignatureException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


3266
3267
3268
3269
3270
3271
# File 'lib/aws-sdk-lambda/types.rb', line 3266

class InvalidCodeSignatureException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end