Class: Aws::Lambda::Types::KMSInvalidStateException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Lambda was unable to decrypt the environment variables because the KMS key used is in an invalid state for Decrypt. Check the function's KMS key settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


3319
3320
3321
3322
3323
3324
# File 'lib/aws-sdk-lambda/types.rb', line 3319

class KMSInvalidStateException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


3319
3320
3321
3322
3323
3324
# File 'lib/aws-sdk-lambda/types.rb', line 3319

class KMSInvalidStateException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end