Class: Aws::Lambda::Types::KafkaSchemaValidationConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Specific schema validation configuration settings that tell Lambda the message attributes you want to validate and filter using your schema registry.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributeString

The attributes you want your schema registry to validate and filter for. If you selected JSON as the EventRecordFormat, Lambda also deserializes the selected message attributes.

Returns:

  • (String)


6048
6049
6050
6051
6052
# File 'lib/aws-sdk-lambda/types.rb', line 6048

class KafkaSchemaValidationConfig < Struct.new(
  :attribute)
  SENSITIVE = []
  include Aws::Structure
end