Class: Aws::Lambda::Types::LoggingConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The function’s Amazon CloudWatch Logs configuration settings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_log_levelString

Set this property to filter the application logs for your function that Lambda sends to CloudWatch. Lambda only sends application logs at the selected level of detail and lower, where ‘TRACE` is the highest level and `FATAL` is the lowest.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
# File 'lib/aws-sdk-lambda/types.rb', line 4723

class LoggingConfig < Struct.new(
  :log_format,
  :application_log_level,
  :system_log_level,
  :log_group)
  SENSITIVE = []
  include Aws::Structure
end

#log_formatString

The format in which Lambda sends your function’s application and system logs to CloudWatch. Select between plain text and structured JSON.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
# File 'lib/aws-sdk-lambda/types.rb', line 4723

class LoggingConfig < Struct.new(
  :log_format,
  :application_log_level,
  :system_log_level,
  :log_group)
  SENSITIVE = []
  include Aws::Structure
end

#log_groupString

The name of the Amazon CloudWatch log group the function sends logs to. By default, Lambda functions send logs to a default log group named ‘/aws/lambda/<function name>`. To use a different log group, enter an existing log group or enter a new log group name.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
# File 'lib/aws-sdk-lambda/types.rb', line 4723

class LoggingConfig < Struct.new(
  :log_format,
  :application_log_level,
  :system_log_level,
  :log_group)
  SENSITIVE = []
  include Aws::Structure
end

#system_log_levelString

Set this property to filter the system logs for your function that Lambda sends to CloudWatch. Lambda only sends system logs at the selected level of detail and lower, where ‘DEBUG` is the highest level and `WARN` is the lowest.

Returns:

  • (String)


4723
4724
4725
4726
4727
4728
4729
4730
# File 'lib/aws-sdk-lambda/types.rb', line 4723

class LoggingConfig < Struct.new(
  :log_format,
  :application_log_level,
  :system_log_level,
  :log_group)
  SENSITIVE = []
  include Aws::Structure
end