Class: Aws::Lambda::Types::OperationUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::OperationUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
An update to be applied to an operation during checkpointing.
Constant Summary collapse
- SENSITIVE =
[:payload]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to take on the operation.
-
#callback_options ⇒ Types::CallbackOptions
Configuration options for callback operations in durable executions, including timeout settings and retry behavior.
-
#chained_invoke_options ⇒ Types::ChainedInvokeOptions
Configuration options for chained function invocations in durable executions, including retry settings and timeout configuration.
-
#context_options ⇒ Types::ContextOptions
Options for context operations.
-
#error ⇒ Types::ErrorObject
The error information for failed operations.
-
#id ⇒ String
The unique identifier for this operation.
-
#name ⇒ String
The customer-provided name for this operation.
-
#parent_id ⇒ String
The unique identifier of the parent operation, if this operation is running within a child context.
-
#payload ⇒ String
The payload for successful operations.
-
#step_options ⇒ Types::StepOptions
Options for step operations.
-
#sub_type ⇒ String
The subtype of the operation, providing additional categorization.
-
#type ⇒ String
The type of operation to update.
-
#wait_options ⇒ Types::WaitOptions
Options for wait operations.
Instance Attribute Details
#action ⇒ String
The action to take on the operation.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#callback_options ⇒ Types::CallbackOptions
Configuration options for callback operations in durable executions, including timeout settings and retry behavior.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#chained_invoke_options ⇒ Types::ChainedInvokeOptions
Configuration options for chained function invocations in durable executions, including retry settings and timeout configuration.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#context_options ⇒ Types::ContextOptions
Options for context operations.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#error ⇒ Types::ErrorObject
The error information for failed operations.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#id ⇒ String
The unique identifier for this operation.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#name ⇒ String
The customer-provided name for this operation.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#parent_id ⇒ String
The unique identifier of the parent operation, if this operation is running within a child context.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#payload ⇒ String
The payload for successful operations. The maximum payload size is 6
MB for synchronous EXECUTION operations (RequestResponse
invocationType), 1 MB for asynchronous EXECUTION (Event
invocationType) and CHAINED_INVOKE operations, and 256 KB for
CONTEXT, STEP, WAIT, and CALLBACK operations.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#step_options ⇒ Types::StepOptions
Options for step operations.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#sub_type ⇒ String
The subtype of the operation, providing additional categorization.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#type ⇒ String
The type of operation to update.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#wait_options ⇒ Types::WaitOptions
Options for wait operations.
7533 7534 7535 7536 7537 7538 7539 7540 7541 7542 7543 7544 7545 7546 7547 7548 7549 |
# File 'lib/aws-sdk-lambda/types.rb', line 7533 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |