Class: Aws::Lambda::Types::OperationUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

An update to be applied to an operation during checkpointing.

Constant Summary collapse

SENSITIVE =
[:payload]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action to take on the operation.

Returns:

  • (String)


7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#callback_optionsTypes::CallbackOptions

Configuration options for callback operations in durable executions, including timeout settings and retry behavior.



7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#chained_invoke_optionsTypes::ChainedInvokeOptions

Configuration options for chained function invocations in durable executions, including retry settings and timeout configuration.



7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#context_optionsTypes::ContextOptions

Options for context operations.



7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#errorTypes::ErrorObject

The error information for failed operations.

Returns:



7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#idString

The unique identifier for this operation.

Returns:

  • (String)


7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#nameString

The customer-provided name for this operation.

Returns:

  • (String)


7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#parent_idString

The unique identifier of the parent operation, if this operation is running within a child context.

Returns:

  • (String)


7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#payloadString

The payload for successful operations. The maximum payload size is 6 MB for synchronous ‘EXECUTION` operations (RequestResponse invocationType), 1 MB for asynchronous `EXECUTION` (Event invocationType) and `CHAINED_INVOKE` operations, and 256 KB for `CONTEXT`, `STEP`, `WAIT`, and `CALLBACK` operations.

Returns:

  • (String)


7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#step_optionsTypes::StepOptions

Options for step operations.

Returns:



7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#sub_typeString

The subtype of the operation, providing additional categorization.

Returns:

  • (String)


7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#typeString

The type of operation to update.

Returns:

  • (String)


7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#wait_optionsTypes::WaitOptions

Options for wait operations.

Returns:



7369
7370
7371
7372
7373
7374
7375
7376
7377
7378
7379
7380
7381
7382
7383
7384
7385
# File 'lib/aws-sdk-lambda/types.rb', line 7369

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end