Class: Aws::Lambda::Types::OperationUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

An update to be applied to an operation during checkpointing.

Constant Summary collapse

SENSITIVE =
[:payload]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

The action to take on the operation.

Returns:

  • (String)


7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#callback_optionsTypes::CallbackOptions

Configuration options for callback operations in durable executions, including timeout settings and retry behavior.



7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#chained_invoke_optionsTypes::ChainedInvokeOptions

Configuration options for chained function invocations in durable executions, including retry settings and timeout configuration.



7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#context_optionsTypes::ContextOptions

Options for context operations.



7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#errorTypes::ErrorObject

The error information for failed operations.

Returns:



7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#idString

The unique identifier for this operation.

Returns:

  • (String)


7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#nameString

The customer-provided name for this operation.

Returns:

  • (String)


7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#parent_idString

The unique identifier of the parent operation, if this operation is running within a child context.

Returns:

  • (String)


7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#payloadString

The payload for successful operations.

Returns:

  • (String)


7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#step_optionsTypes::StepOptions

Options for step operations.

Returns:



7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#sub_typeString

The subtype of the operation, providing additional categorization.

Returns:

  • (String)


7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#typeString

The type of operation to update.

Returns:

  • (String)


7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end

#wait_optionsTypes::WaitOptions

Options for wait operations.

Returns:



7222
7223
7224
7225
7226
7227
7228
7229
7230
7231
7232
7233
7234
7235
7236
7237
7238
# File 'lib/aws-sdk-lambda/types.rb', line 7222

class OperationUpdate < Struct.new(
  :id,
  :parent_id,
  :name,
  :type,
  :sub_type,
  :action,
  :payload,
  :error,
  :context_options,
  :step_options,
  :wait_options,
  :callback_options,
  :chained_invoke_options)
  SENSITIVE = [:payload]
  include Aws::Structure
end