Class: Aws::Lambda::Types::OperationUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::OperationUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
An update to be applied to an operation during checkpointing.
Constant Summary collapse
- SENSITIVE =
[:payload]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to take on the operation.
-
#callback_options ⇒ Types::CallbackOptions
Configuration options for callback operations in durable executions, including timeout settings and retry behavior.
-
#chained_invoke_options ⇒ Types::ChainedInvokeOptions
Configuration options for chained function invocations in durable executions, including retry settings and timeout configuration.
-
#context_options ⇒ Types::ContextOptions
Options for context operations.
-
#error ⇒ Types::ErrorObject
The error information for failed operations.
-
#id ⇒ String
The unique identifier for this operation.
-
#name ⇒ String
The customer-provided name for this operation.
-
#parent_id ⇒ String
The unique identifier of the parent operation, if this operation is running within a child context.
-
#payload ⇒ String
The payload for successful operations.
-
#step_options ⇒ Types::StepOptions
Options for step operations.
-
#sub_type ⇒ String
The subtype of the operation, providing additional categorization.
-
#type ⇒ String
The type of operation to update.
-
#wait_options ⇒ Types::WaitOptions
Options for wait operations.
Instance Attribute Details
#action ⇒ String
The action to take on the operation.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#callback_options ⇒ Types::CallbackOptions
Configuration options for callback operations in durable executions, including timeout settings and retry behavior.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#chained_invoke_options ⇒ Types::ChainedInvokeOptions
Configuration options for chained function invocations in durable executions, including retry settings and timeout configuration.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#context_options ⇒ Types::ContextOptions
Options for context operations.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#error ⇒ Types::ErrorObject
The error information for failed operations.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#id ⇒ String
The unique identifier for this operation.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#name ⇒ String
The customer-provided name for this operation.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#parent_id ⇒ String
The unique identifier of the parent operation, if this operation is running within a child context.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#payload ⇒ String
The payload for successful operations.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#step_options ⇒ Types::StepOptions
Options for step operations.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#sub_type ⇒ String
The subtype of the operation, providing additional categorization.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#type ⇒ String
The type of operation to update.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |
#wait_options ⇒ Types::WaitOptions
Options for wait operations.
7222 7223 7224 7225 7226 7227 7228 7229 7230 7231 7232 7233 7234 7235 7236 7237 7238 |
# File 'lib/aws-sdk-lambda/types.rb', line 7222 class OperationUpdate < Struct.new( :id, :parent_id, :name, :type, :sub_type, :action, :payload, :error, :context_options, :step_options, :wait_options, :callback_options, :chained_invoke_options) SENSITIVE = [:payload] include Aws::Structure end |