Class: Aws::Lambda::Types::PublicPolicyException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PublicPolicyException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The resource-based policy you tried to add to the Lambda function
would grant public access to it, and your account's
BlockPublicAccess setting prevents public access. For more
information about blocking public access to Lambda functions, see
Block public access to Lambda resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The exception message.
-
#type ⇒ String
The exception type.
Instance Attribute Details
#message ⇒ String
The exception message.
7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-lambda/types.rb', line 7747 class PublicPolicyException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The exception type.
7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-lambda/types.rb', line 7747 class PublicPolicyException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |