Class: Aws::Lambda::Types::PublicPolicyException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The resource-based policy you tried to add to the Lambda function would grant public access to it, and your account's BlockPublicAccess setting prevents public access. For more information about blocking public access to Lambda functions, see Block public access to Lambda resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The exception message.

Returns:

  • (String)


7692
7693
7694
7695
7696
7697
# File 'lib/aws-sdk-lambda/types.rb', line 7692

class PublicPolicyException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The exception type.

Returns:

  • (String)


7692
7693
7694
7695
7696
7697
# File 'lib/aws-sdk-lambda/types.rb', line 7692

class PublicPolicyException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end