Class: Aws::Lambda::Types::PublicPolicyException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PublicPolicyException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Lambda prevented your policy from being created because it would grant public access to your function. If you intended to create a public policy, use the PutPublicAccessBlockConfig API action to configure your function’s public-access settings to allow public policies.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#type ⇒ String
The exception type.
Instance Attribute Details
#message ⇒ String
5072 5073 5074 5075 5076 5077 |
# File 'lib/aws-sdk-lambda/types.rb', line 5072 class PublicPolicyException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The exception type.
5072 5073 5074 5075 5076 5077 |
# File 'lib/aws-sdk-lambda/types.rb', line 5072 class PublicPolicyException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |