Class: Aws::Lambda::Types::PublishVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PublishVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
When making an API call, you may pass PublishVersionRequest data as a hash:
{
function_name: "FunctionName", # required
code_sha_256: "String",
description: "Description",
revision_id: "String",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_sha_256 ⇒ String
Only publish a version if the hash value matches the value that's specified.
-
#description ⇒ String
A description for the version to override the description in the function configuration.
-
#function_name ⇒ String
The name of the Lambda function.
-
#revision_id ⇒ String
Only update the function if the revision ID matches the ID that's specified.
Instance Attribute Details
#code_sha_256 ⇒ String
Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode.
5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'lib/aws-sdk-lambda/types.rb', line 5027 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the version to override the description in the function configuration.
5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'lib/aws-sdk-lambda/types.rb', line 5027 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** - `MyFunction`.
-
**Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:MyFunction`.
-
**Partial ARN** - `123456789012:function:MyFunction`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'lib/aws-sdk-lambda/types.rb', line 5027 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Only update the function if the revision ID matches the ID that's specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it.
5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'lib/aws-sdk-lambda/types.rb', line 5027 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id) SENSITIVE = [] include Aws::Structure end |