Class: Aws::Lambda::Types::PublishVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#code_sha_256String

Only publish a version if the hash value matches the value that’s specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode.



5208
5209
5210
5211
5212
5213
5214
5215
# File 'lib/aws-sdk-lambda/types.rb', line 5208

class PublishVersionRequest < Struct.new(
  :function_name,
  :code_sha_256,
  :description,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description for the version to override the description in the function configuration.



5208
5209
5210
5211
5212
5213
5214
5215
# File 'lib/aws-sdk-lambda/types.rb', line 5208

class PublishVersionRequest < Struct.new(
  :function_name,
  :code_sha_256,
  :description,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name or ARN of the Lambda function.

**Name formats**

  • **Function name** - MyFunction.

  • **Function ARN** - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.

  • **Partial ARN** - 123456789012:function:MyFunction.

The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.



5208
5209
5210
5211
5212
5213
5214
5215
# File 'lib/aws-sdk-lambda/types.rb', line 5208

class PublishVersionRequest < Struct.new(
  :function_name,
  :code_sha_256,
  :description,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

Only update the function if the revision ID matches the ID that’s specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it.



5208
5209
5210
5211
5212
5213
5214
5215
# File 'lib/aws-sdk-lambda/types.rb', line 5208

class PublishVersionRequest < Struct.new(
  :function_name,
  :code_sha_256,
  :description,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end