Class: Aws::Lambda::Types::PublishVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PublishVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code_sha_256 ⇒ String
Only publish a version if the hash value matches the value that's specified.
-
#description ⇒ String
A description for the version to override the description in the function configuration.
-
#function_name ⇒ String
The name or ARN of the Lambda function.
-
#publish_to ⇒ String
Specifies where to publish the function version or configuration.
-
#revision_id ⇒ String
Only update the function if the revision ID matches the ID that's specified.
Instance Attribute Details
#code_sha_256 ⇒ String
Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. You can get the hash for the version that you uploaded from the output of UpdateFunctionCode.
8000 8001 8002 8003 8004 8005 8006 8007 8008 |
# File 'lib/aws-sdk-lambda/types.rb', line 8000 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id, :publish_to) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the version to override the description in the function configuration.
8000 8001 8002 8003 8004 8005 8006 8007 8008 |
# File 'lib/aws-sdk-lambda/types.rb', line 8000 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id, :publish_to) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name or ARN of the Lambda function.
Name formats
-
Function name -
MyFunction. -
Function ARN -
arn:aws:lambda:us-west-2:123456789012:function:MyFunction. -
Partial ARN -
123456789012:function:MyFunction.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
8000 8001 8002 8003 8004 8005 8006 8007 8008 |
# File 'lib/aws-sdk-lambda/types.rb', line 8000 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id, :publish_to) SENSITIVE = [] include Aws::Structure end |
#publish_to ⇒ String
Specifies where to publish the function version or configuration.
8000 8001 8002 8003 8004 8005 8006 8007 8008 |
# File 'lib/aws-sdk-lambda/types.rb', line 8000 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id, :publish_to) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Only update the function if the revision ID matches the ID that's specified. Use this option to avoid publishing a version if the function configuration has changed since you last updated it.
8000 8001 8002 8003 8004 8005 8006 8007 8008 |
# File 'lib/aws-sdk-lambda/types.rb', line 8000 class PublishVersionRequest < Struct.new( :function_name, :code_sha_256, :description, :revision_id, :publish_to) SENSITIVE = [] include Aws::Structure end |