Class: Aws::Lambda::Types::PutResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PutResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The JSON resource-based policy you want to add to your function.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the function you want to add the policy to.
-
#revision_id ⇒ String
Replace the existing policy only if its revision ID matches the string you specify.
Instance Attribute Details
#policy ⇒ String
The JSON resource-based policy you want to add to your function.
To learn more about creating resource-based policies for controlling access to Lambda, see [Working with resource-based IAM policies in Lambda] in the *Lambda Developer Guide*.
[1]: docs.aws.amazon.com/
5650 5651 5652 5653 5654 5655 5656 |
# File 'lib/aws-sdk-lambda/types.rb', line 5650 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the function you want to add the policy to. You can use either a qualified or an unqualified ARN, but the value you specify must be a complete ARN and wildcard characters are not accepted.
5650 5651 5652 5653 5654 5655 5656 |
# File 'lib/aws-sdk-lambda/types.rb', line 5650 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Replace the existing policy only if its revision ID matches the string you specify. To find the revision ID of the policy currently attached to your function, use the GetResourcePolicy action.
5650 5651 5652 5653 5654 5655 5656 |
# File 'lib/aws-sdk-lambda/types.rb', line 5650 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |