Class: Aws::Lambda::Types::PutResourcePolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PutResourcePolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The policy Lambda added to your function.
-
#revision_id ⇒ String
The revision ID of the policy Lambda added to your function.
Instance Attribute Details
#policy ⇒ String
The policy Lambda added to your function.
5668 5669 5670 5671 5672 5673 |
# File 'lib/aws-sdk-lambda/types.rb', line 5668 class PutResourcePolicyResponse < Struct.new( :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The revision ID of the policy Lambda added to your function.
5668 5669 5670 5671 5672 5673 |
# File 'lib/aws-sdk-lambda/types.rb', line 5668 class PutResourcePolicyResponse < Struct.new( :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |