Class: Aws::Lambda::Types::PutRuntimeManagementConfigResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::PutRuntimeManagementConfigResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_arn ⇒ String
The ARN of the function.
-
#runtime_version_arn ⇒ String
The ARN of the runtime the function is configured to use.
-
#update_runtime_on ⇒ String
The runtime update mode.
Instance Attribute Details
#function_arn ⇒ String
The ARN of the function
8320 8321 8322 8323 8324 8325 8326 |
# File 'lib/aws-sdk-lambda/types.rb', line 8320 class PutRuntimeManagementConfigResponse < Struct.new( :update_runtime_on, :function_arn, :runtime_version_arn) SENSITIVE = [] include Aws::Structure end |
#runtime_version_arn ⇒ String
The ARN of the runtime the function is configured to use. If the
runtime update mode is manual, the ARN is returned, otherwise
null is returned.
8320 8321 8322 8323 8324 8325 8326 |
# File 'lib/aws-sdk-lambda/types.rb', line 8320 class PutRuntimeManagementConfigResponse < Struct.new( :update_runtime_on, :function_arn, :runtime_version_arn) SENSITIVE = [] include Aws::Structure end |
#update_runtime_on ⇒ String
The runtime update mode.
8320 8321 8322 8323 8324 8325 8326 |
# File 'lib/aws-sdk-lambda/types.rb', line 8320 class PutRuntimeManagementConfigResponse < Struct.new( :update_runtime_on, :function_arn, :runtime_version_arn) SENSITIVE = [] include Aws::Structure end |