Class: Aws::Lambda::Types::PutRuntimeManagementConfigResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_arnString

The ARN of the function



5268
5269
5270
5271
5272
5273
5274
# File 'lib/aws-sdk-lambda/types.rb', line 5268

class PutRuntimeManagementConfigResponse < Struct.new(
  :update_runtime_on,
  :function_arn,
  :runtime_version_arn)
  SENSITIVE = []
  include Aws::Structure
end

#runtime_version_arnString

The ARN of the runtime the function is configured to use. If the runtime update mode is manual, the ARN is returned, otherwise null is returned.



5268
5269
5270
5271
5272
5273
5274
# File 'lib/aws-sdk-lambda/types.rb', line 5268

class PutRuntimeManagementConfigResponse < Struct.new(
  :update_runtime_on,
  :function_arn,
  :runtime_version_arn)
  SENSITIVE = []
  include Aws::Structure
end

#update_runtime_onString

The runtime update mode.



5268
5269
5270
5271
5272
5273
5274
# File 'lib/aws-sdk-lambda/types.rb', line 5268

class PutRuntimeManagementConfigResponse < Struct.new(
  :update_runtime_on,
  :function_arn,
  :runtime_version_arn)
  SENSITIVE = []
  include Aws::Structure
end