Class: Aws::Lambda::Types::RemovePermissionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::RemovePermissionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#function_name ⇒ String
The name or ARN of the Lambda function, version, or alias.
-
#qualifier ⇒ String
Specify a version or alias to remove permissions from a published version of the function.
-
#revision_id ⇒ String
Update the policy only if the revision ID matches the ID that's specified.
-
#statement_id ⇒ String
Statement ID of the permission to remove.
Instance Attribute Details
#function_name ⇒ String
The name or ARN of the Lambda function, version, or alias.
Name formats
-
Function name –
my-function(name-only),my-function:v1(with alias). -
Function ARN –
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
Partial ARN –
123456789012:function:my-function.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
8363 8364 8365 8366 8367 8368 8369 8370 |
# File 'lib/aws-sdk-lambda/types.rb', line 8363 class RemovePermissionRequest < Struct.new( :function_name, :statement_id, :qualifier, :revision_id) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
Specify a version or alias to remove permissions from a published version of the function.
8363 8364 8365 8366 8367 8368 8369 8370 |
# File 'lib/aws-sdk-lambda/types.rb', line 8363 class RemovePermissionRequest < Struct.new( :function_name, :statement_id, :qualifier, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Update the policy only if the revision ID matches the ID that's specified. Use this option to avoid modifying a policy that has changed since you last read it.
8363 8364 8365 8366 8367 8368 8369 8370 |
# File 'lib/aws-sdk-lambda/types.rb', line 8363 class RemovePermissionRequest < Struct.new( :function_name, :statement_id, :qualifier, :revision_id) SENSITIVE = [] include Aws::Structure end |
#statement_id ⇒ String
Statement ID of the permission to remove.
8363 8364 8365 8366 8367 8368 8369 8370 |
# File 'lib/aws-sdk-lambda/types.rb', line 8363 class RemovePermissionRequest < Struct.new( :function_name, :statement_id, :qualifier, :revision_id) SENSITIVE = [] include Aws::Structure end |