Class: Aws::Lambda::Types::RemovePermissionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#function_nameString

The name of the Lambda function, version, or alias.

**Name formats**

  • **Function name** – ‘my-function` (name-only), `my-function:v1` (with alias).

  • **Function ARN** – ‘arn:aws:lambda:us-west-2:123456789012:function:my-function`.

  • **Partial ARN** – ‘123456789012:function:my-function`.

You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


5245
5246
5247
5248
5249
5250
5251
5252
# File 'lib/aws-sdk-lambda/types.rb', line 5245

class RemovePermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :qualifier,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#qualifierString

Specify a version or alias to remove permissions from a published version of the function.

Returns:

  • (String)


5245
5246
5247
5248
5249
5250
5251
5252
# File 'lib/aws-sdk-lambda/types.rb', line 5245

class RemovePermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :qualifier,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

Update the policy only if the revision ID matches the ID that’s specified. Use this option to avoid modifying a policy that has changed since you last read it.

Returns:

  • (String)


5245
5246
5247
5248
5249
5250
5251
5252
# File 'lib/aws-sdk-lambda/types.rb', line 5245

class RemovePermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :qualifier,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#statement_idString

Statement ID of the permission to remove.

Returns:

  • (String)


5245
5246
5247
5248
5249
5250
5251
5252
# File 'lib/aws-sdk-lambda/types.rb', line 5245

class RemovePermissionRequest < Struct.new(
  :function_name,
  :statement_id,
  :qualifier,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end