Class: Aws::Lambda::Types::ResourceInUseException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The operation conflicts with the resource’s availability. For example, you tried to update an event source mapping in the CREATING state, or you tried to delete an event source mapping currently UPDATING.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


8376
8377
8378
8379
8380
8381
# File 'lib/aws-sdk-lambda/types.rb', line 8376

class ResourceInUseException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Returns:

  • (String)


8376
8377
8378
8379
8380
8381
# File 'lib/aws-sdk-lambda/types.rb', line 8376

class ResourceInUseException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end