Class: Aws::Lambda::Types::ResourceInUseException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ResourceInUseException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The operation conflicts with the resource’s availability. For example, you tried to update an event source mapping in the CREATING state, or you tried to delete an event source mapping currently UPDATING.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
5295 5296 5297 5298 5299 5300 |
# File 'lib/aws-sdk-lambda/types.rb', line 5295 class ResourceInUseException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
5295 5296 5297 5298 5299 5300 |
# File 'lib/aws-sdk-lambda/types.rb', line 5295 class ResourceInUseException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |