Class: Aws::Lambda::Types::ServiceQuotaExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::ServiceQuotaExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The request would exceed a service quota. For more information about Lambda service quotas, see Lambda quotas. To request a quota increase, see Requesting a quota increase in the Service Quotas User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The exception message.
-
#type ⇒ String
The exception type.
Instance Attribute Details
#message ⇒ String
The exception message.
8789 8790 8791 8792 8793 8794 |
# File 'lib/aws-sdk-lambda/types.rb', line 8789 class ServiceQuotaExceededException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The exception type.
8789 8790 8791 8792 8793 8794 |
# File 'lib/aws-sdk-lambda/types.rb', line 8789 class ServiceQuotaExceededException < Struct.new( :type, :message) SENSITIVE = [] include Aws::Structure end |