Class: Aws::Lambda::Types::SnapStart
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::SnapStart
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The function’s Lambda SnapStart setting. Set ‘ApplyOn` to `PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version.
SnapStart is supported with the ‘java11` runtime. For more information, see [Improving startup performance with Lambda SnapStart].
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_on ⇒ String
Set to ‘PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version.
Instance Attribute Details
#apply_on ⇒ String
Set to ‘PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version.
5483 5484 5485 5486 5487 |
# File 'lib/aws-sdk-lambda/types.rb', line 5483 class SnapStart < Struct.new( :apply_on) SENSITIVE = [] include Aws::Structure end |