Class: Aws::Lambda::Types::SnapStart

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Note:

When making an API call, you may pass SnapStart data as a hash:

{
  apply_on: "PublishedVersions", # accepts PublishedVersions, None
}

The function's SnapStart setting. Set `ApplyOn` to `PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version. For more information, see [Reducing startup time with Lambda SnapStart].

[1]: docs.aws.amazon.com/lambda/latest/dg/snapstart.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apply_onString

Set to `PublishedVersions` to create a snapshot of the initialized execution environment when you publish a function version.

Returns:

  • (String)


5711
5712
5713
5714
5715
# File 'lib/aws-sdk-lambda/types.rb', line 5711

class SnapStart < Struct.new(
  :apply_on)
  SENSITIVE = []
  include Aws::Structure
end