Class: Aws::Lambda::Types::SnapStart
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::SnapStart
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
The function’s [Lambda SnapStart] setting. Set ApplyOn to PublishedVersions to create a snapshot of the initialized execution environment when you publish a function version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_on ⇒ String
Set to
PublishedVersionsto create a snapshot of the initialized execution environment when you publish a function version.