Class: Aws::Lambda::Types::SnapStartRegenerationFailureException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Lambda couldn’t regenerate the SnapStart snapshot for the function. SnapStart-enabled functions periodically regenerate snapshots when their underlying runtime or dependencies change; this regeneration failed. Wait for Lambda to retry, or update the function’s configuration to trigger a new snapshot. For more information, see [Lambda SnapStart].

[1]: docs.aws.amazon.com/lambda/latest/dg/snapstart.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The exception message.

Returns:

  • (String)


8807
8808
8809
8810
8811
8812
# File 'lib/aws-sdk-lambda/types.rb', line 8807

class SnapStartRegenerationFailureException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The exception type.

Returns:

  • (String)


8807
8808
8809
8810
8811
8812
# File 'lib/aws-sdk-lambda/types.rb', line 8807

class SnapStartRegenerationFailureException < Struct.new(
  :type,
  :message)
  SENSITIVE = []
  include Aws::Structure
end