Class: Aws::Lambda::Types::UpdateAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the alias.

Returns:

  • (String)


5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-lambda/types.rb', line 5883

class UpdateAliasRequest < Struct.new(
  :function_name,
  :name,
  :function_version,
  :description,
  :routing_config,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the Lambda function.

**Name formats**

  • **Function name** - ‘MyFunction`.

  • **Function ARN** - ‘arn:aws:lambda:us-west-2:123456789012:function:MyFunction`.

  • **Partial ARN** - ‘123456789012:function:MyFunction`.

The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-lambda/types.rb', line 5883

class UpdateAliasRequest < Struct.new(
  :function_name,
  :name,
  :function_version,
  :description,
  :routing_config,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#function_versionString

The function version that the alias invokes.

Returns:

  • (String)


5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-lambda/types.rb', line 5883

class UpdateAliasRequest < Struct.new(
  :function_name,
  :name,
  :function_version,
  :description,
  :routing_config,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the alias.

Returns:

  • (String)


5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-lambda/types.rb', line 5883

class UpdateAliasRequest < Struct.new(
  :function_name,
  :name,
  :function_version,
  :description,
  :routing_config,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

Only update the alias if the revision ID matches the ID that’s specified. Use this option to avoid modifying an alias that has changed since you last read it.

Returns:

  • (String)


5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-lambda/types.rb', line 5883

class UpdateAliasRequest < Struct.new(
  :function_name,
  :name,
  :function_version,
  :description,
  :routing_config,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#routing_configTypes::AliasRoutingConfiguration



5883
5884
5885
5886
5887
5888
5889
5890
5891
5892
# File 'lib/aws-sdk-lambda/types.rb', line 5883

class UpdateAliasRequest < Struct.new(
  :function_name,
  :name,
  :function_version,
  :description,
  :routing_config,
  :revision_id)
  SENSITIVE = []
  include Aws::Structure
end