Class: Aws::Lambda::Types::UpdateAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
When making an API call, you may pass UpdateAliasRequest data as a hash:
{
function_name: "FunctionName", # required
name: "Alias", # required
function_version: "Version",
description: "Description",
routing_config: {
additional_version_weights: {
"AdditionalVersion" => 1.0,
},
},
revision_id: "String",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the alias.
-
#function_name ⇒ String
The name of the Lambda function.
-
#function_version ⇒ String
The function version that the alias invokes.
-
#name ⇒ String
The name of the alias.
-
#revision_id ⇒ String
Only update the alias if the revision ID matches the ID that's specified.
-
#routing_config ⇒ Types::AliasRoutingConfiguration
The [routing configuration] of the alias.
Instance Attribute Details
#description ⇒ String
A description of the alias.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-lambda/types.rb', line 5903 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** - `MyFunction`.
-
**Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:MyFunction`.
-
**Partial ARN** - `123456789012:function:MyFunction`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-lambda/types.rb', line 5903 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#function_version ⇒ String
The function version that the alias invokes.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-lambda/types.rb', line 5903 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the alias.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-lambda/types.rb', line 5903 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Only update the alias if the revision ID matches the ID that's specified. Use this option to avoid modifying an alias that has changed since you last read it.
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-lambda/types.rb', line 5903 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |
#routing_config ⇒ Types::AliasRoutingConfiguration
The [routing configuration] of the alias.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-aliases.html#configuring-alias-routing
5903 5904 5905 5906 5907 5908 5909 5910 5911 5912 |
# File 'lib/aws-sdk-lambda/types.rb', line 5903 class UpdateAliasRequest < Struct.new( :function_name, :name, :function_version, :description, :routing_config, :revision_id) SENSITIVE = [] include Aws::Structure end |