Class: Aws::Lambda::Types::UpdateEventSourceMappingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Note:

When making an API call, you may pass UpdateEventSourceMappingRequest data as a hash:

{
  uuid: "String", # required
  function_name: "FunctionName",
  enabled: false,
  batch_size: 1,
  filter_criteria: {
    filters: [
      {
        pattern: "Pattern",
      },
    ],
  },
  maximum_batching_window_in_seconds: 1,
  destination_config: {
    on_success: {
      destination: "DestinationArn",
    },
    on_failure: {
      destination: "DestinationArn",
    },
  },
  maximum_record_age_in_seconds: 1,
  bisect_batch_on_function_error: false,
  maximum_retry_attempts: 1,
  parallelization_factor: 1,
  source_access_configurations: [
    {
      type: "BASIC_AUTH", # accepts BASIC_AUTH, VPC_SUBNET, VPC_SECURITY_GROUP, SASL_SCRAM_512_AUTH, SASL_SCRAM_256_AUTH, VIRTUAL_HOST, CLIENT_CERTIFICATE_TLS_AUTH, SERVER_ROOT_CA_CERTIFICATE
      uri: "URI",
    },
  ],
  tumbling_window_in_seconds: 1,
  function_response_types: ["ReportBatchItemFailures"], # accepts ReportBatchItemFailures
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_sizeInteger

The maximum number of records in each batch that Lambda pulls from your stream or queue and sends to your function. Lambda passes all of the records in the batch to the function in a single call, up to the payload limit for synchronous invocation (6 MB).

  • **Amazon Kinesis** - Default 100. Max 10,000.

  • **Amazon DynamoDB Streams** - Default 100. Max 1,000.

  • **Amazon Simple Queue Service** - Default 10. For standard queues the max is 10,000. For FIFO queues the max is 10.

  • **Amazon Managed Streaming for Apache Kafka** - Default 100. Max 10,000.

  • **Self-Managed Apache Kafka** - Default 100. Max 10,000.

  • **Amazon MQ (ActiveMQ and RabbitMQ)** - Default 100. Max 10,000.

Returns:

  • (Integer)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#bisect_batch_on_function_errorBoolean

(Streams only) If the function returns an error, split the batch in two and retry.

Returns:

  • (Boolean)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#destination_configTypes::DestinationConfig

(Streams only) An Amazon SQS queue or Amazon SNS topic destination for discarded records.



5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#enabledBoolean

When true, the event source mapping is active. When false, Lambda pauses polling and invocation.

Default: True

Returns:

  • (Boolean)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#filter_criteriaTypes::FilterCriteria

(Streams and Amazon SQS) An object that defines the filter criteria that determine whether Lambda should process an event. For more information, see [Lambda event filtering].

[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html



5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the Lambda function.

**Name formats**

  • **Function name** - `MyFunction`.

  • **Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:MyFunction`.

  • **Version or Alias ARN** - `arn:aws:lambda:us-west-2:123456789012:function:MyFunction:PROD`.

  • **Partial ARN** - `123456789012:function:MyFunction`.

The length constraint applies only to the full ARN. If you specify only the function name, it's limited to 64 characters in length.

Returns:

  • (String)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#function_response_typesArray<String>

(Streams and Amazon SQS) A list of current response type enums applied to the event source mapping.

Returns:

  • (Array<String>)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_batching_window_in_secondsInteger

(Streams and Amazon SQS standard queues) The maximum amount of time, in seconds, that Lambda spends gathering records before invoking the function.

Default: 0

Related setting: When you set `BatchSize` to a value greater than 10, you must set `MaximumBatchingWindowInSeconds` to at least 1.

Returns:

  • (Integer)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_record_age_in_secondsInteger

(Streams only) Discard records older than the specified age. The default value is infinite (-1).

Returns:

  • (Integer)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_retry_attemptsInteger

(Streams only) Discard records after the specified number of retries. The default value is infinite (-1). When set to infinite (-1), failed records will be retried until the record expires.

Returns:

  • (Integer)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#parallelization_factorInteger

(Streams only) The number of batches to process from each shard concurrently.

Returns:

  • (Integer)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#source_access_configurationsArray<Types::SourceAccessConfiguration>

An array of authentication protocols or VPC components required to secure your event source.



5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#tumbling_window_in_secondsInteger

(Streams only) The duration in seconds of a processing window. The range is between 1 second up to 900 seconds.

Returns:

  • (Integer)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end

#uuidString

The identifier of the event source mapping.

Returns:

  • (String)


5576
5577
5578
5579
5580
5581
5582
5583
5584
5585
5586
5587
5588
5589
5590
5591
5592
5593
# File 'lib/aws-sdk-lambda/types.rb', line 5576

class UpdateEventSourceMappingRequest < Struct.new(
  :uuid,
  :function_name,
  :enabled,
  :batch_size,
  :filter_criteria,
  :maximum_batching_window_in_seconds,
  :destination_config,
  :maximum_record_age_in_seconds,
  :bisect_batch_on_function_error,
  :maximum_retry_attempts,
  :parallelization_factor,
  :source_access_configurations,
  :tumbling_window_in_seconds,
  :function_response_types)
  SENSITIVE = []
  include Aws::Structure
end