Class: Aws::Lambda::Types::UpdateFunctionCodeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateFunctionCodeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
When making an API call, you may pass UpdateFunctionCodeRequest data as a hash:
{
function_name: "FunctionName", # required
zip_file: "data",
s3_bucket: "S3Bucket",
s3_key: "S3Key",
s3_object_version: "S3ObjectVersion",
image_uri: "String",
publish: false,
dry_run: false,
revision_id: "String",
architectures: ["x86_64"], # accepts x86_64, arm64
}
Constant Summary collapse
- SENSITIVE =
[:zip_file]
Instance Attribute Summary collapse
-
#architectures ⇒ Array<String>
The instruction set architecture that the function supports.
-
#dry_run ⇒ Boolean
Set to true to validate the request parameters and access permissions without modifying the function code.
-
#function_name ⇒ String
The name of the Lambda function.
-
#image_uri ⇒ String
URI of a container image in the Amazon ECR registry.
-
#publish ⇒ Boolean
Set to true to publish a new version of the function after updating the code.
-
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that's specified.
-
#s3_bucket ⇒ String
An Amazon S3 bucket in the same Amazon Web Services Region as your function.
-
#s3_key ⇒ String
The Amazon S3 key of the deployment package.
-
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
-
#zip_file ⇒ String
The base64-encoded contents of the deployment package.
Instance Attribute Details
#architectures ⇒ Array<String>
The instruction set architecture that the function supports. Enter a string array with one of the valid values (arm64 or x86_64). The default value is `x86_64`.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#dry_run ⇒ Boolean
Set to true to validate the request parameters and access permissions without modifying the function code.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** – `my-function`.
-
**Function ARN** – `arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – `123456789012:function:my-function`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#image_uri ⇒ String
URI of a container image in the Amazon ECR registry. Do not use for a function defined with a .zip file archive.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#publish ⇒ Boolean
Set to true to publish a new version of the function after updating the code. This has the same effect as calling PublishVersion separately.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_bucket ⇒ String
An Amazon S3 bucket in the same Amazon Web Services Region as your function. The bucket can be in a different Amazon Web Services account. Use only with a function defined with a .zip file archive deployment package.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_key ⇒ String
The Amazon S3 key of the deployment package. Use only with a function defined with a .zip file archive deployment package.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |
#zip_file ⇒ String
The base64-encoded contents of the deployment package. Amazon Web Services SDK and CLI clients handle the encoding for you. Use only with a function defined with a .zip file archive deployment package.
6423 6424 6425 6426 6427 6428 6429 6430 6431 6432 6433 6434 6435 6436 |
# File 'lib/aws-sdk-lambda/types.rb', line 6423 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :image_uri, :publish, :dry_run, :revision_id, :architectures) SENSITIVE = [:zip_file] include Aws::Structure end |