Class: Aws::Lambda::Types::UpdateFunctionCodeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateFunctionCodeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
When making an API call, you may pass UpdateFunctionCodeRequest data as a hash:
{
function_name: "FunctionName", # required
zip_file: "data",
s3_bucket: "S3Bucket",
s3_key: "S3Key",
s3_object_version: "S3ObjectVersion",
publish: false,
dry_run: false,
revision_id: "String",
}
Constant Summary collapse
- SENSITIVE =
[:zip_file]
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
Set to true to validate the request parameters and access permissions without modifying the function code.
-
#function_name ⇒ String
The name of the Lambda function.
-
#publish ⇒ Boolean
Set to true to publish a new version of the function after updating the code.
-
#revision_id ⇒ String
Only update the function if the revision ID matches the ID that’s specified.
-
#s3_bucket ⇒ String
An Amazon S3 bucket in the same AWS Region as your function.
-
#s3_key ⇒ String
The Amazon S3 key of the deployment package.
-
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
-
#zip_file ⇒ String
The base64-encoded contents of the deployment package.
Instance Attribute Details
#dry_run ⇒ Boolean
Set to true to validate the request parameters and access permissions without modifying the function code.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** -
my-function. -
**Function ARN** -
arn:aws:lambda:us-west-2:123456789012:function:my-function. -
**Partial ARN** -
123456789012:function:my-function.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |
#publish ⇒ Boolean
Set to true to publish a new version of the function after updating the code. This has the same effect as calling PublishVersion separately.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |
#revision_id ⇒ String
Only update the function if the revision ID matches the ID that’s specified. Use this option to avoid modifying a function that has changed since you last read it.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_bucket ⇒ String
An Amazon S3 bucket in the same AWS Region as your function. The bucket can be in a different AWS account.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_key ⇒ String
The Amazon S3 key of the deployment package.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |
#s3_object_version ⇒ String
For versioned objects, the version of the deployment package object to use.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |
#zip_file ⇒ String
The base64-encoded contents of the deployment package. AWS SDK and AWS CLI clients handle the encoding for you.
4394 4395 4396 4397 4398 4399 4400 4401 4402 4403 4404 4405 |
# File 'lib/aws-sdk-lambda/types.rb', line 4394 class UpdateFunctionCodeRequest < Struct.new( :function_name, :zip_file, :s3_bucket, :s3_key, :s3_object_version, :publish, :dry_run, :revision_id) SENSITIVE = [:zip_file] include Aws::Structure end |