Class: Aws::Lambda::Types::UpdateFunctionConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_provider_configTypes::CapacityProviderConfig

Configuration for the capacity provider that manages compute resources for Lambda functions.



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#dead_letter_configTypes::DeadLetterConfig

A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see Dead-letter queues.



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the function.

Returns:

  • (String)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#durable_configTypes::DurableConfig

Configuration settings for durable functions, including execution timeout, retention period for execution history, and an optional ARN of the Key Management Service (KMS) customer managed key that is used to encrypt your durable execution's payload data, including input, output, and error payloads.



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#environmentTypes::Environment

Environment variables that are accessible from function code during execution.

Returns:



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeral_storageTypes::EphemeralStorage

The size of the function's /tmp directory in MB. The default value is 512, but can be any whole number between 512 and 10,240 MB. For more information, see Configuring ephemeral storage (console).



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_configsArray<Types::FileSystemConfig>

Connection settings for an Amazon EFS file system or an Amazon S3 Files file system.

Returns:



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name or ARN of the Lambda function.

Name formats

  • Function namemy-function.

  • Function ARNarn:aws:lambda:us-west-2:123456789012:function:my-function.

  • Partial ARN123456789012:function:my-function.

The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#handlerString

The name of the method within your code that Lambda calls to run your function. Handler is required if the deployment package is a .zip file archive. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see Lambda programming model.

Returns:

  • (String)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#image_configTypes::ImageConfig

Container image configuration values that override the values in the container image Docker file.

Returns:



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The ARN of the Key Management Service (KMS) customer managed key that's used to encrypt the following resources:

  • The function's environment variables.

  • The function's Lambda SnapStart snapshots.

  • When used with SourceKMSKeyArn, the unzipped version of the .zip deployment package that's used for function invocations. For more information, see Specifying a customer managed key for Lambda.

  • The optimized version of the container image that's used for function invocations. Note that this is not the same key that's used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see Function lifecycle.

If you don't provide a customer managed key, Lambda uses an Amazon Web Services owned key or an Amazon Web Services managed key.

Returns:

  • (String)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#layersArray<String>

A list of function layers to add to the function's execution environment. Specify each layer by its ARN, including the version.

Returns:

  • (Array<String>)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configTypes::LoggingConfig

The function's Amazon CloudWatch Logs configuration settings.



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#memory_sizeInteger

The amount of memory available to the function at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB.

Returns:

  • (Integer)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#revision_idString

Update the function only if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.

Returns:

  • (String)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The Amazon Resource Name (ARN) of the function's execution role.

Returns:

  • (String)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#runtimeString

The identifier of the function's runtime. Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you're deploying a function using a container image.

The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see Runtime use after deprecation.

For a list of all currently supported runtimes, see Supported runtimes.

Returns:

  • (String)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#snap_startTypes::SnapStart

The function's SnapStart setting.

Returns:



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#timeoutInteger

The amount of time (in seconds) that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For more information, see Lambda execution environment.

Returns:

  • (Integer)


10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#tracing_configTypes::TracingConfig

Set Mode to Active to sample and trace a subset of incoming requests with X-Ray.



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can access resources and the internet only through that VPC. For more information, see Configuring a Lambda function to access resources in a VPC.

Returns:



10123
10124
10125
10126
10127
10128
10129
10130
10131
10132
10133
10134
10135
10136
10137
10138
10139
10140
10141
10142
10143
10144
10145
10146
10147
# File 'lib/aws-sdk-lambda/types.rb', line 10123

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers,
  :file_system_configs,
  :image_config,
  :ephemeral_storage,
  :snap_start,
  :logging_config,
  :capacity_provider_config,
  :durable_config)
  SENSITIVE = []
  include Aws::Structure
end