Class: Aws::Lambda::Types::UpdateFunctionConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateFunctionConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dead_letter_config ⇒ Types::DeadLetterConfig
A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing.
-
#description ⇒ String
A description of the function.
-
#environment ⇒ Types::Environment
Environment variables that are accessible from function code during execution.
-
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function’s ‘/tmp` directory in MB.
-
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an Amazon EFS file system.
-
#function_name ⇒ String
The name of the Lambda function.
-
#handler ⇒ String
The name of the method within your code that Lambda calls to run your function.
-
#image_config ⇒ Types::ImageConfig
- Container image configuration values][1
-
that override the values in the container image Docker file.
-
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that’s used to encrypt your function’s [environment variables].
-
#layers ⇒ Array<String>
A list of [function layers] to add to the function’s execution environment.
-
#memory_size ⇒ Integer
The amount of [memory available to the function] at runtime.
-
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that’s specified.
-
#role ⇒ String
The Amazon Resource Name (ARN) of the function’s execution role.
-
#runtime ⇒ String
The identifier of the function’s [runtime].
-
#snap_start ⇒ Types::SnapStart
The function’s [SnapStart] setting.
-
#timeout ⇒ Integer
The amount of time (in seconds) that Lambda allows a function to run before stopping it.
-
#tracing_config ⇒ Types::TracingConfig
Set ‘Mode` to `Active` to sample and trace a subset of incoming requests with [X-Ray].
-
#vpc_config ⇒ Types::VpcConfig
For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC.
Instance Attribute Details
#dead_letter_config ⇒ Types::DeadLetterConfig
A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see [Dead-letter queues].
[1]: docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-dlq
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the function.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#environment ⇒ Types::Environment
Environment variables that are accessible from function code during execution.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#ephemeral_storage ⇒ Types::EphemeralStorage
The size of the function’s ‘/tmp` directory in MB. The default value is 512, but can be any whole number between 512 and 10,240 MB.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#file_system_configs ⇒ Array<Types::FileSystemConfig>
Connection settings for an Amazon EFS file system.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** – ‘my-function`.
-
**Function ARN** – ‘arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – ‘123456789012:function:my-function`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#handler ⇒ String
The name of the method within your code that Lambda calls to run your function. Handler is required if the deployment package is a .zip file archive. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see [Lambda programming model].
[1]: docs.aws.amazon.com/lambda/latest/dg/foundation-progmodel.html
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#image_config ⇒ Types::ImageConfig
- Container image configuration values][1
-
that override the values
in the container image Docker file.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the Key Management Service (KMS) customer managed key that’s used to encrypt your function’s [environment variables]. When [Lambda SnapStart] is activated, Lambda also uses this key is to encrypt your function’s snapshot. If you deploy your function using a container image, Lambda also uses this key to encrypt your function when it’s deployed. Note that this is not the same key that’s used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). If you don’t provide a customer managed key, Lambda uses a default service key.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html#configuration-envvars-encryption [2]: docs.aws.amazon.com/lambda/latest/dg/snapstart-security.html
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#layers ⇒ Array<String>
A list of [function layers] to add to the function’s execution environment. Specify each layer by its ARN, including the version.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#memory_size ⇒ Integer
The amount of [memory available to the function] at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB.
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-function-common.html#configuration-memory-console
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
Update the function only if the revision ID matches the ID that’s specified. Use this option to avoid modifying a function that has changed since you last read it.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
The Amazon Resource Name (ARN) of the function’s execution role.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#runtime ⇒ String
The identifier of the function’s [runtime]. Runtime is required if the deployment package is a .zip file archive.
The following list includes deprecated runtimes. For more information, see [Runtime deprecation policy].
[1]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html [2]: docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtime-support-policy
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#snap_start ⇒ Types::SnapStart
The function’s [SnapStart] setting.
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#timeout ⇒ Integer
The amount of time (in seconds) that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For more information, see [Lambda execution environment].
[1]: docs.aws.amazon.com/lambda/latest/dg/runtimes-context.html
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#tracing_config ⇒ Types::TracingConfig
Set ‘Mode` to `Active` to sample and trace a subset of incoming requests with [X-Ray].
[1]: docs.aws.amazon.com/lambda/latest/dg/services-xray.html
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
For network connectivity to Amazon Web Services resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can access resources and the internet only through that VPC. For more information, see [Configuring a Lambda function to access resources in a VPC].
[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html
6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 6339 6340 6341 6342 6343 6344 6345 6346 6347 6348 6349 |
# File 'lib/aws-sdk-lambda/types.rb', line 6328 class UpdateFunctionConfigurationRequest < Struct.new( :function_name, :role, :handler, :description, :timeout, :memory_size, :vpc_config, :environment, :runtime, :dead_letter_config, :kms_key_arn, :tracing_config, :revision_id, :layers, :file_system_configs, :image_config, :ephemeral_storage, :snap_start) SENSITIVE = [] include Aws::Structure end |