Class: Aws::Lambda::Types::UpdateFunctionConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Note:

When making an API call, you may pass UpdateFunctionConfigurationRequest data as a hash:

{
  function_name: "FunctionName", # required
  role: "RoleArn",
  handler: "Handler",
  description: "Description",
  timeout: 1,
  memory_size: 1,
  vpc_config: {
    subnet_ids: ["SubnetId"],
    security_group_ids: ["SecurityGroupId"],
  },
  environment: {
    variables: {
      "EnvironmentVariableName" => "EnvironmentVariableValue",
    },
  },
  runtime: "nodejs", # accepts nodejs, nodejs4.3, nodejs6.10, nodejs8.10, java8, python2.7, python3.6, python3.7, dotnetcore1.0, dotnetcore2.0, dotnetcore2.1, nodejs4.3-edge, go1.x, ruby2.5, provided
  dead_letter_config: {
    target_arn: "ResourceArn",
  },
  kms_key_arn: "KMSKeyArn",
  tracing_config: {
    mode: "Active", # accepts Active, PassThrough
  },
  revision_id: "String",
  layers: ["LayerVersionArn"],
}

Instance Attribute Summary collapse

Instance Attribute Details

#dead_letter_configTypes::DeadLetterConfig

A dead letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see Dead Letter Queues.



2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#descriptionString

A description of the function.

Returns:

  • (String)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#environmentTypes::Environment

Environment variables that are accessible from function code during execution.

Returns:



2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#function_nameString

The name of the Lambda function.

Name formats

  • Function name - my-function.

  • Function ARN - arn:aws:lambda:us-west-2:123456789012:function:my-function.

  • Partial ARN - 123456789012:function:my-function.

The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#handlerString

The name of the method within your code that Lambda calls to execute your function. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see Programming Model.

Returns:

  • (String)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#kms_key_arnString

The ARN of the AWS Key Management Service (AWS KMS) key that's used to encrypt your function's environment variables. If it's not provided, AWS Lambda uses a default service key.

Returns:

  • (String)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#layersArray<String>

A list of function layers to add to the function's execution environment. Specify each layer by its ARN, including the version.

Returns:

  • (Array<String>)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#memory_sizeInteger

The amount of memory that your function has access to. Increasing the function's memory also increases its CPU allocation. The default value is 128 MB. The value must be a multiple of 64 MB.

Returns:

  • (Integer)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#revision_idString

Only update the function if the revision ID matches the ID that's specified. Use this option to avoid modifying a function that has changed since you last read it.

Returns:

  • (String)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#roleString

The Amazon Resource Name (ARN) of the function's execution role.

Returns:

  • (String)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#runtimeString

The identifier of the function's runtime.

Returns:

  • (String)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#timeoutInteger

The amount of time that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds.

Returns:

  • (Integer)


2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#tracing_configTypes::TracingConfig

Set Mode to Active to sample and trace a subset of incoming requests with AWS X-Ray.



2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

For network connectivity to AWS resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can only access resources and the internet through that VPC. For more information, see VPC Settings.

Returns:



2949
2950
2951
2952
2953
2954
2955
2956
2957
2958
2959
2960
2961
2962
2963
2964
2965
# File 'lib/aws-sdk-lambda/types.rb', line 2949

class UpdateFunctionConfigurationRequest < Struct.new(
  :function_name,
  :role,
  :handler,
  :description,
  :timeout,
  :memory_size,
  :vpc_config,
  :environment,
  :runtime,
  :dead_letter_config,
  :kms_key_arn,
  :tracing_config,
  :revision_id,
  :layers)
  include Aws::Structure
end