Class: Aws::Lambda::Types::UpdateFunctionEventInvokeConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateFunctionEventInvokeConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_config ⇒ Types::DestinationConfig
A destination for events after they have been sent to a function for processing.
-
#function_name ⇒ String
The name of the Lambda function, version, or alias.
-
#maximum_event_age_in_seconds ⇒ Integer
The maximum age of a request that Lambda sends to a function for processing.
-
#maximum_retry_attempts ⇒ Integer
The maximum number of times to retry when the function returns an error.
-
#qualifier ⇒ String
A version number or alias name.
Instance Attribute Details
#destination_config ⇒ Types::DestinationConfig
A destination for events after they have been sent to a function for processing.
Destinations
-
Function - The Amazon Resource Name (ARN) of a Lambda function.
-
Queue - The ARN of a standard SQS queue.
-
Topic - The ARN of a standard SNS topic.
-
**Event Bus** - The ARN of an Amazon EventBridge event bus.
6339 6340 6341 6342 6343 6344 6345 6346 6347 |
# File 'lib/aws-sdk-lambda/types.rb', line 6339 class UpdateFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier, :maximum_retry_attempts, :maximum_event_age_in_seconds, :destination_config) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function, version, or alias.
**Name formats**
-
**Function name** - ‘my-function` (name-only), `my-function:v1` (with alias).
-
**Function ARN** - ‘arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** - ‘123456789012:function:my-function`.
You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
6339 6340 6341 6342 6343 6344 6345 6346 6347 |
# File 'lib/aws-sdk-lambda/types.rb', line 6339 class UpdateFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier, :maximum_retry_attempts, :maximum_event_age_in_seconds, :destination_config) SENSITIVE = [] include Aws::Structure end |
#maximum_event_age_in_seconds ⇒ Integer
The maximum age of a request that Lambda sends to a function for processing.
6339 6340 6341 6342 6343 6344 6345 6346 6347 |
# File 'lib/aws-sdk-lambda/types.rb', line 6339 class UpdateFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier, :maximum_retry_attempts, :maximum_event_age_in_seconds, :destination_config) SENSITIVE = [] include Aws::Structure end |
#maximum_retry_attempts ⇒ Integer
The maximum number of times to retry when the function returns an error.
6339 6340 6341 6342 6343 6344 6345 6346 6347 |
# File 'lib/aws-sdk-lambda/types.rb', line 6339 class UpdateFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier, :maximum_retry_attempts, :maximum_event_age_in_seconds, :destination_config) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
A version number or alias name.
6339 6340 6341 6342 6343 6344 6345 6346 6347 |
# File 'lib/aws-sdk-lambda/types.rb', line 6339 class UpdateFunctionEventInvokeConfigRequest < Struct.new( :function_name, :qualifier, :maximum_retry_attempts, :maximum_event_age_in_seconds, :destination_config) SENSITIVE = [] include Aws::Structure end |