Class: Aws::Lambda::Types::UpdateFunctionEventInvokeConfigRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_configTypes::DestinationConfig

A destination for events after they have been sent to a function for processing.

*Destinations*

  • *Function* - The Amazon Resource Name (ARN) of a Lambda function.

  • *Queue* - The ARN of an SQS queue.

  • *Topic* - The ARN of an SNS topic.

  • **Event Bus** - The ARN of an Amazon EventBridge event bus.



5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lambda/types.rb', line 5834

class UpdateFunctionEventInvokeConfigRequest < Struct.new(
  :function_name,
  :qualifier,
  :maximum_retry_attempts,
  :maximum_event_age_in_seconds,
  :destination_config)
  SENSITIVE = []
  include Aws::Structure
end

#function_nameString

The name of the Lambda function, version, or alias.

**Name formats**

  • **Function name** - `my-function` (name-only), `my-function:v1` (with alias).

  • **Function ARN** - `arn:aws:lambda:us-west-2:123456789012:function:my-function`.

  • **Partial ARN** - `123456789012:function:my-function`.

You can append a version number or alias to any of the formats. The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.

Returns:

  • (String)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lambda/types.rb', line 5834

class UpdateFunctionEventInvokeConfigRequest < Struct.new(
  :function_name,
  :qualifier,
  :maximum_retry_attempts,
  :maximum_event_age_in_seconds,
  :destination_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_event_age_in_secondsInteger

The maximum age of a request that Lambda sends to a function for processing.

Returns:

  • (Integer)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lambda/types.rb', line 5834

class UpdateFunctionEventInvokeConfigRequest < Struct.new(
  :function_name,
  :qualifier,
  :maximum_retry_attempts,
  :maximum_event_age_in_seconds,
  :destination_config)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_retry_attemptsInteger

The maximum number of times to retry when the function returns an error.

Returns:

  • (Integer)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lambda/types.rb', line 5834

class UpdateFunctionEventInvokeConfigRequest < Struct.new(
  :function_name,
  :qualifier,
  :maximum_retry_attempts,
  :maximum_event_age_in_seconds,
  :destination_config)
  SENSITIVE = []
  include Aws::Structure
end

#qualifierString

A version number or alias name.

Returns:

  • (String)


5834
5835
5836
5837
5838
5839
5840
5841
5842
# File 'lib/aws-sdk-lambda/types.rb', line 5834

class UpdateFunctionEventInvokeConfigRequest < Struct.new(
  :function_name,
  :qualifier,
  :maximum_retry_attempts,
  :maximum_event_age_in_seconds,
  :destination_config)
  SENSITIVE = []
  include Aws::Structure
end