Class: Aws::Lambda::Types::UpdateFunctionUrlConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Lambda::Types::UpdateFunctionUrlConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-lambda/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_type ⇒ String
The type of authentication that your function URL uses.
-
#cors ⇒ Types::Cors
The [cross-origin resource sharing (CORS)] settings for your function URL.
-
#function_name ⇒ String
The name of the Lambda function.
-
#qualifier ⇒ String
The alias name.
Instance Attribute Details
#auth_type ⇒ String
The type of authentication that your function URL uses. Set to `AWS_IAM` if you want to restrict access to authenticated IAM users only. Set to `NONE` if you want to bypass IAM authentication to create a public endpoint. For more information, see [Security and auth model for Lambda function URLs].
5887 5888 5889 5890 5891 5892 5893 5894 |
# File 'lib/aws-sdk-lambda/types.rb', line 5887 class UpdateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors) SENSITIVE = [] include Aws::Structure end |
#cors ⇒ Types::Cors
The [cross-origin resource sharing (CORS)] settings for your function URL.
5887 5888 5889 5890 5891 5892 5893 5894 |
# File 'lib/aws-sdk-lambda/types.rb', line 5887 class UpdateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors) SENSITIVE = [] include Aws::Structure end |
#function_name ⇒ String
The name of the Lambda function.
**Name formats**
-
**Function name** – `my-function`.
-
**Function ARN** – `arn:aws:lambda:us-west-2:123456789012:function:my-function`.
-
**Partial ARN** – `123456789012:function:my-function`.
The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
5887 5888 5889 5890 5891 5892 5893 5894 |
# File 'lib/aws-sdk-lambda/types.rb', line 5887 class UpdateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors) SENSITIVE = [] include Aws::Structure end |
#qualifier ⇒ String
The alias name.
5887 5888 5889 5890 5891 5892 5893 5894 |
# File 'lib/aws-sdk-lambda/types.rb', line 5887 class UpdateFunctionUrlConfigRequest < Struct.new( :function_name, :qualifier, :auth_type, :cors) SENSITIVE = [] include Aws::Structure end |