Class: Aws::Lambda::Types::VpcConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-lambda/types.rb

Overview

The VPC security groups and subnets that are attached to a Lambda function. For more information, see [Configuring a Lambda function to access resources in a VPC].

[1]: docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#security_group_idsArray<String>

A list of VPC security group IDs.

Returns:

  • (Array<String>)


5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-lambda/types.rb', line 5974

class VpcConfig < Struct.new(
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

A list of VPC subnet IDs.

Returns:

  • (Array<String>)


5974
5975
5976
5977
5978
5979
# File 'lib/aws-sdk-lambda/types.rb', line 5974

class VpcConfig < Struct.new(
  :subnet_ids,
  :security_group_ids)
  SENSITIVE = []
  include Aws::Structure
end