Class: Aws::Lambda::Waiters::FunctionActiveV2
- Inherits:
-
Object
- Object
- Aws::Lambda::Waiters::FunctionActiveV2
- Defined in:
- lib/aws-sdk-lambda/waiters.rb,
sig/waiters.rbs
Overview
Waits for the function's State to be Active. This waiter uses GetFunction API. This should be used after new function creation.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FunctionActiveV2
constructor
A new instance of FunctionActiveV2.
-
#wait(params = {}) ⇒ Types::GetFunctionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FunctionActiveV2
Returns a new instance of FunctionActiveV2.
141 142 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 141
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
179 180 181 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 179 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetFunctionResponse
Returns a response object which responds to the following methods:
- #configuration => Types::FunctionConfiguration
- #code => Types::FunctionCodeLocation
- #tags => Hash<String,String>
- #tags_error => Types::TagsError
- #concurrency => Types::Concurrency
174 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 174
def wait: (
|