Class: Aws::Lambda::Waiters::FunctionExists
- Inherits:
-
Object
- Object
- Aws::Lambda::Waiters::FunctionExists
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-lambda/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FunctionExists
constructor
A new instance of FunctionExists.
-
#wait(params = {}) ⇒ Types::GetFunctionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FunctionExists
Returns a new instance of FunctionExists.
191 192 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 191
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
221 222 223 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 221 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetFunctionResponse
Returns a response object which responds to the following methods:
- #configuration => Types::FunctionConfiguration
- #code => Types::FunctionCodeLocation
- #tags => Hash<String,String>
- #tags_error => Types::TagsError
- #concurrency => Types::Concurrency
216 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 216
def wait: (
|