Class: Aws::Lambda::Waiters::FunctionUpdated
- Inherits:
-
Object
- Object
- Aws::Lambda::Waiters::FunctionUpdated
- Defined in:
- lib/aws-sdk-lambda/waiters.rb,
sig/waiters.rbs
Overview
Waits for the function's LastUpdateStatus to be Successful. This waiter uses GetFunctionConfiguration API. This should be used after function updates.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FunctionUpdated
constructor
A new instance of FunctionUpdated.
-
#wait(params = {}) ⇒ Types::FunctionConfiguration
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FunctionUpdated
Returns a new instance of FunctionUpdated.
234 235 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 234
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
272 273 274 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 272 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::FunctionConfiguration
Returns a response object which responds to the following methods:
- #function_name => String
- #function_arn => String
- #runtime => String
- #role => String
- #handler => String
- #code_size => Integer
- #description => String
- #timeout => Integer
- #memory_size => Integer
- #last_modified => Time
- #code_sha_256 => String
- #version => String
- #vpc_config => Types::VpcConfigResponse
- #dead_letter_config => Types::DeadLetterConfig
- #environment => Types::EnvironmentResponse
- #kms_key_arn => String
- #tracing_config => Types::TracingConfigResponse
- #master_arn => String
- #revision_id => String
- #layers => Array<Types::Layer>
- #state => String
- #state_reason => String
- #state_reason_code => String
- #last_update_status => String
- #last_update_status_reason => String
- #last_update_status_reason_code => String
- #file_system_configs => Array<Types::FileSystemConfig>
- #signing_profile_version_arn => String
- #signing_job_arn => String
- #package_type => String
- #image_config_response => Types::ImageConfigResponse
- #architectures => Array<String>
- #ephemeral_storage => Types::EphemeralStorage
- #snap_start => Types::SnapStartResponse
- #runtime_version_config => Types::RuntimeVersionConfig
- #logging_config => Types::LoggingConfig
- #tenancy_config => Types::TenancyConfig
- #capacity_provider_config => Types::CapacityProviderConfig
- #config_sha_256 => String
- #durable_config => Types::DurableConfig
267 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 267
def wait: (
|