Class: Aws::Lambda::Waiters::FunctionUpdatedV2
- Inherits:
-
Object
- Object
- Aws::Lambda::Waiters::FunctionUpdatedV2
- Defined in:
- lib/aws-sdk-lambda/waiters.rb,
sig/waiters.rbs
Overview
Waits for the function's LastUpdateStatus to be Successful. This waiter uses GetFunction API. This should be used after function updates.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ FunctionUpdatedV2
constructor
A new instance of FunctionUpdatedV2.
-
#wait(params = {}) ⇒ Types::GetFunctionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ FunctionUpdatedV2
Returns a new instance of FunctionUpdatedV2.
285 286 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 285
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
323 324 325 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 323 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetFunctionResponse
Returns a response object which responds to the following methods:
- #configuration => Types::FunctionConfiguration
- #code => Types::FunctionCodeLocation
- #tags => Hash<String,String>
- #tags_error => Types::TagsError
- #concurrency => Types::Concurrency
318 |
# File 'lib/aws-sdk-lambda/waiters.rb', line 318
def wait: (
|